# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: loki_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'loki_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12loki_service.proto\x12\x08isa.loki\x1a\x0c\x63ommon.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xb9\x01\n\x08LogEntry\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04line\x18\x02 \x01(\t\x12.\n\x06labels\x18\x03 \x03(\x0b\x32\x1e.isa.loki.LogEntry.LabelsEntry\x12\x11\n\tstream_id\x18\x04 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb5\x02\n\nStreamInfo\x12\x11\n\tstream_id\x18\x01 \x01(\t\x12\x30\n\x06labels\x18\x02 \x03(\x0b\x32 .isa.loki.StreamInfo.LabelsEntry\x12\x13\n\x0b\x65ntry_count\x18\x03 \x01(\x03\x12\r\n\x05\x62ytes\x18\x04 \x01(\x03\x12\x32\n\x0e\x66irst_entry_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rlast_entry_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07user_id\x18\x07 \x01(\t\x12\x17\n\x0forganization_id\x18\x08 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\tDataPoint\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\"\x8a\x01\n\x06Matrix\x12,\n\x06metric\x18\x01 \x03(\x0b\x32\x1c.isa.loki.Matrix.MetricEntry\x12#\n\x06values\x18\x02 \x03(\x0b\x32\x13.isa.loki.DataPoint\x1a-\n\x0bMetricEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"p\n\x0ePushLogRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x11\n\ttenant_id\x18\x03 \x01(\t\x12!\n\x05\x65ntry\x18\x04 \x01(\x0b\x32\x12.isa.loki.LogEntry\"F\n\x0fPushLogResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x11\n\tstream_id\x18\x03 \x01(\t\"w\n\x13PushLogBatchRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x11\n\ttenant_id\x18\x03 \x01(\t\x12#\n\x07\x65ntries\x18\x04 \x03(\x0b\x32\x12.isa.loki.LogEntry\"x\n\x14PushLogBatchResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0e\x61\x63\x63\x65pted_count\x18\x02 \x01(\x05\x12\x16\n\x0erejected_count\x18\x03 \x01(\x05\x12\x0e\n\x06\x65rrors\x18\x04 \x03(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xaf\x02\n\x14PushSimpleLogRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0f\n\x07service\x18\x03 \x01(\t\x12!\n\x05level\x18\x04 \x01(\x0e\x32\x12.isa.loki.LogLevel\x12\x0f\n\x07message\x18\x05 \x01(\t\x12\x45\n\x0c\x65xtra_labels\x18\x06 \x03(\x0b\x32/.isa.loki.PushSimpleLogRequest.ExtraLabelsEntry\x12-\n\ttimestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x32\n\x10\x45xtraLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd4\x01\n\x10QueryLogsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x11\n\ttenant_id\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\x12\r\n\x05limit\x18\x05 \x01(\x05\x12)\n\x05start\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tdirection\x18\x08 \x01(\t\"\xb2\x01\n\x11QueryLogsResponse\x12#\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x12.isa.loki.LogEntry\x12\x13\n\x0btotal_count\x18\x02 \x01(\x03\x12\x35\n\x05stats\x18\x03 \x03(\x0b\x32&.isa.loki.QueryLogsResponse.StatsEntry\x1a,\n\nStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd0\x01\n\x11QueryRangeRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x11\n\ttenant_id\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\x12)\n\x05start\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04step\x18\x07 \x01(\x05\x12\r\n\x05limit\x18\x08 \x01(\x05\"\xe9\x01\n\x12QueryRangeResponse\x12\x13\n\x0bresult_type\x18\x01 \x01(\t\x12(\n\x0ematrix_results\x18\x02 \x03(\x0b\x32\x10.isa.loki.Matrix\x12.\n\x0estream_results\x18\x03 \x03(\x0b\x32\x16.isa.loki.StreamResult\x12\x36\n\x05stats\x18\x04 \x03(\x0b\x32\'.isa.loki.QueryRangeResponse.StatsEntry\x1a,\n\nStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x96\x01\n\x0cStreamResult\x12\x32\n\x06stream\x18\x01 \x03(\x0b\x32\".isa.loki.StreamResult.StreamEntry\x12#\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x12.isa.loki.LogEntry\x1a-\n\x0bStreamEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaa\x01\n\x0fTailLogsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x11\n\ttenant_id\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\x12\x11\n\tdelay_for\x18\x05 \x01(\x05\x12\r\n\x05limit\x18\x06 \x01(\x05\x12)\n\x05start\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xb3\x01\n\x11QueryStatsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x11\n\ttenant_id\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\x12)\n\x05start\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x8d\x02\n\x12QueryStatsResponse\x12\x15\n\rtotal_entries\x18\x01 \x01(\x03\x12\x13\n\x0btotal_bytes\x18\x02 \x01(\x03\x12\x15\n\rstreams_count\x18\x03 \x01(\x03\x12\x15\n\rquery_time_ms\x18\x04 \x01(\x01\x12O\n\x12level_distribution\x18\x05 \x03(\x0b\x32\x33.isa.loki.QueryStatsResponse.LevelDistributionEntry\x12\x12\n\ntop_labels\x18\x06 \x03(\t\x1a\x38\n\x16LevelDistributionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xa3\x01\n\x10GetLabelsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x11\n\ttenant_id\x18\x03 \x01(\t\x12)\n\x05start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"#\n\x11GetLabelsResponse\x12\x0e\n\x06labels\x18\x01 \x03(\t\"\xcb\x01\n\x15GetLabelValuesRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x11\n\ttenant_id\x18\x03 \x01(\t\x12\x12\n\nlabel_name\x18\x04 \x01(\t\x12)\n\x05start\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05query\x18\x07 \x01(\t\"(\n\x16GetLabelValuesResponse\x12\x0e\n\x06values\x18\x01 \x03(\t\"\x83\x01\n\x15ValidateLabelsRequest\x12;\n\x06labels\x18\x01 \x03(\x0b\x32+.isa.loki.ValidateLabelsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"L\n\x16ValidateLabelsResponse\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x12\n\nviolations\x18\x02 \x03(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"\xeb\x01\n\x12ListStreamsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x11\n\ttenant_id\x18\x03 \x01(\t\x12\x43\n\x0clabel_filter\x18\x04 \x03(\x0b\x32-.isa.loki.ListStreamsRequest.LabelFilterEntry\x12\x0c\n\x04page\x18\x05 \x01(\x05\x12\x11\n\tpage_size\x18\x06 \x01(\x05\x1a\x32\n\x10LabelFilterEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"r\n\x13ListStreamsResponse\x12%\n\x07streams\x18\x01 \x03(\x0b\x32\x14.isa.loki.StreamInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x11\n\tpage_size\x18\x04 \x01(\x05\":\n\x14GetStreamInfoRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x11\n\tstream_id\x18\x02 \x01(\t\"=\n\x15GetStreamInfoResponse\x12$\n\x06stream\x18\x01 \x01(\x0b\x32\x14.isa.loki.StreamInfo\"\x8d\x01\n\x13\x44\x65leteStreamRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x11\n\tstream_id\x18\x02 \x01(\t\x12)\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"Q\n\x14\x44\x65leteStreamResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x17\n\x0f\x64\x65leted_entries\x18\x02 \x01(\x03\x12\x0f\n\x07message\x18\x03 \x01(\t\"\xef\x01\n\x11\x45xportLogsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x11\n\ttenant_id\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\x12)\n\x05start\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x06\x66ormat\x18\x07 \x01(\x0e\x32\x16.isa.loki.ExportFormat\x12\x12\n\nchunk_size\x18\x08 \x01(\x05\"y\n\x12\x45xportLogsResponse\x12\x11\n\texport_id\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x15\n\rtotal_entries\x18\x03 \x01(\x03\x12\x19\n\x11processed_entries\x18\x04 \x01(\x03\x12\x10\n\x08\x63omplete\x18\x05 \x01(\x08\"<\n\x16GetExportStatusRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x11\n\texport_id\x18\x02 \x01(\t\"\x83\x02\n\x17GetExportStatusResponse\x12\x11\n\texport_id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x15\n\rtotal_entries\x18\x03 \x01(\x03\x12\x18\n\x10\x65xported_entries\x18\x04 \x01(\x03\x12\x1b\n\x13progress_percentage\x18\x05 \x01(\x05\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63ompleted_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rerror_message\x18\x08 \x01(\t\"\x94\x01\n\x14GetStatisticsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12)\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa1\x04\n\x15GetStatisticsResponse\x12\x15\n\rtotal_entries\x18\x01 \x01(\x03\x12\x13\n\x0btotal_bytes\x18\x02 \x01(\x03\x12\x15\n\rstreams_count\x18\x03 \x01(\x03\x12Q\n\x12\x65ntries_by_service\x18\x04 \x03(\x0b\x32\x35.isa.loki.GetStatisticsResponse.EntriesByServiceEntry\x12M\n\x10\x65ntries_by_level\x18\x05 \x03(\x0b\x32\x33.isa.loki.GetStatisticsResponse.EntriesByLevelEntry\x12+\n\x0eingestion_rate\x18\x06 \x03(\x0b\x32\x13.isa.loki.DataPoint\x12\x14\n\x0ctop_services\x18\x07 \x03(\t\x12?\n\x08metadata\x18\x08 \x03(\x0b\x32-.isa.loki.GetStatisticsResponse.MetadataEntry\x1a\x37\n\x15\x45ntriesByServiceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x35\n\x13\x45ntriesByLevelEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\x13GetUserQuotaRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\"\xa8\x01\n\x14GetUserQuotaResponse\x12\x13\n\x0b\x64\x61ily_limit\x18\x01 \x01(\x03\x12\x12\n\ntoday_used\x18\x02 \x01(\x03\x12\x1b\n\x13storage_limit_bytes\x18\x03 \x01(\x03\x12\x1a\n\x12storage_used_bytes\x18\x04 \x01(\x03\x12\x16\n\x0eretention_days\x18\x05 \x01(\x05\x12\x16\n\x0equota_exceeded\x18\x06 \x01(\x08\",\n\x16LokiHealthCheckRequest\x12\x12\n\ndeep_check\x18\x01 \x01(\x08\"\xaf\x02\n\x17LokiHealthCheckResponse\x12\x0f\n\x07healthy\x18\x01 \x01(\x08\x12\x13\n\x0bloki_status\x18\x02 \x01(\t\x12\x11\n\tcan_write\x18\x03 \x01(\x08\x12\x10\n\x08\x63\x61n_read\x18\x04 \x01(\x08\x12.\n\nchecked_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07message\x18\x06 \x01(\t\x12P\n\x10\x63omponent_status\x18\x07 \x03(\x0b\x32\x36.isa.loki.LokiHealthCheckResponse.ComponentStatusEntry\x1a\x36\n\x14\x43omponentStatusEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*\x88\x01\n\x08LogLevel\x12\x15\n\x11LOG_LEVEL_UNKNOWN\x10\x00\x12\x13\n\x0fLOG_LEVEL_DEBUG\x10\x01\x12\x12\n\x0eLOG_LEVEL_INFO\x10\x02\x12\x12\n\x0eLOG_LEVEL_WARN\x10\x03\x12\x13\n\x0fLOG_LEVEL_ERROR\x10\x04\x12\x13\n\x0fLOG_LEVEL_FATAL\x10\x05*R\n\x0c\x45xportFormat\x12\x0f\n\x0b\x45XPORT_JSON\x10\x00\x12\x10\n\x0c\x45XPORT_JSONL\x10\x01\x12\x0e\n\nEXPORT_CSV\x10\x02\x12\x0f\n\x0b\x45XPORT_TEXT\x10\x03\x32\xbf\x0b\n\x0bLokiService\x12>\n\x07PushLog\x12\x18.isa.loki.PushLogRequest\x1a\x19.isa.loki.PushLogResponse\x12M\n\x0cPushLogBatch\x12\x1d.isa.loki.PushLogBatchRequest\x1a\x1e.isa.loki.PushLogBatchResponse\x12K\n\rPushLogStream\x12\x18.isa.loki.PushLogRequest\x1a\x1e.isa.loki.PushLogBatchResponse(\x01\x12J\n\rPushSimpleLog\x12\x1e.isa.loki.PushSimpleLogRequest\x1a\x19.isa.loki.PushLogResponse\x12\x44\n\tQueryLogs\x12\x1a.isa.loki.QueryLogsRequest\x1a\x1b.isa.loki.QueryLogsResponse\x12G\n\nQueryRange\x12\x1b.isa.loki.QueryRangeRequest\x1a\x1c.isa.loki.QueryRangeResponse\x12;\n\x08TailLogs\x12\x19.isa.loki.TailLogsRequest\x1a\x12.isa.loki.LogEntry0\x01\x12G\n\nQueryStats\x12\x1b.isa.loki.QueryStatsRequest\x1a\x1c.isa.loki.QueryStatsResponse\x12\x44\n\tGetLabels\x12\x1a.isa.loki.GetLabelsRequest\x1a\x1b.isa.loki.GetLabelsResponse\x12S\n\x0eGetLabelValues\x12\x1f.isa.loki.GetLabelValuesRequest\x1a .isa.loki.GetLabelValuesResponse\x12S\n\x0eValidateLabels\x12\x1f.isa.loki.ValidateLabelsRequest\x1a .isa.loki.ValidateLabelsResponse\x12J\n\x0bListStreams\x12\x1c.isa.loki.ListStreamsRequest\x1a\x1d.isa.loki.ListStreamsResponse\x12P\n\rGetStreamInfo\x12\x1e.isa.loki.GetStreamInfoRequest\x1a\x1f.isa.loki.GetStreamInfoResponse\x12M\n\x0c\x44\x65leteStream\x12\x1d.isa.loki.DeleteStreamRequest\x1a\x1e.isa.loki.DeleteStreamResponse\x12I\n\nExportLogs\x12\x1b.isa.loki.ExportLogsRequest\x1a\x1c.isa.loki.ExportLogsResponse0\x01\x12V\n\x0fGetExportStatus\x12 .isa.loki.GetExportStatusRequest\x1a!.isa.loki.GetExportStatusResponse\x12P\n\rGetStatistics\x12\x1e.isa.loki.GetStatisticsRequest\x1a\x1f.isa.loki.GetStatisticsResponse\x12M\n\x0cGetUserQuota\x12\x1d.isa.loki.GetUserQuotaRequest\x1a\x1e.isa.loki.GetUserQuotaResponse\x12R\n\x0bHealthCheck\x12 .isa.loki.LokiHealthCheckRequest\x1a!.isa.loki.LokiHealthCheckResponseB/Z-github.com/isa-cloud/isa_cloud/api/proto/lokib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'loki_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/isa-cloud/isa_cloud/api/proto/loki'
  _globals['_LOGENTRY_LABELSENTRY']._loaded_options = None
  _globals['_LOGENTRY_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_STREAMINFO_LABELSENTRY']._loaded_options = None
  _globals['_STREAMINFO_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_MATRIX_METRICENTRY']._loaded_options = None
  _globals['_MATRIX_METRICENTRY']._serialized_options = b'8\001'
  _globals['_PUSHSIMPLELOGREQUEST_EXTRALABELSENTRY']._loaded_options = None
  _globals['_PUSHSIMPLELOGREQUEST_EXTRALABELSENTRY']._serialized_options = b'8\001'
  _globals['_QUERYLOGSRESPONSE_STATSENTRY']._loaded_options = None
  _globals['_QUERYLOGSRESPONSE_STATSENTRY']._serialized_options = b'8\001'
  _globals['_QUERYRANGERESPONSE_STATSENTRY']._loaded_options = None
  _globals['_QUERYRANGERESPONSE_STATSENTRY']._serialized_options = b'8\001'
  _globals['_STREAMRESULT_STREAMENTRY']._loaded_options = None
  _globals['_STREAMRESULT_STREAMENTRY']._serialized_options = b'8\001'
  _globals['_QUERYSTATSRESPONSE_LEVELDISTRIBUTIONENTRY']._loaded_options = None
  _globals['_QUERYSTATSRESPONSE_LEVELDISTRIBUTIONENTRY']._serialized_options = b'8\001'
  _globals['_VALIDATELABELSREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_VALIDATELABELSREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_LISTSTREAMSREQUEST_LABELFILTERENTRY']._loaded_options = None
  _globals['_LISTSTREAMSREQUEST_LABELFILTERENTRY']._serialized_options = b'8\001'
  _globals['_GETSTATISTICSRESPONSE_ENTRIESBYSERVICEENTRY']._loaded_options = None
  _globals['_GETSTATISTICSRESPONSE_ENTRIESBYSERVICEENTRY']._serialized_options = b'8\001'
  _globals['_GETSTATISTICSRESPONSE_ENTRIESBYLEVELENTRY']._loaded_options = None
  _globals['_GETSTATISTICSRESPONSE_ENTRIESBYLEVELENTRY']._serialized_options = b'8\001'
  _globals['_GETSTATISTICSRESPONSE_METADATAENTRY']._loaded_options = None
  _globals['_GETSTATISTICSRESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_LOKIHEALTHCHECKRESPONSE_COMPONENTSTATUSENTRY']._loaded_options = None
  _globals['_LOKIHEALTHCHECKRESPONSE_COMPONENTSTATUSENTRY']._serialized_options = b'8\001'
  _globals['_LOGLEVEL']._serialized_start=6527
  _globals['_LOGLEVEL']._serialized_end=6663
  _globals['_EXPORTFORMAT']._serialized_start=6665
  _globals['_EXPORTFORMAT']._serialized_end=6747
  _globals['_LOGENTRY']._serialized_start=110
  _globals['_LOGENTRY']._serialized_end=295
  _globals['_LOGENTRY_LABELSENTRY']._serialized_start=250
  _globals['_LOGENTRY_LABELSENTRY']._serialized_end=295
  _globals['_STREAMINFO']._serialized_start=298
  _globals['_STREAMINFO']._serialized_end=607
  _globals['_STREAMINFO_LABELSENTRY']._serialized_start=250
  _globals['_STREAMINFO_LABELSENTRY']._serialized_end=295
  _globals['_DATAPOINT']._serialized_start=609
  _globals['_DATAPOINT']._serialized_end=682
  _globals['_MATRIX']._serialized_start=685
  _globals['_MATRIX']._serialized_end=823
  _globals['_MATRIX_METRICENTRY']._serialized_start=778
  _globals['_MATRIX_METRICENTRY']._serialized_end=823
  _globals['_PUSHLOGREQUEST']._serialized_start=825
  _globals['_PUSHLOGREQUEST']._serialized_end=937
  _globals['_PUSHLOGRESPONSE']._serialized_start=939
  _globals['_PUSHLOGRESPONSE']._serialized_end=1009
  _globals['_PUSHLOGBATCHREQUEST']._serialized_start=1011
  _globals['_PUSHLOGBATCHREQUEST']._serialized_end=1130
  _globals['_PUSHLOGBATCHRESPONSE']._serialized_start=1132
  _globals['_PUSHLOGBATCHRESPONSE']._serialized_end=1252
  _globals['_PUSHSIMPLELOGREQUEST']._serialized_start=1255
  _globals['_PUSHSIMPLELOGREQUEST']._serialized_end=1558
  _globals['_PUSHSIMPLELOGREQUEST_EXTRALABELSENTRY']._serialized_start=1508
  _globals['_PUSHSIMPLELOGREQUEST_EXTRALABELSENTRY']._serialized_end=1558
  _globals['_QUERYLOGSREQUEST']._serialized_start=1561
  _globals['_QUERYLOGSREQUEST']._serialized_end=1773
  _globals['_QUERYLOGSRESPONSE']._serialized_start=1776
  _globals['_QUERYLOGSRESPONSE']._serialized_end=1954
  _globals['_QUERYLOGSRESPONSE_STATSENTRY']._serialized_start=1910
  _globals['_QUERYLOGSRESPONSE_STATSENTRY']._serialized_end=1954
  _globals['_QUERYRANGEREQUEST']._serialized_start=1957
  _globals['_QUERYRANGEREQUEST']._serialized_end=2165
  _globals['_QUERYRANGERESPONSE']._serialized_start=2168
  _globals['_QUERYRANGERESPONSE']._serialized_end=2401
  _globals['_QUERYRANGERESPONSE_STATSENTRY']._serialized_start=1910
  _globals['_QUERYRANGERESPONSE_STATSENTRY']._serialized_end=1954
  _globals['_STREAMRESULT']._serialized_start=2404
  _globals['_STREAMRESULT']._serialized_end=2554
  _globals['_STREAMRESULT_STREAMENTRY']._serialized_start=2509
  _globals['_STREAMRESULT_STREAMENTRY']._serialized_end=2554
  _globals['_TAILLOGSREQUEST']._serialized_start=2557
  _globals['_TAILLOGSREQUEST']._serialized_end=2727
  _globals['_QUERYSTATSREQUEST']._serialized_start=2730
  _globals['_QUERYSTATSREQUEST']._serialized_end=2909
  _globals['_QUERYSTATSRESPONSE']._serialized_start=2912
  _globals['_QUERYSTATSRESPONSE']._serialized_end=3181
  _globals['_QUERYSTATSRESPONSE_LEVELDISTRIBUTIONENTRY']._serialized_start=3125
  _globals['_QUERYSTATSRESPONSE_LEVELDISTRIBUTIONENTRY']._serialized_end=3181
  _globals['_GETLABELSREQUEST']._serialized_start=3184
  _globals['_GETLABELSREQUEST']._serialized_end=3347
  _globals['_GETLABELSRESPONSE']._serialized_start=3349
  _globals['_GETLABELSRESPONSE']._serialized_end=3384
  _globals['_GETLABELVALUESREQUEST']._serialized_start=3387
  _globals['_GETLABELVALUESREQUEST']._serialized_end=3590
  _globals['_GETLABELVALUESRESPONSE']._serialized_start=3592
  _globals['_GETLABELVALUESRESPONSE']._serialized_end=3632
  _globals['_VALIDATELABELSREQUEST']._serialized_start=3635
  _globals['_VALIDATELABELSREQUEST']._serialized_end=3766
  _globals['_VALIDATELABELSREQUEST_LABELSENTRY']._serialized_start=250
  _globals['_VALIDATELABELSREQUEST_LABELSENTRY']._serialized_end=295
  _globals['_VALIDATELABELSRESPONSE']._serialized_start=3768
  _globals['_VALIDATELABELSRESPONSE']._serialized_end=3844
  _globals['_LISTSTREAMSREQUEST']._serialized_start=3847
  _globals['_LISTSTREAMSREQUEST']._serialized_end=4082
  _globals['_LISTSTREAMSREQUEST_LABELFILTERENTRY']._serialized_start=4032
  _globals['_LISTSTREAMSREQUEST_LABELFILTERENTRY']._serialized_end=4082
  _globals['_LISTSTREAMSRESPONSE']._serialized_start=4084
  _globals['_LISTSTREAMSRESPONSE']._serialized_end=4198
  _globals['_GETSTREAMINFOREQUEST']._serialized_start=4200
  _globals['_GETSTREAMINFOREQUEST']._serialized_end=4258
  _globals['_GETSTREAMINFORESPONSE']._serialized_start=4260
  _globals['_GETSTREAMINFORESPONSE']._serialized_end=4321
  _globals['_DELETESTREAMREQUEST']._serialized_start=4324
  _globals['_DELETESTREAMREQUEST']._serialized_end=4465
  _globals['_DELETESTREAMRESPONSE']._serialized_start=4467
  _globals['_DELETESTREAMRESPONSE']._serialized_end=4548
  _globals['_EXPORTLOGSREQUEST']._serialized_start=4551
  _globals['_EXPORTLOGSREQUEST']._serialized_end=4790
  _globals['_EXPORTLOGSRESPONSE']._serialized_start=4792
  _globals['_EXPORTLOGSRESPONSE']._serialized_end=4913
  _globals['_GETEXPORTSTATUSREQUEST']._serialized_start=4915
  _globals['_GETEXPORTSTATUSREQUEST']._serialized_end=4975
  _globals['_GETEXPORTSTATUSRESPONSE']._serialized_start=4978
  _globals['_GETEXPORTSTATUSRESPONSE']._serialized_end=5237
  _globals['_GETSTATISTICSREQUEST']._serialized_start=5240
  _globals['_GETSTATISTICSREQUEST']._serialized_end=5388
  _globals['_GETSTATISTICSRESPONSE']._serialized_start=5391
  _globals['_GETSTATISTICSRESPONSE']._serialized_end=5936
  _globals['_GETSTATISTICSRESPONSE_ENTRIESBYSERVICEENTRY']._serialized_start=5777
  _globals['_GETSTATISTICSRESPONSE_ENTRIESBYSERVICEENTRY']._serialized_end=5832
  _globals['_GETSTATISTICSRESPONSE_ENTRIESBYLEVELENTRY']._serialized_start=5834
  _globals['_GETSTATISTICSRESPONSE_ENTRIESBYLEVELENTRY']._serialized_end=5887
  _globals['_GETSTATISTICSRESPONSE_METADATAENTRY']._serialized_start=5889
  _globals['_GETSTATISTICSRESPONSE_METADATAENTRY']._serialized_end=5936
  _globals['_GETUSERQUOTAREQUEST']._serialized_start=5938
  _globals['_GETUSERQUOTAREQUEST']._serialized_end=6001
  _globals['_GETUSERQUOTARESPONSE']._serialized_start=6004
  _globals['_GETUSERQUOTARESPONSE']._serialized_end=6172
  _globals['_LOKIHEALTHCHECKREQUEST']._serialized_start=6174
  _globals['_LOKIHEALTHCHECKREQUEST']._serialized_end=6218
  _globals['_LOKIHEALTHCHECKRESPONSE']._serialized_start=6221
  _globals['_LOKIHEALTHCHECKRESPONSE']._serialized_end=6524
  _globals['_LOKIHEALTHCHECKRESPONSE_COMPONENTSTATUSENTRY']._serialized_start=6470
  _globals['_LOKIHEALTHCHECKRESPONSE_COMPONENTSTATUSENTRY']._serialized_end=6524
  _globals['_LOKISERVICE']._serialized_start=6750
  _globals['_LOKISERVICE']._serialized_end=8221
# @@protoc_insertion_point(module_scope)
