# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: postgres_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'postgres_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16postgres_service.proto\x12\x0cisa.postgres\x1a\x0c\x63ommon.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x82\x01\n\x0cQueryRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x0b\n\x03sql\x18\x02 \x01(\t\x12&\n\x06params\x18\x03 \x03(\x0b\x32\x16.google.protobuf.Value\x12\x0e\n\x06schema\x18\x04 \x01(\t\"y\n\rQueryResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12%\n\x04rows\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\trow_count\x18\x03 \x01(\x05\"\x85\x01\n\x0fQueryRowRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x0b\n\x03sql\x18\x02 \x01(\t\x12&\n\x06params\x18\x03 \x03(\x0b\x32\x16.google.protobuf.Value\x12\x0e\n\x06schema\x18\x04 \x01(\t\"w\n\x10QueryRowResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12$\n\x03row\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05\x66ound\x18\x03 \x01(\x08\"\x84\x01\n\x0e\x45xecuteRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x0b\n\x03sql\x18\x02 \x01(\t\x12&\n\x06params\x18\x03 \x03(\x0b\x32\x16.google.protobuf.Value\x12\x0e\n\x06schema\x18\x04 \x01(\t\"m\n\x0f\x45xecuteResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x15\n\rrows_affected\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ommand_tag\x18\x03 \x01(\t\"\x86\x01\n\x13\x45xecuteBatchRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x30\n\noperations\x18\x02 \x03(\x0b\x32\x1c.isa.postgres.BatchOperation\x12\x0e\n\x06schema\x18\x03 \x01(\t\"E\n\x0e\x42\x61tchOperation\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12&\n\x06params\x18\x02 \x03(\x0b\x32\x16.google.protobuf.Value\"\x91\x01\n\x14\x45xecuteBatchResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12,\n\x07results\x18\x02 \x03(\x0b\x32\x1b.isa.postgres.ExecuteResult\x12\x1b\n\x13total_rows_affected\x18\x03 \x01(\x05\"J\n\rExecuteResult\x12\x15\n\rrows_affected\x18\x01 \x01(\x03\x12\x13\n\x0b\x63ommand_tag\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"\xcd\x01\n\x11SelectFromRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x03 \x03(\t\x12(\n\x05where\x18\x04 \x03(\x0b\x32\x19.isa.postgres.WhereClause\x12\x10\n\x08order_by\x18\x05 \x03(\t\x12\r\n\x05limit\x18\x06 \x01(\x05\x12\x0e\n\x06offset\x18\x07 \x01(\x05\x12\x0e\n\x06schema\x18\x08 \x01(\t\"V\n\x0bWhereClause\x12\x0e\n\x06\x63olumn\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12%\n\x05value\x18\x03 \x01(\x0b\x32\x16.google.protobuf.Value\"~\n\x12SelectFromResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12%\n\x04rows\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\trow_count\x18\x03 \x01(\x05\"\x9b\x01\n\x11InsertIntoRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12%\n\x04rows\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\treturning\x18\x04 \x01(\x08\x12\x0e\n\x06schema\x18\x05 \x01(\t\"\x82\x01\n\x12InsertIntoResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x15\n\rrows_inserted\x18\x02 \x01(\x03\x12%\n\x04rows\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct\"\xc8\x01\n\x12UpdateTableRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12\'\n\x06values\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12(\n\x05where\x18\x04 \x03(\x0b\x32\x19.isa.postgres.WhereClause\x12\x11\n\treturning\x18\x05 \x01(\x08\x12\x0e\n\x06schema\x18\x06 \x01(\t\"\x82\x01\n\x13UpdateTableResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x14\n\x0crows_updated\x18\x02 \x01(\x03\x12%\n\x04rows\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct\"\x9e\x01\n\x11\x44\x65leteFromRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12(\n\x05where\x18\x03 \x03(\x0b\x32\x19.isa.postgres.WhereClause\x12\x11\n\treturning\x18\x04 \x01(\x08\x12\x0e\n\x06schema\x18\x05 \x01(\t\"\x81\x01\n\x12\x44\x65leteFromResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x14\n\x0crows_deleted\x18\x02 \x01(\x03\x12%\n\x04rows\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct\"a\n\x17\x42\x65ginTransactionRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0fisolation_level\x18\x02 \x01(\t\"b\n\x18\x42\x65ginTransactionResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x16\n\x0etransaction_id\x18\x02 \x01(\t\"a\n\x18\x43ommitTransactionRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x16\n\x0etransaction_id\x18\x02 \x01(\t\"\\\n\x19\x43ommitTransactionResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07success\x18\x02 \x01(\x08\"c\n\x1aRollbackTransactionRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x16\n\x0etransaction_id\x18\x02 \x01(\t\"^\n\x1bRollbackTransactionResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07success\x18\x02 \x01(\x08\"\x8e\x01\n\x1b\x45xecuteInTransactionRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x30\n\noperations\x18\x02 \x03(\x0b\x32\x1c.isa.postgres.BatchOperation\x12\x0e\n\x06schema\x18\x03 \x01(\t\"\x8f\x01\n\x1c\x45xecuteInTransactionResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12,\n\x07results\x18\x02 \x03(\x0b\x32\x1b.isa.postgres.ExecuteResult\x12\x11\n\tcommitted\x18\x03 \x01(\x08\"c\n\x13GetTableInfoRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\"s\n\x14GetTableInfoResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12+\n\ntable_info\x18\x02 \x01(\x0b\x32\x17.isa.postgres.TableInfo\"\x8c\x01\n\tTableInfo\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12)\n\x07\x63olumns\x18\x03 \x03(\x0b\x32\x18.isa.postgres.ColumnInfo\x12\x14\n\x0cprimary_keys\x18\x04 \x03(\t\x12\x1a\n\x12row_count_estimate\x18\x05 \x01(\x03\"`\n\nColumnInfo\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x11\n\tdata_type\x18\x02 \x01(\t\x12\x13\n\x0bis_nullable\x18\x03 \x01(\x08\x12\x15\n\rdefault_value\x18\x04 \x01(\t\"R\n\x11ListTablesRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x0e\n\x06schema\x18\x02 \x01(\t\"T\n\x12ListTablesResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0e\n\x06tables\x18\x02 \x03(\t\"b\n\x12TableExistsRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\"U\n\x13TableExistsResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0e\n\x06\x65xists\x18\x02 \x01(\x08\"U\n\x12HealthCheckRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x10\n\x08\x64\x65tailed\x18\x02 \x01(\x08\"\xa1\x01\n\x13HealthCheckResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07healthy\x18\x02 \x01(\x08\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12(\n\x07\x64\x65tails\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"@\n\x0fGetStatsRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\"\xa8\x01\n\x10GetStatsResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x35\n\npool_stats\x18\x02 \x01(\x0b\x32!.isa.postgres.ConnectionPoolStats\x12-\n\x08\x64\x62_stats\x18\x03 \x01(\x0b\x32\x1b.isa.postgres.DatabaseStats\"\x95\x01\n\x13\x43onnectionPoolStats\x12\x17\n\x0fmax_connections\x18\x01 \x01(\x05\x12\x18\n\x10open_connections\x18\x02 \x01(\x05\x12\x18\n\x10idle_connections\x18\x03 \x01(\x05\x12\x1a\n\x12\x61\x63tive_connections\x18\x04 \x01(\x05\x12\x15\n\rtotal_queries\x18\x05 \x01(\x03\"\xa0\x01\n\rDatabaseStats\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x1b\n\x13\x64\x61tabase_size_bytes\x18\x02 \x01(\x03\x12\x14\n\x0ctotal_tables\x18\x03 \x01(\x05\x12\x19\n\x11total_connections\x18\x04 \x01(\x03\x12\x30\n\x0cuptime_since\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xc3\x0b\n\x0fPostgresService\x12@\n\x05Query\x12\x1a.isa.postgres.QueryRequest\x1a\x1b.isa.postgres.QueryResponse\x12I\n\x08QueryRow\x12\x1d.isa.postgres.QueryRowRequest\x1a\x1e.isa.postgres.QueryRowResponse\x12\x46\n\x07\x45xecute\x12\x1c.isa.postgres.ExecuteRequest\x1a\x1d.isa.postgres.ExecuteResponse\x12U\n\x0c\x45xecuteBatch\x12!.isa.postgres.ExecuteBatchRequest\x1a\".isa.postgres.ExecuteBatchResponse\x12O\n\nSelectFrom\x12\x1f.isa.postgres.SelectFromRequest\x1a .isa.postgres.SelectFromResponse\x12O\n\nInsertInto\x12\x1f.isa.postgres.InsertIntoRequest\x1a .isa.postgres.InsertIntoResponse\x12R\n\x0bUpdateTable\x12 .isa.postgres.UpdateTableRequest\x1a!.isa.postgres.UpdateTableResponse\x12O\n\nDeleteFrom\x12\x1f.isa.postgres.DeleteFromRequest\x1a .isa.postgres.DeleteFromResponse\x12\x61\n\x10\x42\x65ginTransaction\x12%.isa.postgres.BeginTransactionRequest\x1a&.isa.postgres.BeginTransactionResponse\x12\x64\n\x11\x43ommitTransaction\x12&.isa.postgres.CommitTransactionRequest\x1a\'.isa.postgres.CommitTransactionResponse\x12j\n\x13RollbackTransaction\x12(.isa.postgres.RollbackTransactionRequest\x1a).isa.postgres.RollbackTransactionResponse\x12m\n\x14\x45xecuteInTransaction\x12).isa.postgres.ExecuteInTransactionRequest\x1a*.isa.postgres.ExecuteInTransactionResponse\x12U\n\x0cGetTableInfo\x12!.isa.postgres.GetTableInfoRequest\x1a\".isa.postgres.GetTableInfoResponse\x12O\n\nListTables\x12\x1f.isa.postgres.ListTablesRequest\x1a .isa.postgres.ListTablesResponse\x12R\n\x0bTableExists\x12 .isa.postgres.TableExistsRequest\x1a!.isa.postgres.TableExistsResponse\x12R\n\x0bHealthCheck\x12 .isa.postgres.HealthCheckRequest\x1a!.isa.postgres.HealthCheckResponse\x12I\n\x08GetStats\x12\x1d.isa.postgres.GetStatsRequest\x1a\x1e.isa.postgres.GetStatsResponseB3Z1github.com/isa-cloud/isa_cloud/api/proto/postgresb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'postgres_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/isa-cloud/isa_cloud/api/proto/postgres'
  _globals['_QUERYREQUEST']._serialized_start=118
  _globals['_QUERYREQUEST']._serialized_end=248
  _globals['_QUERYRESPONSE']._serialized_start=250
  _globals['_QUERYRESPONSE']._serialized_end=371
  _globals['_QUERYROWREQUEST']._serialized_start=374
  _globals['_QUERYROWREQUEST']._serialized_end=507
  _globals['_QUERYROWRESPONSE']._serialized_start=509
  _globals['_QUERYROWRESPONSE']._serialized_end=628
  _globals['_EXECUTEREQUEST']._serialized_start=631
  _globals['_EXECUTEREQUEST']._serialized_end=763
  _globals['_EXECUTERESPONSE']._serialized_start=765
  _globals['_EXECUTERESPONSE']._serialized_end=874
  _globals['_EXECUTEBATCHREQUEST']._serialized_start=877
  _globals['_EXECUTEBATCHREQUEST']._serialized_end=1011
  _globals['_BATCHOPERATION']._serialized_start=1013
  _globals['_BATCHOPERATION']._serialized_end=1082
  _globals['_EXECUTEBATCHRESPONSE']._serialized_start=1085
  _globals['_EXECUTEBATCHRESPONSE']._serialized_end=1230
  _globals['_EXECUTERESULT']._serialized_start=1232
  _globals['_EXECUTERESULT']._serialized_end=1306
  _globals['_SELECTFROMREQUEST']._serialized_start=1309
  _globals['_SELECTFROMREQUEST']._serialized_end=1514
  _globals['_WHERECLAUSE']._serialized_start=1516
  _globals['_WHERECLAUSE']._serialized_end=1602
  _globals['_SELECTFROMRESPONSE']._serialized_start=1604
  _globals['_SELECTFROMRESPONSE']._serialized_end=1730
  _globals['_INSERTINTOREQUEST']._serialized_start=1733
  _globals['_INSERTINTOREQUEST']._serialized_end=1888
  _globals['_INSERTINTORESPONSE']._serialized_start=1891
  _globals['_INSERTINTORESPONSE']._serialized_end=2021
  _globals['_UPDATETABLEREQUEST']._serialized_start=2024
  _globals['_UPDATETABLEREQUEST']._serialized_end=2224
  _globals['_UPDATETABLERESPONSE']._serialized_start=2227
  _globals['_UPDATETABLERESPONSE']._serialized_end=2357
  _globals['_DELETEFROMREQUEST']._serialized_start=2360
  _globals['_DELETEFROMREQUEST']._serialized_end=2518
  _globals['_DELETEFROMRESPONSE']._serialized_start=2521
  _globals['_DELETEFROMRESPONSE']._serialized_end=2650
  _globals['_BEGINTRANSACTIONREQUEST']._serialized_start=2652
  _globals['_BEGINTRANSACTIONREQUEST']._serialized_end=2749
  _globals['_BEGINTRANSACTIONRESPONSE']._serialized_start=2751
  _globals['_BEGINTRANSACTIONRESPONSE']._serialized_end=2849
  _globals['_COMMITTRANSACTIONREQUEST']._serialized_start=2851
  _globals['_COMMITTRANSACTIONREQUEST']._serialized_end=2948
  _globals['_COMMITTRANSACTIONRESPONSE']._serialized_start=2950
  _globals['_COMMITTRANSACTIONRESPONSE']._serialized_end=3042
  _globals['_ROLLBACKTRANSACTIONREQUEST']._serialized_start=3044
  _globals['_ROLLBACKTRANSACTIONREQUEST']._serialized_end=3143
  _globals['_ROLLBACKTRANSACTIONRESPONSE']._serialized_start=3145
  _globals['_ROLLBACKTRANSACTIONRESPONSE']._serialized_end=3239
  _globals['_EXECUTEINTRANSACTIONREQUEST']._serialized_start=3242
  _globals['_EXECUTEINTRANSACTIONREQUEST']._serialized_end=3384
  _globals['_EXECUTEINTRANSACTIONRESPONSE']._serialized_start=3387
  _globals['_EXECUTEINTRANSACTIONRESPONSE']._serialized_end=3530
  _globals['_GETTABLEINFOREQUEST']._serialized_start=3532
  _globals['_GETTABLEINFOREQUEST']._serialized_end=3631
  _globals['_GETTABLEINFORESPONSE']._serialized_start=3633
  _globals['_GETTABLEINFORESPONSE']._serialized_end=3748
  _globals['_TABLEINFO']._serialized_start=3751
  _globals['_TABLEINFO']._serialized_end=3891
  _globals['_COLUMNINFO']._serialized_start=3893
  _globals['_COLUMNINFO']._serialized_end=3989
  _globals['_LISTTABLESREQUEST']._serialized_start=3991
  _globals['_LISTTABLESREQUEST']._serialized_end=4073
  _globals['_LISTTABLESRESPONSE']._serialized_start=4075
  _globals['_LISTTABLESRESPONSE']._serialized_end=4159
  _globals['_TABLEEXISTSREQUEST']._serialized_start=4161
  _globals['_TABLEEXISTSREQUEST']._serialized_end=4259
  _globals['_TABLEEXISTSRESPONSE']._serialized_start=4261
  _globals['_TABLEEXISTSRESPONSE']._serialized_end=4346
  _globals['_HEALTHCHECKREQUEST']._serialized_start=4348
  _globals['_HEALTHCHECKREQUEST']._serialized_end=4433
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=4436
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=4597
  _globals['_GETSTATSREQUEST']._serialized_start=4599
  _globals['_GETSTATSREQUEST']._serialized_end=4663
  _globals['_GETSTATSRESPONSE']._serialized_start=4666
  _globals['_GETSTATSRESPONSE']._serialized_end=4834
  _globals['_CONNECTIONPOOLSTATS']._serialized_start=4837
  _globals['_CONNECTIONPOOLSTATS']._serialized_end=4986
  _globals['_DATABASESTATS']._serialized_start=4989
  _globals['_DATABASESTATS']._serialized_end=5149
  _globals['_POSTGRESSERVICE']._serialized_start=5152
  _globals['_POSTGRESSERVICE']._serialized_end=6627
# @@protoc_insertion_point(module_scope)
