# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: duckdb_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'duckdb_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x64uckdb_service.proto\x12\nisa.duckdb\x1a\x0c\x63ommon.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x96\x03\n\x0c\x44\x61tabaseInfo\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x17\n\x0forganization_id\x18\x04 \x01(\t\x12\x14\n\x0cminio_bucket\x18\x05 \x01(\t\x12\x12\n\nminio_path\x18\x06 \x01(\t\x12\x12\n\nsize_bytes\x18\x07 \x01(\x03\x12\x13\n\x0btable_count\x18\x08 \x01(\x05\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rlast_accessed\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x08metadata\x18\x0b \x03(\x0b\x32&.isa.duckdb.DatabaseInfo.MetadataEntry\x12\x0f\n\x07version\x18\x0c \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd9\x01\n\tTableInfo\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x13\n\x0bschema_name\x18\x02 \x01(\t\x12\'\n\x07\x63olumns\x18\x03 \x03(\x0b\x32\x16.isa.duckdb.ColumnInfo\x12\x11\n\trow_count\x18\x04 \x01(\x03\x12\x12\n\nsize_bytes\x18\x05 \x01(\x03\x12\x12\n\ntable_type\x18\x06 \x01(\t\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x63omment\x18\x08 \x01(\t\"\x92\x01\n\nColumnInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdata_type\x18\x02 \x01(\t\x12\x10\n\x08nullable\x18\x03 \x01(\x08\x12\x15\n\rdefault_value\x18\x04 \x01(\t\x12\x16\n\x0eis_primary_key\x18\x05 \x01(\x08\x12\x11\n\tis_unique\x18\x06 \x01(\x08\x12\x0f\n\x07\x63omment\x18\x07 \x01(\t\"\xa4\x01\n\x10QueryResultChunk\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\x12\x14\n\x0c\x63olumn_types\x18\x03 \x03(\t\x12\x1d\n\x04rows\x18\x04 \x03(\x0b\x32\x0f.isa.duckdb.Row\x12\x0f\n\x07is_last\x18\x05 \x01(\x08\x12\x19\n\x11\x65xecution_time_ms\x18\x06 \x01(\x01\x12\r\n\x05\x65rror\x18\x07 \x01(\t\"(\n\x03Row\x12!\n\x06values\x18\x01 \x03(\x0b\x32\x11.isa.duckdb.Value\"\x97\x02\n\x05Value\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x03 \x01(\x01H\x00\x12\x14\n\nbool_value\x18\x04 \x01(\x08H\x00\x12\x15\n\x0b\x62ytes_value\x18\x05 \x01(\x0cH\x00\x12\x35\n\x0ftimestamp_value\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12/\n\x0cstruct_value\x18\x07 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12+\n\nnull_value\x18\x08 \x01(\x0e\x32\x15.isa.duckdb.NullValueH\x00\x42\x07\n\x05value\"v\n\nTableStats\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x11\n\trow_count\x18\x02 \x01(\x03\x12\x12\n\nsize_bytes\x18\x03 \x01(\x03\x12-\n\x0c\x63olumn_stats\x18\x04 \x03(\x0b\x32\x17.isa.duckdb.ColumnStats\"\x9a\x01\n\x0b\x43olumnStats\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x16\n\x0e\x64istinct_count\x18\x02 \x01(\x03\x12$\n\tmin_value\x18\x03 \x01(\x0b\x32\x11.isa.duckdb.Value\x12$\n\tmax_value\x18\x04 \x01(\x0b\x32\x11.isa.duckdb.Value\x12\x12\n\nnull_count\x18\x05 \x01(\x03\"\xd0\x02\n\x15\x43reateDatabaseRequest\x12\x15\n\rdatabase_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x17\n\x0forganization_id\x18\x03 \x01(\t\x12\x14\n\x0cminio_bucket\x18\x04 \x01(\t\x12\x41\n\x08metadata\x18\x05 \x03(\x0b\x32/.isa.duckdb.CreateDatabaseRequest.MetadataEntry\x12=\n\x06\x63onfig\x18\x06 \x03(\x0b\x32-.isa.duckdb.CreateDatabaseRequest.ConfigEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0b\x43onfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"z\n\x16\x43reateDatabaseResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12/\n\rdatabase_info\x18\x03 \x01(\x0b\x32\x18.isa.duckdb.DatabaseInfo\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"v\n\x14ListDatabasesRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x13\n\x0bname_filter\x18\x03 \x01(\t\x12\x0c\n\x04page\x18\x04 \x01(\x05\x12\x11\n\tpage_size\x18\x05 \x01(\x05\"\x9a\x01\n\x15ListDatabasesResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12+\n\tdatabases\x18\x02 \x03(\x0b\x32\x18.isa.duckdb.DatabaseInfo\x12\x13\n\x0btotal_count\x18\x03 \x01(\x05\x12\x0c\n\x04page\x18\x04 \x01(\x05\x12\x11\n\tpage_size\x18\x05 \x01(\x05\x12\r\n\x05\x65rror\x18\x06 \x01(\t\"g\n\x15\x44\x65leteDatabaseRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x19\n\x11\x64\x65lete_from_minio\x18\x03 \x01(\x08\x12\r\n\x05\x66orce\x18\x04 \x01(\x08\"I\n\x16\x44\x65leteDatabaseResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\">\n\x16GetDatabaseInfoRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"j\n\x17GetDatabaseInfoResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12/\n\rdatabase_info\x18\x02 \x01(\x0b\x32\x18.isa.duckdb.DatabaseInfo\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"g\n\x15\x42\x61\x63kupDatabaseRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x13\n\x0b\x62\x61\x63kup_name\x18\x03 \x01(\t\x12\x13\n\x0bincremental\x18\x04 \x01(\x08\"\xa4\x01\n\x16\x42\x61\x63kupDatabaseResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x13\n\x0b\x62\x61\x63kup_path\x18\x03 \x01(\t\x12\x13\n\x0b\x62\x61\x63kup_size\x18\x04 \x01(\x03\x12/\n\x0b\x62\x61\x63kup_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x65rror\x18\x06 \x01(\t\"Y\n\x16RestoreDatabaseRequest\x12\x13\n\x0b\x62\x61\x63kup_path\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x19\n\x11new_database_name\x18\x03 \x01(\t\"{\n\x17RestoreDatabaseResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12/\n\rdatabase_info\x18\x03 \x01(\x0b\x32\x18.isa.duckdb.DatabaseInfo\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"\x91\x02\n\x13\x45xecuteQueryRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\r\n\x05query\x18\x03 \x01(\t\x12\x43\n\nparameters\x18\x04 \x03(\x0b\x32/.isa.duckdb.ExecuteQueryRequest.ParametersEntry\x12\x10\n\x08max_rows\x18\x05 \x01(\x05\x12\x17\n\x0ftimeout_seconds\x18\x06 \x01(\x05\x12\x0f\n\x07\x65xplain\x18\x07 \x01(\x08\x1a\x44\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.isa.duckdb.Value:\x02\x38\x01\"\xbe\x01\n\x14\x45xecuteQueryResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\x12\x14\n\x0c\x63olumn_types\x18\x03 \x03(\t\x12\x1d\n\x04rows\x18\x04 \x03(\x0b\x32\x0f.isa.duckdb.Row\x12\x11\n\trow_count\x18\x05 \x01(\x05\x12\x19\n\x11\x65xecution_time_ms\x18\x06 \x01(\x01\x12\x12\n\nquery_plan\x18\x07 \x01(\t\x12\r\n\x05\x65rror\x18\x08 \x01(\t\"\xe1\x01\n\x17\x45xecuteStatementRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x11\n\tstatement\x18\x03 \x01(\t\x12G\n\nparameters\x18\x04 \x03(\x0b\x32\x33.isa.duckdb.ExecuteStatementRequest.ParametersEntry\x1a\x44\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.isa.duckdb.Value:\x02\x38\x01\"}\n\x18\x45xecuteStatementResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\raffected_rows\x18\x02 \x01(\x05\x12\x19\n\x11\x65xecution_time_ms\x18\x03 \x01(\x01\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\r\n\x05\x65rror\x18\x05 \x01(\t\"d\n\x13\x45xecuteBatchRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x12\n\nstatements\x18\x03 \x03(\t\x12\x13\n\x0btransaction\x18\x04 \x01(\x08\"\x81\x01\n\x14\x45xecuteBatchResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12(\n\x07results\x18\x02 \x03(\x0b\x32\x17.isa.duckdb.BatchResult\x12\x1f\n\x17total_execution_time_ms\x18\x03 \x01(\x01\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"D\n\x0b\x42\x61tchResult\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\raffected_rows\x18\x02 \x01(\x05\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"R\n\x17PrepareStatementRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x11\n\tstatement\x18\x03 \x01(\t\"i\n\x18PrepareStatementResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x14\n\x0cstatement_id\x18\x02 \x01(\t\x12\x17\n\x0fparameter_types\x18\x03 \x03(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"\xb5\x01\n\x12\x43reateTableRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12\'\n\x07\x63olumns\x18\x04 \x03(\x0b\x32\x16.isa.duckdb.ColumnInfo\x12\x14\n\x0cprimary_keys\x18\x05 \x03(\t\x12\x15\n\rif_not_exists\x18\x06 \x01(\x08\x12\x0f\n\x07\x63omment\x18\x07 \x01(\t\"q\n\x13\x43reateTableResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12)\n\ntable_info\x18\x03 \x01(\x0b\x32\x15.isa.duckdb.TableInfo\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"c\n\x11ListTablesRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x13\n\x0bschema_name\x18\x03 \x01(\t\x12\x13\n\x0bname_filter\x18\x04 \x01(\t\"p\n\x12ListTablesResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12%\n\x06tables\x18\x02 \x03(\x0b\x32\x15.isa.duckdb.TableInfo\x12\x13\n\x0btotal_count\x18\x03 \x01(\x05\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"p\n\x10\x44ropTableRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12\x11\n\tif_exists\x18\x04 \x01(\x08\x12\x0f\n\x07\x63\x61scade\x18\x05 \x01(\x08\"D\n\x11\x44ropTableResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"Q\n\x15GetTableSchemaRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x12\n\ntable_name\x18\x03 \x01(\t\"c\n\x16GetTableSchemaResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12)\n\ntable_info\x18\x02 \x01(\x0b\x32\x15.isa.duckdb.TableInfo\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"i\n\x14GetTableStatsRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12\x17\n\x0finclude_columns\x18\x04 \x01(\x08\"^\n\x15GetTableStatsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12%\n\x05stats\x18\x02 \x01(\x0b\x32\x16.isa.duckdb.TableStats\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"l\n\x11\x43reateViewRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x11\n\tview_name\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\x12\x0f\n\x07replace\x18\x05 \x01(\x08\"E\n\x12\x43reateViewResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"8\n\x10ListViewsRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"B\n\x11ListViewsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05views\x18\x02 \x03(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"J\n\x0f\x44ropViewRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x11\n\tview_name\x18\x03 \x01(\t\"C\n\x10\x44ropViewResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"\xa5\x02\n\x16ImportFromMinIORequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x04 \x01(\t\x12\x12\n\nobject_key\x18\x05 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x06 \x01(\t\x12\x14\n\x0c\x63reate_table\x18\x07 \x01(\x08\x12\x10\n\x08truncate\x18\x08 \x01(\x08\x12@\n\x07options\x18\t \x03(\x0b\x32/.isa.duckdb.ImportFromMinIORequest.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"|\n\x17ImportFromMinIOResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x15\n\rrows_imported\x18\x03 \x01(\x05\x12\x19\n\x11\x65xecution_time_ms\x18\x04 \x01(\x01\x12\r\n\x05\x65rror\x18\x05 \x01(\t\"\x87\x02\n\x14\x45xportToMinIORequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\r\n\x05query\x18\x03 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x04 \x01(\t\x12\x12\n\nobject_key\x18\x05 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x06 \x01(\t\x12>\n\x07options\x18\x07 \x03(\x0b\x32-.isa.duckdb.ExportToMinIORequest.OptionsEntry\x12\x11\n\toverwrite\x18\x08 \x01(\x08\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x01\n\x15\x45xportToMinIOResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x15\n\rrows_exported\x18\x03 \x01(\x05\x12\x11\n\tfile_size\x18\x04 \x01(\x03\x12\x19\n\x11\x65xecution_time_ms\x18\x05 \x01(\x01\x12\r\n\x05\x65rror\x18\x06 \x01(\t\"\xf6\x01\n\x15QueryMinIOFileRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x03 \x01(\t\x12\x12\n\nobject_key\x18\x04 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x05 \x01(\t\x12\r\n\x05query\x18\x06 \x01(\t\x12?\n\x07options\x18\x07 \x03(\x0b\x32..isa.duckdb.QueryMinIOFileRequest.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x96\x01\n\x16QueryMinIOFileResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\x12\x1d\n\x04rows\x18\x03 \x03(\x0b\x32\x0f.isa.duckdb.Row\x12\x11\n\trow_count\x18\x04 \x01(\x05\x12\x19\n\x11\x65xecution_time_ms\x18\x05 \x01(\x01\x12\r\n\x05\x65rror\x18\x06 \x01(\t\"`\n\x11ImportDataRequest\x12\x32\n\x08metadata\x18\x01 \x01(\x0b\x32\x1e.isa.duckdb.ImportDataMetadataH\x00\x12\x0f\n\x05\x63hunk\x18\x02 \x01(\x0cH\x00\x42\x06\n\x04\x64\x61ta\"\xe0\x01\n\x12ImportDataMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x04 \x01(\t\x12\x12\n\ntotal_size\x18\x05 \x01(\x03\x12<\n\x07options\x18\x06 \x03(\x0b\x32+.isa.duckdb.ImportDataMetadata.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"w\n\x12ImportDataResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x15\n\rrows_imported\x18\x03 \x01(\x05\x12\x19\n\x11\x65xecution_time_ms\x18\x04 \x01(\x01\x12\r\n\x05\x65rror\x18\x05 \x01(\t\"W\n\x17InstallExtensionRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x16\n\x0e\x65xtension_name\x18\x03 \x01(\t\"K\n\x18InstallExtensionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"=\n\x15ListExtensionsRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"g\n\x16ListExtensionsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12-\n\nextensions\x18\x02 \x03(\x0b\x32\x19.isa.duckdb.ExtensionInfo\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"f\n\rExtensionInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x11\n\tinstalled\x18\x03 \x01(\x08\x12\x0e\n\x06loaded\x18\x04 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"\x94\x01\n\x15\x43reateFunctionRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x15\n\rfunction_name\x18\x03 \x01(\t\x12\x15\n\rfunction_body\x18\x04 \x01(\t\x12\x12\n\nparameters\x18\x05 \x03(\t\x12\x13\n\x0breturn_type\x18\x06 \x01(\t\"I\n\x16\x43reateFunctionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\";\n\x12HealthCheckRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x10\n\x08\x64\x65tailed\x18\x02 \x01(\x08\"\xaf\x01\n\x13HealthCheckResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07healthy\x18\x02 \x01(\x08\x12\x0e\n\x06status\x18\x03 \x01(\t\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x07\x64\x65tails\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05\x65rror\x18\x06 \x01(\t\"(\n\x11GetMetricsRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\"\xd6\x01\n\x12GetMetricsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rtotal_queries\x18\x02 \x01(\x03\x12\x1a\n\x12\x61\x63tive_connections\x18\x03 \x01(\x03\x12\x19\n\x11\x61vg_query_time_ms\x18\x04 \x01(\x01\x12\x12\n\ncache_hits\x18\x05 \x01(\x03\x12\x14\n\x0c\x63\x61\x63he_misses\x18\x06 \x01(\x03\x12(\n\x07metrics\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05\x65rror\x18\x08 \x01(\t*\x1b\n\tNullValue\x12\x0e\n\nNULL_VALUE\x10\x00\x32\xdf\x12\n\rDuckDBService\x12W\n\x0e\x43reateDatabase\x12!.isa.duckdb.CreateDatabaseRequest\x1a\".isa.duckdb.CreateDatabaseResponse\x12T\n\rListDatabases\x12 .isa.duckdb.ListDatabasesRequest\x1a!.isa.duckdb.ListDatabasesResponse\x12W\n\x0e\x44\x65leteDatabase\x12!.isa.duckdb.DeleteDatabaseRequest\x1a\".isa.duckdb.DeleteDatabaseResponse\x12Z\n\x0fGetDatabaseInfo\x12\".isa.duckdb.GetDatabaseInfoRequest\x1a#.isa.duckdb.GetDatabaseInfoResponse\x12W\n\x0e\x42\x61\x63kupDatabase\x12!.isa.duckdb.BackupDatabaseRequest\x1a\".isa.duckdb.BackupDatabaseResponse\x12Z\n\x0fRestoreDatabase\x12\".isa.duckdb.RestoreDatabaseRequest\x1a#.isa.duckdb.RestoreDatabaseResponse\x12Q\n\x0c\x45xecuteQuery\x12\x1f.isa.duckdb.ExecuteQueryRequest\x1a .isa.duckdb.ExecuteQueryResponse\x12U\n\x12\x45xecuteQueryStream\x12\x1f.isa.duckdb.ExecuteQueryRequest\x1a\x1c.isa.duckdb.QueryResultChunk0\x01\x12]\n\x10\x45xecuteStatement\x12#.isa.duckdb.ExecuteStatementRequest\x1a$.isa.duckdb.ExecuteStatementResponse\x12Q\n\x0c\x45xecuteBatch\x12\x1f.isa.duckdb.ExecuteBatchRequest\x1a .isa.duckdb.ExecuteBatchResponse\x12]\n\x10PrepareStatement\x12#.isa.duckdb.PrepareStatementRequest\x1a$.isa.duckdb.PrepareStatementResponse\x12N\n\x0b\x43reateTable\x12\x1e.isa.duckdb.CreateTableRequest\x1a\x1f.isa.duckdb.CreateTableResponse\x12K\n\nListTables\x12\x1d.isa.duckdb.ListTablesRequest\x1a\x1e.isa.duckdb.ListTablesResponse\x12H\n\tDropTable\x12\x1c.isa.duckdb.DropTableRequest\x1a\x1d.isa.duckdb.DropTableResponse\x12W\n\x0eGetTableSchema\x12!.isa.duckdb.GetTableSchemaRequest\x1a\".isa.duckdb.GetTableSchemaResponse\x12T\n\rGetTableStats\x12 .isa.duckdb.GetTableStatsRequest\x1a!.isa.duckdb.GetTableStatsResponse\x12K\n\nCreateView\x12\x1d.isa.duckdb.CreateViewRequest\x1a\x1e.isa.duckdb.CreateViewResponse\x12H\n\tListViews\x12\x1c.isa.duckdb.ListViewsRequest\x1a\x1d.isa.duckdb.ListViewsResponse\x12\x45\n\x08\x44ropView\x12\x1b.isa.duckdb.DropViewRequest\x1a\x1c.isa.duckdb.DropViewResponse\x12Z\n\x0fImportFromMinIO\x12\".isa.duckdb.ImportFromMinIORequest\x1a#.isa.duckdb.ImportFromMinIOResponse\x12T\n\rExportToMinIO\x12 .isa.duckdb.ExportToMinIORequest\x1a!.isa.duckdb.ExportToMinIOResponse\x12W\n\x0eQueryMinIOFile\x12!.isa.duckdb.QueryMinIOFileRequest\x1a\".isa.duckdb.QueryMinIOFileResponse\x12M\n\nImportData\x12\x1d.isa.duckdb.ImportDataRequest\x1a\x1e.isa.duckdb.ImportDataResponse(\x01\x12]\n\x10InstallExtension\x12#.isa.duckdb.InstallExtensionRequest\x1a$.isa.duckdb.InstallExtensionResponse\x12W\n\x0eListExtensions\x12!.isa.duckdb.ListExtensionsRequest\x1a\".isa.duckdb.ListExtensionsResponse\x12W\n\x0e\x43reateFunction\x12!.isa.duckdb.CreateFunctionRequest\x1a\".isa.duckdb.CreateFunctionResponse\x12N\n\x0bHealthCheck\x12\x1e.isa.duckdb.HealthCheckRequest\x1a\x1f.isa.duckdb.HealthCheckResponse\x12K\n\nGetMetrics\x12\x1d.isa.duckdb.GetMetricsRequest\x1a\x1e.isa.duckdb.GetMetricsResponseB1Z/github.com/isa-cloud/isa_cloud/api/proto/duckdbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'duckdb_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/isa-cloud/isa_cloud/api/proto/duckdb'
  _globals['_DATABASEINFO_METADATAENTRY']._loaded_options = None
  _globals['_DATABASEINFO_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CREATEDATABASEREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_CREATEDATABASEREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CREATEDATABASEREQUEST_CONFIGENTRY']._loaded_options = None
  _globals['_CREATEDATABASEREQUEST_CONFIGENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTEQUERYREQUEST_PARAMETERSENTRY']._loaded_options = None
  _globals['_EXECUTEQUERYREQUEST_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTESTATEMENTREQUEST_PARAMETERSENTRY']._loaded_options = None
  _globals['_EXECUTESTATEMENTREQUEST_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_IMPORTFROMMINIOREQUEST_OPTIONSENTRY']._loaded_options = None
  _globals['_IMPORTFROMMINIOREQUEST_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_EXPORTTOMINIOREQUEST_OPTIONSENTRY']._loaded_options = None
  _globals['_EXPORTTOMINIOREQUEST_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_QUERYMINIOFILEREQUEST_OPTIONSENTRY']._loaded_options = None
  _globals['_QUERYMINIOFILEREQUEST_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_IMPORTDATAMETADATA_OPTIONSENTRY']._loaded_options = None
  _globals['_IMPORTDATAMETADATA_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_NULLVALUE']._serialized_start=8937
  _globals['_NULLVALUE']._serialized_end=8964
  _globals['_DATABASEINFO']._serialized_start=114
  _globals['_DATABASEINFO']._serialized_end=520
  _globals['_DATABASEINFO_METADATAENTRY']._serialized_start=473
  _globals['_DATABASEINFO_METADATAENTRY']._serialized_end=520
  _globals['_TABLEINFO']._serialized_start=523
  _globals['_TABLEINFO']._serialized_end=740
  _globals['_COLUMNINFO']._serialized_start=743
  _globals['_COLUMNINFO']._serialized_end=889
  _globals['_QUERYRESULTCHUNK']._serialized_start=892
  _globals['_QUERYRESULTCHUNK']._serialized_end=1056
  _globals['_ROW']._serialized_start=1058
  _globals['_ROW']._serialized_end=1098
  _globals['_VALUE']._serialized_start=1101
  _globals['_VALUE']._serialized_end=1380
  _globals['_TABLESTATS']._serialized_start=1382
  _globals['_TABLESTATS']._serialized_end=1500
  _globals['_COLUMNSTATS']._serialized_start=1503
  _globals['_COLUMNSTATS']._serialized_end=1657
  _globals['_CREATEDATABASEREQUEST']._serialized_start=1660
  _globals['_CREATEDATABASEREQUEST']._serialized_end=1996
  _globals['_CREATEDATABASEREQUEST_METADATAENTRY']._serialized_start=473
  _globals['_CREATEDATABASEREQUEST_METADATAENTRY']._serialized_end=520
  _globals['_CREATEDATABASEREQUEST_CONFIGENTRY']._serialized_start=1951
  _globals['_CREATEDATABASEREQUEST_CONFIGENTRY']._serialized_end=1996
  _globals['_CREATEDATABASERESPONSE']._serialized_start=1998
  _globals['_CREATEDATABASERESPONSE']._serialized_end=2120
  _globals['_LISTDATABASESREQUEST']._serialized_start=2122
  _globals['_LISTDATABASESREQUEST']._serialized_end=2240
  _globals['_LISTDATABASESRESPONSE']._serialized_start=2243
  _globals['_LISTDATABASESRESPONSE']._serialized_end=2397
  _globals['_DELETEDATABASEREQUEST']._serialized_start=2399
  _globals['_DELETEDATABASEREQUEST']._serialized_end=2502
  _globals['_DELETEDATABASERESPONSE']._serialized_start=2504
  _globals['_DELETEDATABASERESPONSE']._serialized_end=2577
  _globals['_GETDATABASEINFOREQUEST']._serialized_start=2579
  _globals['_GETDATABASEINFOREQUEST']._serialized_end=2641
  _globals['_GETDATABASEINFORESPONSE']._serialized_start=2643
  _globals['_GETDATABASEINFORESPONSE']._serialized_end=2749
  _globals['_BACKUPDATABASEREQUEST']._serialized_start=2751
  _globals['_BACKUPDATABASEREQUEST']._serialized_end=2854
  _globals['_BACKUPDATABASERESPONSE']._serialized_start=2857
  _globals['_BACKUPDATABASERESPONSE']._serialized_end=3021
  _globals['_RESTOREDATABASEREQUEST']._serialized_start=3023
  _globals['_RESTOREDATABASEREQUEST']._serialized_end=3112
  _globals['_RESTOREDATABASERESPONSE']._serialized_start=3114
  _globals['_RESTOREDATABASERESPONSE']._serialized_end=3237
  _globals['_EXECUTEQUERYREQUEST']._serialized_start=3240
  _globals['_EXECUTEQUERYREQUEST']._serialized_end=3513
  _globals['_EXECUTEQUERYREQUEST_PARAMETERSENTRY']._serialized_start=3445
  _globals['_EXECUTEQUERYREQUEST_PARAMETERSENTRY']._serialized_end=3513
  _globals['_EXECUTEQUERYRESPONSE']._serialized_start=3516
  _globals['_EXECUTEQUERYRESPONSE']._serialized_end=3706
  _globals['_EXECUTESTATEMENTREQUEST']._serialized_start=3709
  _globals['_EXECUTESTATEMENTREQUEST']._serialized_end=3934
  _globals['_EXECUTESTATEMENTREQUEST_PARAMETERSENTRY']._serialized_start=3445
  _globals['_EXECUTESTATEMENTREQUEST_PARAMETERSENTRY']._serialized_end=3513
  _globals['_EXECUTESTATEMENTRESPONSE']._serialized_start=3936
  _globals['_EXECUTESTATEMENTRESPONSE']._serialized_end=4061
  _globals['_EXECUTEBATCHREQUEST']._serialized_start=4063
  _globals['_EXECUTEBATCHREQUEST']._serialized_end=4163
  _globals['_EXECUTEBATCHRESPONSE']._serialized_start=4166
  _globals['_EXECUTEBATCHRESPONSE']._serialized_end=4295
  _globals['_BATCHRESULT']._serialized_start=4297
  _globals['_BATCHRESULT']._serialized_end=4365
  _globals['_PREPARESTATEMENTREQUEST']._serialized_start=4367
  _globals['_PREPARESTATEMENTREQUEST']._serialized_end=4449
  _globals['_PREPARESTATEMENTRESPONSE']._serialized_start=4451
  _globals['_PREPARESTATEMENTRESPONSE']._serialized_end=4556
  _globals['_CREATETABLEREQUEST']._serialized_start=4559
  _globals['_CREATETABLEREQUEST']._serialized_end=4740
  _globals['_CREATETABLERESPONSE']._serialized_start=4742
  _globals['_CREATETABLERESPONSE']._serialized_end=4855
  _globals['_LISTTABLESREQUEST']._serialized_start=4857
  _globals['_LISTTABLESREQUEST']._serialized_end=4956
  _globals['_LISTTABLESRESPONSE']._serialized_start=4958
  _globals['_LISTTABLESRESPONSE']._serialized_end=5070
  _globals['_DROPTABLEREQUEST']._serialized_start=5072
  _globals['_DROPTABLEREQUEST']._serialized_end=5184
  _globals['_DROPTABLERESPONSE']._serialized_start=5186
  _globals['_DROPTABLERESPONSE']._serialized_end=5254
  _globals['_GETTABLESCHEMAREQUEST']._serialized_start=5256
  _globals['_GETTABLESCHEMAREQUEST']._serialized_end=5337
  _globals['_GETTABLESCHEMARESPONSE']._serialized_start=5339
  _globals['_GETTABLESCHEMARESPONSE']._serialized_end=5438
  _globals['_GETTABLESTATSREQUEST']._serialized_start=5440
  _globals['_GETTABLESTATSREQUEST']._serialized_end=5545
  _globals['_GETTABLESTATSRESPONSE']._serialized_start=5547
  _globals['_GETTABLESTATSRESPONSE']._serialized_end=5641
  _globals['_CREATEVIEWREQUEST']._serialized_start=5643
  _globals['_CREATEVIEWREQUEST']._serialized_end=5751
  _globals['_CREATEVIEWRESPONSE']._serialized_start=5753
  _globals['_CREATEVIEWRESPONSE']._serialized_end=5822
  _globals['_LISTVIEWSREQUEST']._serialized_start=5824
  _globals['_LISTVIEWSREQUEST']._serialized_end=5880
  _globals['_LISTVIEWSRESPONSE']._serialized_start=5882
  _globals['_LISTVIEWSRESPONSE']._serialized_end=5948
  _globals['_DROPVIEWREQUEST']._serialized_start=5950
  _globals['_DROPVIEWREQUEST']._serialized_end=6024
  _globals['_DROPVIEWRESPONSE']._serialized_start=6026
  _globals['_DROPVIEWRESPONSE']._serialized_end=6093
  _globals['_IMPORTFROMMINIOREQUEST']._serialized_start=6096
  _globals['_IMPORTFROMMINIOREQUEST']._serialized_end=6389
  _globals['_IMPORTFROMMINIOREQUEST_OPTIONSENTRY']._serialized_start=6343
  _globals['_IMPORTFROMMINIOREQUEST_OPTIONSENTRY']._serialized_end=6389
  _globals['_IMPORTFROMMINIORESPONSE']._serialized_start=6391
  _globals['_IMPORTFROMMINIORESPONSE']._serialized_end=6515
  _globals['_EXPORTTOMINIOREQUEST']._serialized_start=6518
  _globals['_EXPORTTOMINIOREQUEST']._serialized_end=6781
  _globals['_EXPORTTOMINIOREQUEST_OPTIONSENTRY']._serialized_start=6343
  _globals['_EXPORTTOMINIOREQUEST_OPTIONSENTRY']._serialized_end=6389
  _globals['_EXPORTTOMINIORESPONSE']._serialized_start=6784
  _globals['_EXPORTTOMINIORESPONSE']._serialized_end=6925
  _globals['_QUERYMINIOFILEREQUEST']._serialized_start=6928
  _globals['_QUERYMINIOFILEREQUEST']._serialized_end=7174
  _globals['_QUERYMINIOFILEREQUEST_OPTIONSENTRY']._serialized_start=6343
  _globals['_QUERYMINIOFILEREQUEST_OPTIONSENTRY']._serialized_end=6389
  _globals['_QUERYMINIOFILERESPONSE']._serialized_start=7177
  _globals['_QUERYMINIOFILERESPONSE']._serialized_end=7327
  _globals['_IMPORTDATAREQUEST']._serialized_start=7329
  _globals['_IMPORTDATAREQUEST']._serialized_end=7425
  _globals['_IMPORTDATAMETADATA']._serialized_start=7428
  _globals['_IMPORTDATAMETADATA']._serialized_end=7652
  _globals['_IMPORTDATAMETADATA_OPTIONSENTRY']._serialized_start=6343
  _globals['_IMPORTDATAMETADATA_OPTIONSENTRY']._serialized_end=6389
  _globals['_IMPORTDATARESPONSE']._serialized_start=7654
  _globals['_IMPORTDATARESPONSE']._serialized_end=7773
  _globals['_INSTALLEXTENSIONREQUEST']._serialized_start=7775
  _globals['_INSTALLEXTENSIONREQUEST']._serialized_end=7862
  _globals['_INSTALLEXTENSIONRESPONSE']._serialized_start=7864
  _globals['_INSTALLEXTENSIONRESPONSE']._serialized_end=7939
  _globals['_LISTEXTENSIONSREQUEST']._serialized_start=7941
  _globals['_LISTEXTENSIONSREQUEST']._serialized_end=8002
  _globals['_LISTEXTENSIONSRESPONSE']._serialized_start=8004
  _globals['_LISTEXTENSIONSRESPONSE']._serialized_end=8107
  _globals['_EXTENSIONINFO']._serialized_start=8109
  _globals['_EXTENSIONINFO']._serialized_end=8211
  _globals['_CREATEFUNCTIONREQUEST']._serialized_start=8214
  _globals['_CREATEFUNCTIONREQUEST']._serialized_end=8362
  _globals['_CREATEFUNCTIONRESPONSE']._serialized_start=8364
  _globals['_CREATEFUNCTIONRESPONSE']._serialized_end=8437
  _globals['_HEALTHCHECKREQUEST']._serialized_start=8439
  _globals['_HEALTHCHECKREQUEST']._serialized_end=8498
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=8501
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=8676
  _globals['_GETMETRICSREQUEST']._serialized_start=8678
  _globals['_GETMETRICSREQUEST']._serialized_end=8718
  _globals['_GETMETRICSRESPONSE']._serialized_start=8721
  _globals['_GETMETRICSRESPONSE']._serialized_end=8935
  _globals['_DUCKDBSERVICE']._serialized_start=8967
  _globals['_DUCKDBSERVICE']._serialized_end=11366
# @@protoc_insertion_point(module_scope)
