# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: minio_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'minio_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13minio_service.proto\x12\tisa.minio\x1a\x0c\x63ommon.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x8e\x02\n\nBucketInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x31\n\rcreation_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08owner_id\x18\x03 \x01(\t\x12\x17\n\x0forganization_id\x18\x04 \x01(\t\x12-\n\x04tags\x18\x05 \x03(\x0b\x32\x1f.isa.minio.BucketInfo.TagsEntry\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x12\n\nsize_bytes\x18\x07 \x01(\x03\x12\x14\n\x0cobject_count\x18\x08 \x01(\x03\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x02\n\nObjectInfo\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x03\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x04 \x01(\t\x12\x31\n\rlast_modified\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x08metadata\x18\x06 \x03(\x0b\x32#.isa.minio.ObjectInfo.MetadataEntry\x12\x15\n\rstorage_class\x18\x07 \x01(\t\x12\x12\n\nversion_id\x18\x08 \x01(\t\x12\x10\n\x08owner_id\x18\t \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe1\x01\n\x13\x43reateBucketRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x17\n\x0forganization_id\x18\x03 \x01(\t\x12\x0e\n\x06region\x18\x04 \x01(\t\x12\x16\n\x0eobject_locking\x18\x05 \x01(\x08\x12\x36\n\x04tags\x18\x06 \x03(\x0b\x32(.isa.minio.CreateBucketRequest.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"s\n\x14\x43reateBucketResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12*\n\x0b\x62ucket_info\x18\x03 \x01(\x0b\x32\x15.isa.minio.BucketInfo\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"N\n\x12ListBucketsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0e\n\x06prefix\x18\x03 \x01(\t\"r\n\x13ListBucketsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12&\n\x07\x62uckets\x18\x02 \x03(\x0b\x32\x15.isa.minio.BucketInfo\x12\x13\n\x0btotal_count\x18\x03 \x01(\x05\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"J\n\x13\x44\x65leteBucketRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\"`\n\x14\x44\x65leteBucketResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x65leted_objects\x18\x03 \x01(\x05\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"<\n\x14GetBucketInfoRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"c\n\x15GetBucketInfoResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12*\n\x0b\x62ucket_info\x18\x02 \x01(\x0b\x32\x15.isa.minio.BucketInfo\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"\x87\x01\n\x16SetBucketPolicyRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x30\n\x0bpolicy_type\x18\x03 \x01(\x0e\x32\x1b.isa.minio.BucketPolicyType\x12\x15\n\rcustom_policy\x18\x04 \x01(\t\"J\n\x17SetBucketPolicyResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\">\n\x16GetBucketPolicyRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"\x80\x01\n\x17GetBucketPolicyResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x30\n\x0bpolicy_type\x18\x02 \x01(\x0e\x32\x1b.isa.minio.BucketPolicyType\x12\x13\n\x0bpolicy_json\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"\xa2\x01\n\x14SetBucketTagsRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x37\n\x04tags\x18\x03 \x03(\x0b\x32).isa.minio.SetBucketTagsRequest.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x15SetBucketTagsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"<\n\x14GetBucketTagsRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"\x9e\x01\n\x15GetBucketTagsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x38\n\x04tags\x18\x02 \x03(\x0b\x32*.isa.minio.GetBucketTagsResponse.TagsEntry\x12\r\n\x05\x65rror\x18\x03 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\x17\x44\x65leteBucketTagsRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"K\n\x18\x44\x65leteBucketTagsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"S\n\x1aSetBucketVersioningRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"N\n\x1bSetBucketVersioningResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"B\n\x1aGetBucketVersioningRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"N\n\x1bGetBucketVersioningResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"\xae\x01\n\rLifecycleRule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\'\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\nexpiration\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\ntransition\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"j\n\x19SetBucketLifecycleRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\'\n\x05rules\x18\x03 \x03(\x0b\x32\x18.isa.minio.LifecycleRule\"M\n\x1aSetBucketLifecycleResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"A\n\x19GetBucketLifecycleRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"e\n\x1aGetBucketLifecycleResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\'\n\x05rules\x18\x02 \x03(\x0b\x32\x18.isa.minio.LifecycleRule\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"D\n\x1c\x44\x65leteBucketLifecycleRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"P\n\x1d\x44\x65leteBucketLifecycleResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"]\n\x10PutObjectRequest\x12\x30\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.minio.PutObjectMetadataH\x00\x12\x0f\n\x05\x63hunk\x18\x02 \x01(\x0cH\x00\x42\x06\n\x04\x64\x61ta\"\x81\x02\n\x11PutObjectMetadata\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x12\n\nobject_key\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x04 \x01(\t\x12\x16\n\x0e\x63ontent_length\x18\x05 \x01(\x03\x12<\n\x08metadata\x18\x06 \x03(\x0b\x32*.isa.minio.PutObjectMetadata.MetadataEntry\x12\x15\n\rstorage_class\x18\x07 \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"w\n\x11PutObjectResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x12\n\nobject_key\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\x12\n\nversion_id\x18\x04 \x01(\t\x12\x0c\n\x04size\x18\x05 \x01(\x03\x12\r\n\x05\x65rror\x18\x06 \x01(\t\"\x80\x01\n\x10GetObjectRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x12\n\nobject_key\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x0e\n\x06offset\x18\x04 \x01(\x03\x12\x0e\n\x06length\x18\x05 \x01(\x03\x12\x12\n\nversion_id\x18\x06 \x01(\t\"W\n\x11GetObjectResponse\x12)\n\x08metadata\x18\x01 \x01(\x0b\x32\x15.isa.minio.ObjectInfoH\x00\x12\x0f\n\x05\x63hunk\x18\x02 \x01(\x0cH\x00\x42\x06\n\x04\x64\x61ta\"c\n\x13\x44\x65leteObjectRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x12\n\nobject_key\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x12\n\nversion_id\x18\x04 \x01(\t\"G\n\x14\x44\x65leteObjectResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"`\n\x14\x44\x65leteObjectsRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x13\n\x0bobject_keys\x18\x03 \x03(\t\x12\r\n\x05quiet\x18\x04 \x01(\x08\"u\n\x15\x44\x65leteObjectsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x14\n\x0c\x64\x65leted_keys\x18\x02 \x03(\t\x12&\n\x06\x65rrors\x18\x03 \x03(\x0b\x32\x16.isa.minio.DeleteError\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"E\n\x0b\x44\x65leteError\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nerror_code\x18\x02 \x01(\t\x12\x15\n\rerror_message\x18\x03 \x01(\t\"\xb3\x01\n\x12ListObjectsRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0e\n\x06prefix\x18\x03 \x01(\t\x12\x11\n\tdelimiter\x18\x04 \x01(\t\x12\x10\n\x08max_keys\x18\x05 \x01(\x05\x12\x13\n\x0bstart_after\x18\x06 \x01(\t\x12\x1a\n\x12\x63ontinuation_token\x18\x07 \x01(\t\x12\x11\n\trecursive\x18\x08 \x01(\x08\"\xad\x01\n\x13ListObjectsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12&\n\x07objects\x18\x02 \x03(\x0b\x32\x15.isa.minio.ObjectInfo\x12\x17\n\x0f\x63ommon_prefixes\x18\x03 \x03(\t\x12\x1f\n\x17next_continuation_token\x18\x04 \x01(\t\x12\x14\n\x0cis_truncated\x18\x05 \x01(\x08\x12\r\n\x05\x65rror\x18\x06 \x01(\t\"\x81\x02\n\x11\x43opyObjectRequest\x12\x15\n\rsource_bucket\x18\x01 \x01(\t\x12\x12\n\nsource_key\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65st_bucket\x18\x03 \x01(\t\x12\x10\n\x08\x64\x65st_key\x18\x04 \x01(\t\x12\x0f\n\x07user_id\x18\x05 \x01(\t\x12<\n\x08metadata\x18\x06 \x03(\x0b\x32*.isa.minio.CopyObjectRequest.MetadataEntry\x12\x1a\n\x12metadata_directive\x18\x07 \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x01\n\x12\x43opyObjectResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\x31\n\rlast_modified\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x65rror\x18\x05 \x01(\t\"a\n\x11StatObjectRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x12\n\nobject_key\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x12\n\nversion_id\x18\x04 \x01(\t\"`\n\x12StatObjectResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12*\n\x0bobject_info\x18\x02 \x01(\x0b\x32\x15.isa.minio.ObjectInfo\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"\xca\x01\n\x14SetObjectTagsRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x12\n\nobject_key\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x37\n\x04tags\x18\x04 \x03(\x0b\x32).isa.minio.SetObjectTagsRequest.TagsEntry\x12\x12\n\nversion_id\x18\x05 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x15SetObjectTagsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"d\n\x14GetObjectTagsRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x12\n\nobject_key\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x12\n\nversion_id\x18\x04 \x01(\t\"\x9e\x01\n\x15GetObjectTagsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x38\n\x04tags\x18\x02 \x03(\x0b\x32*.isa.minio.GetObjectTagsResponse.TagsEntry\x12\r\n\x05\x65rror\x18\x03 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"g\n\x17\x44\x65leteObjectTagsRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x12\n\nobject_key\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x12\n\nversion_id\x18\x04 \x01(\t\"K\n\x18\x44\x65leteObjectTagsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"\xee\x01\n\x16GetPresignedURLRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x12\n\nobject_key\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x16\n\x0e\x65xpiry_seconds\x18\x04 \x01(\x05\x12L\n\x0erequest_params\x18\x05 \x03(\x0b\x32\x34.isa.minio.GetPresignedURLRequest.RequestParamsEntry\x1a\x34\n\x12RequestParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"v\n\x17GetPresignedURLResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0b\n\x03url\x18\x02 \x01(\t\x12.\n\nexpires_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"\x83\x01\n\x19GetPresignedPutURLRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x12\n\nobject_key\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x16\n\x0e\x65xpiry_seconds\x18\x04 \x01(\x05\x12\x14\n\x0c\x63ontent_type\x18\x05 \x01(\t\"y\n\x1aGetPresignedPutURLResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0b\n\x03url\x18\x02 \x01(\t\x12.\n\nexpires_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"\xec\x01\n\x1eInitiateMultipartUploadRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x12\n\nobject_key\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x04 \x01(\t\x12I\n\x08metadata\x18\x05 \x03(\x0b\x32\x37.isa.minio.InitiateMultipartUploadRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"}\n\x1fInitiateMultipartUploadResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x11\n\tupload_id\x18\x02 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x03 \x01(\t\x12\x12\n\nobject_key\x18\x04 \x01(\t\x12\r\n\x05\x65rror\x18\x05 \x01(\t\"_\n\x11UploadPartRequest\x12\x31\n\x08metadata\x18\x01 \x01(\x0b\x32\x1d.isa.minio.UploadPartMetadataH\x00\x12\x0f\n\x05\x63hunk\x18\x02 \x01(\x0cH\x00\x42\x06\n\x04\x64\x61ta\"\x89\x01\n\x12UploadPartMetadata\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x12\n\nobject_key\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x11\n\tupload_id\x18\x04 \x01(\t\x12\x13\n\x0bpart_number\x18\x05 \x01(\x05\x12\x11\n\tpart_size\x18\x06 \x01(\x03\"W\n\x12UploadPartResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x13\n\x0bpart_number\x18\x02 \x01(\x05\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"2\n\rCompletedPart\x12\x13\n\x0bpart_number\x18\x01 \x01(\x05\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\"\x96\x01\n\x1e\x43ompleteMultipartUploadRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x12\n\nobject_key\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x11\n\tupload_id\x18\x04 \x01(\t\x12\'\n\x05parts\x18\x05 \x03(\x0b\x32\x18.isa.minio.CompletedPart\"u\n\x1f\x43ompleteMultipartUploadResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x12\n\nobject_key\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\r\n\x05\x65rror\x18\x05 \x01(\t\"j\n\x1b\x41\x62ortMultipartUploadRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x12\n\nobject_key\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x11\n\tupload_id\x18\x04 \x01(\t\"O\n\x1c\x41\x62ortMultipartUploadResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"+\n\x17MinIOHealthCheckRequest\x12\x10\n\x08\x64\x65tailed\x18\x01 \x01(\x08\"\xb4\x01\n\x18MinIOHealthCheckResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07healthy\x18\x02 \x01(\x08\x12\x0e\n\x06status\x18\x03 \x01(\t\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x07\x64\x65tails\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05\x65rror\x18\x06 \x01(\t*\xa3\x01\n\x10\x42ucketPolicyType\x12\x19\n\x15\x42UCKET_POLICY_PRIVATE\x10\x00\x12\x1d\n\x19\x42UCKET_POLICY_PUBLIC_READ\x10\x01\x12\x1e\n\x1a\x42UCKET_POLICY_PUBLIC_WRITE\x10\x02\x12\x1b\n\x17\x42UCKET_POLICY_PUBLIC_RW\x10\x03\x12\x18\n\x14\x42UCKET_POLICY_CUSTOM\x10\x04\x32\xda\x15\n\x0cMinIOService\x12O\n\x0c\x43reateBucket\x12\x1e.isa.minio.CreateBucketRequest\x1a\x1f.isa.minio.CreateBucketResponse\x12L\n\x0bListBuckets\x12\x1d.isa.minio.ListBucketsRequest\x1a\x1e.isa.minio.ListBucketsResponse\x12O\n\x0c\x44\x65leteBucket\x12\x1e.isa.minio.DeleteBucketRequest\x1a\x1f.isa.minio.DeleteBucketResponse\x12R\n\rGetBucketInfo\x12\x1f.isa.minio.GetBucketInfoRequest\x1a .isa.minio.GetBucketInfoResponse\x12X\n\x0fSetBucketPolicy\x12!.isa.minio.SetBucketPolicyRequest\x1a\".isa.minio.SetBucketPolicyResponse\x12X\n\x0fGetBucketPolicy\x12!.isa.minio.GetBucketPolicyRequest\x1a\".isa.minio.GetBucketPolicyResponse\x12R\n\rSetBucketTags\x12\x1f.isa.minio.SetBucketTagsRequest\x1a .isa.minio.SetBucketTagsResponse\x12R\n\rGetBucketTags\x12\x1f.isa.minio.GetBucketTagsRequest\x1a .isa.minio.GetBucketTagsResponse\x12[\n\x10\x44\x65leteBucketTags\x12\".isa.minio.DeleteBucketTagsRequest\x1a#.isa.minio.DeleteBucketTagsResponse\x12\x64\n\x13SetBucketVersioning\x12%.isa.minio.SetBucketVersioningRequest\x1a&.isa.minio.SetBucketVersioningResponse\x12\x64\n\x13GetBucketVersioning\x12%.isa.minio.GetBucketVersioningRequest\x1a&.isa.minio.GetBucketVersioningResponse\x12\x61\n\x12SetBucketLifecycle\x12$.isa.minio.SetBucketLifecycleRequest\x1a%.isa.minio.SetBucketLifecycleResponse\x12\x61\n\x12GetBucketLifecycle\x12$.isa.minio.GetBucketLifecycleRequest\x1a%.isa.minio.GetBucketLifecycleResponse\x12j\n\x15\x44\x65leteBucketLifecycle\x12\'.isa.minio.DeleteBucketLifecycleRequest\x1a(.isa.minio.DeleteBucketLifecycleResponse\x12H\n\tPutObject\x12\x1b.isa.minio.PutObjectRequest\x1a\x1c.isa.minio.PutObjectResponse(\x01\x12H\n\tGetObject\x12\x1b.isa.minio.GetObjectRequest\x1a\x1c.isa.minio.GetObjectResponse0\x01\x12O\n\x0c\x44\x65leteObject\x12\x1e.isa.minio.DeleteObjectRequest\x1a\x1f.isa.minio.DeleteObjectResponse\x12R\n\rDeleteObjects\x12\x1f.isa.minio.DeleteObjectsRequest\x1a .isa.minio.DeleteObjectsResponse\x12L\n\x0bListObjects\x12\x1d.isa.minio.ListObjectsRequest\x1a\x1e.isa.minio.ListObjectsResponse\x12I\n\nCopyObject\x12\x1c.isa.minio.CopyObjectRequest\x1a\x1d.isa.minio.CopyObjectResponse\x12I\n\nStatObject\x12\x1c.isa.minio.StatObjectRequest\x1a\x1d.isa.minio.StatObjectResponse\x12R\n\rSetObjectTags\x12\x1f.isa.minio.SetObjectTagsRequest\x1a .isa.minio.SetObjectTagsResponse\x12R\n\rGetObjectTags\x12\x1f.isa.minio.GetObjectTagsRequest\x1a .isa.minio.GetObjectTagsResponse\x12[\n\x10\x44\x65leteObjectTags\x12\".isa.minio.DeleteObjectTagsRequest\x1a#.isa.minio.DeleteObjectTagsResponse\x12X\n\x0fGetPresignedURL\x12!.isa.minio.GetPresignedURLRequest\x1a\".isa.minio.GetPresignedURLResponse\x12\x61\n\x12GetPresignedPutURL\x12$.isa.minio.GetPresignedPutURLRequest\x1a%.isa.minio.GetPresignedPutURLResponse\x12p\n\x17InitiateMultipartUpload\x12).isa.minio.InitiateMultipartUploadRequest\x1a*.isa.minio.InitiateMultipartUploadResponse\x12K\n\nUploadPart\x12\x1c.isa.minio.UploadPartRequest\x1a\x1d.isa.minio.UploadPartResponse(\x01\x12p\n\x17\x43ompleteMultipartUpload\x12).isa.minio.CompleteMultipartUploadRequest\x1a*.isa.minio.CompleteMultipartUploadResponse\x12g\n\x14\x41\x62ortMultipartUpload\x12&.isa.minio.AbortMultipartUploadRequest\x1a\'.isa.minio.AbortMultipartUploadResponse\x12V\n\x0bHealthCheck\x12\".isa.minio.MinIOHealthCheckRequest\x1a#.isa.minio.MinIOHealthCheckResponseB0Z.github.com/isa-cloud/isa_cloud/api/proto/miniob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'minio_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z.github.com/isa-cloud/isa_cloud/api/proto/minio'
  _globals['_BUCKETINFO_TAGSENTRY']._loaded_options = None
  _globals['_BUCKETINFO_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_OBJECTINFO_METADATAENTRY']._loaded_options = None
  _globals['_OBJECTINFO_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CREATEBUCKETREQUEST_TAGSENTRY']._loaded_options = None
  _globals['_CREATEBUCKETREQUEST_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_SETBUCKETTAGSREQUEST_TAGSENTRY']._loaded_options = None
  _globals['_SETBUCKETTAGSREQUEST_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_GETBUCKETTAGSRESPONSE_TAGSENTRY']._loaded_options = None
  _globals['_GETBUCKETTAGSRESPONSE_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_PUTOBJECTMETADATA_METADATAENTRY']._loaded_options = None
  _globals['_PUTOBJECTMETADATA_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_COPYOBJECTREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_COPYOBJECTREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_SETOBJECTTAGSREQUEST_TAGSENTRY']._loaded_options = None
  _globals['_SETOBJECTTAGSREQUEST_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_GETOBJECTTAGSRESPONSE_TAGSENTRY']._loaded_options = None
  _globals['_GETOBJECTTAGSRESPONSE_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_GETPRESIGNEDURLREQUEST_REQUESTPARAMSENTRY']._loaded_options = None
  _globals['_GETPRESIGNEDURLREQUEST_REQUESTPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_INITIATEMULTIPARTUPLOADREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_INITIATEMULTIPARTUPLOADREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_BUCKETPOLICYTYPE']._serialized_start=8454
  _globals['_BUCKETPOLICYTYPE']._serialized_end=8617
  _globals['_BUCKETINFO']._serialized_start=112
  _globals['_BUCKETINFO']._serialized_end=382
  _globals['_BUCKETINFO_TAGSENTRY']._serialized_start=339
  _globals['_BUCKETINFO_TAGSENTRY']._serialized_end=382
  _globals['_OBJECTINFO']._serialized_start=385
  _globals['_OBJECTINFO']._serialized_end=676
  _globals['_OBJECTINFO_METADATAENTRY']._serialized_start=629
  _globals['_OBJECTINFO_METADATAENTRY']._serialized_end=676
  _globals['_CREATEBUCKETREQUEST']._serialized_start=679
  _globals['_CREATEBUCKETREQUEST']._serialized_end=904
  _globals['_CREATEBUCKETREQUEST_TAGSENTRY']._serialized_start=339
  _globals['_CREATEBUCKETREQUEST_TAGSENTRY']._serialized_end=382
  _globals['_CREATEBUCKETRESPONSE']._serialized_start=906
  _globals['_CREATEBUCKETRESPONSE']._serialized_end=1021
  _globals['_LISTBUCKETSREQUEST']._serialized_start=1023
  _globals['_LISTBUCKETSREQUEST']._serialized_end=1101
  _globals['_LISTBUCKETSRESPONSE']._serialized_start=1103
  _globals['_LISTBUCKETSRESPONSE']._serialized_end=1217
  _globals['_DELETEBUCKETREQUEST']._serialized_start=1219
  _globals['_DELETEBUCKETREQUEST']._serialized_end=1293
  _globals['_DELETEBUCKETRESPONSE']._serialized_start=1295
  _globals['_DELETEBUCKETRESPONSE']._serialized_end=1391
  _globals['_GETBUCKETINFOREQUEST']._serialized_start=1393
  _globals['_GETBUCKETINFOREQUEST']._serialized_end=1453
  _globals['_GETBUCKETINFORESPONSE']._serialized_start=1455
  _globals['_GETBUCKETINFORESPONSE']._serialized_end=1554
  _globals['_SETBUCKETPOLICYREQUEST']._serialized_start=1557
  _globals['_SETBUCKETPOLICYREQUEST']._serialized_end=1692
  _globals['_SETBUCKETPOLICYRESPONSE']._serialized_start=1694
  _globals['_SETBUCKETPOLICYRESPONSE']._serialized_end=1768
  _globals['_GETBUCKETPOLICYREQUEST']._serialized_start=1770
  _globals['_GETBUCKETPOLICYREQUEST']._serialized_end=1832
  _globals['_GETBUCKETPOLICYRESPONSE']._serialized_start=1835
  _globals['_GETBUCKETPOLICYRESPONSE']._serialized_end=1963
  _globals['_SETBUCKETTAGSREQUEST']._serialized_start=1966
  _globals['_SETBUCKETTAGSREQUEST']._serialized_end=2128
  _globals['_SETBUCKETTAGSREQUEST_TAGSENTRY']._serialized_start=339
  _globals['_SETBUCKETTAGSREQUEST_TAGSENTRY']._serialized_end=382
  _globals['_SETBUCKETTAGSRESPONSE']._serialized_start=2130
  _globals['_SETBUCKETTAGSRESPONSE']._serialized_end=2202
  _globals['_GETBUCKETTAGSREQUEST']._serialized_start=2204
  _globals['_GETBUCKETTAGSREQUEST']._serialized_end=2264
  _globals['_GETBUCKETTAGSRESPONSE']._serialized_start=2267
  _globals['_GETBUCKETTAGSRESPONSE']._serialized_end=2425
  _globals['_GETBUCKETTAGSRESPONSE_TAGSENTRY']._serialized_start=339
  _globals['_GETBUCKETTAGSRESPONSE_TAGSENTRY']._serialized_end=382
  _globals['_DELETEBUCKETTAGSREQUEST']._serialized_start=2427
  _globals['_DELETEBUCKETTAGSREQUEST']._serialized_end=2490
  _globals['_DELETEBUCKETTAGSRESPONSE']._serialized_start=2492
  _globals['_DELETEBUCKETTAGSRESPONSE']._serialized_end=2567
  _globals['_SETBUCKETVERSIONINGREQUEST']._serialized_start=2569
  _globals['_SETBUCKETVERSIONINGREQUEST']._serialized_end=2652
  _globals['_SETBUCKETVERSIONINGRESPONSE']._serialized_start=2654
  _globals['_SETBUCKETVERSIONINGRESPONSE']._serialized_end=2732
  _globals['_GETBUCKETVERSIONINGREQUEST']._serialized_start=2734
  _globals['_GETBUCKETVERSIONINGREQUEST']._serialized_end=2800
  _globals['_GETBUCKETVERSIONINGRESPONSE']._serialized_start=2802
  _globals['_GETBUCKETVERSIONINGRESPONSE']._serialized_end=2880
  _globals['_LIFECYCLERULE']._serialized_start=2883
  _globals['_LIFECYCLERULE']._serialized_end=3057
  _globals['_SETBUCKETLIFECYCLEREQUEST']._serialized_start=3059
  _globals['_SETBUCKETLIFECYCLEREQUEST']._serialized_end=3165
  _globals['_SETBUCKETLIFECYCLERESPONSE']._serialized_start=3167
  _globals['_SETBUCKETLIFECYCLERESPONSE']._serialized_end=3244
  _globals['_GETBUCKETLIFECYCLEREQUEST']._serialized_start=3246
  _globals['_GETBUCKETLIFECYCLEREQUEST']._serialized_end=3311
  _globals['_GETBUCKETLIFECYCLERESPONSE']._serialized_start=3313
  _globals['_GETBUCKETLIFECYCLERESPONSE']._serialized_end=3414
  _globals['_DELETEBUCKETLIFECYCLEREQUEST']._serialized_start=3416
  _globals['_DELETEBUCKETLIFECYCLEREQUEST']._serialized_end=3484
  _globals['_DELETEBUCKETLIFECYCLERESPONSE']._serialized_start=3486
  _globals['_DELETEBUCKETLIFECYCLERESPONSE']._serialized_end=3566
  _globals['_PUTOBJECTREQUEST']._serialized_start=3568
  _globals['_PUTOBJECTREQUEST']._serialized_end=3661
  _globals['_PUTOBJECTMETADATA']._serialized_start=3664
  _globals['_PUTOBJECTMETADATA']._serialized_end=3921
  _globals['_PUTOBJECTMETADATA_METADATAENTRY']._serialized_start=629
  _globals['_PUTOBJECTMETADATA_METADATAENTRY']._serialized_end=676
  _globals['_PUTOBJECTRESPONSE']._serialized_start=3923
  _globals['_PUTOBJECTRESPONSE']._serialized_end=4042
  _globals['_GETOBJECTREQUEST']._serialized_start=4045
  _globals['_GETOBJECTREQUEST']._serialized_end=4173
  _globals['_GETOBJECTRESPONSE']._serialized_start=4175
  _globals['_GETOBJECTRESPONSE']._serialized_end=4262
  _globals['_DELETEOBJECTREQUEST']._serialized_start=4264
  _globals['_DELETEOBJECTREQUEST']._serialized_end=4363
  _globals['_DELETEOBJECTRESPONSE']._serialized_start=4365
  _globals['_DELETEOBJECTRESPONSE']._serialized_end=4436
  _globals['_DELETEOBJECTSREQUEST']._serialized_start=4438
  _globals['_DELETEOBJECTSREQUEST']._serialized_end=4534
  _globals['_DELETEOBJECTSRESPONSE']._serialized_start=4536
  _globals['_DELETEOBJECTSRESPONSE']._serialized_end=4653
  _globals['_DELETEERROR']._serialized_start=4655
  _globals['_DELETEERROR']._serialized_end=4724
  _globals['_LISTOBJECTSREQUEST']._serialized_start=4727
  _globals['_LISTOBJECTSREQUEST']._serialized_end=4906
  _globals['_LISTOBJECTSRESPONSE']._serialized_start=4909
  _globals['_LISTOBJECTSRESPONSE']._serialized_end=5082
  _globals['_COPYOBJECTREQUEST']._serialized_start=5085
  _globals['_COPYOBJECTREQUEST']._serialized_end=5342
  _globals['_COPYOBJECTREQUEST_METADATAENTRY']._serialized_start=629
  _globals['_COPYOBJECTREQUEST_METADATAENTRY']._serialized_end=676
  _globals['_COPYOBJECTRESPONSE']._serialized_start=5345
  _globals['_COPYOBJECTRESPONSE']._serialized_end=5479
  _globals['_STATOBJECTREQUEST']._serialized_start=5481
  _globals['_STATOBJECTREQUEST']._serialized_end=5578
  _globals['_STATOBJECTRESPONSE']._serialized_start=5580
  _globals['_STATOBJECTRESPONSE']._serialized_end=5676
  _globals['_SETOBJECTTAGSREQUEST']._serialized_start=5679
  _globals['_SETOBJECTTAGSREQUEST']._serialized_end=5881
  _globals['_SETOBJECTTAGSREQUEST_TAGSENTRY']._serialized_start=339
  _globals['_SETOBJECTTAGSREQUEST_TAGSENTRY']._serialized_end=382
  _globals['_SETOBJECTTAGSRESPONSE']._serialized_start=5883
  _globals['_SETOBJECTTAGSRESPONSE']._serialized_end=5955
  _globals['_GETOBJECTTAGSREQUEST']._serialized_start=5957
  _globals['_GETOBJECTTAGSREQUEST']._serialized_end=6057
  _globals['_GETOBJECTTAGSRESPONSE']._serialized_start=6060
  _globals['_GETOBJECTTAGSRESPONSE']._serialized_end=6218
  _globals['_GETOBJECTTAGSRESPONSE_TAGSENTRY']._serialized_start=339
  _globals['_GETOBJECTTAGSRESPONSE_TAGSENTRY']._serialized_end=382
  _globals['_DELETEOBJECTTAGSREQUEST']._serialized_start=6220
  _globals['_DELETEOBJECTTAGSREQUEST']._serialized_end=6323
  _globals['_DELETEOBJECTTAGSRESPONSE']._serialized_start=6325
  _globals['_DELETEOBJECTTAGSRESPONSE']._serialized_end=6400
  _globals['_GETPRESIGNEDURLREQUEST']._serialized_start=6403
  _globals['_GETPRESIGNEDURLREQUEST']._serialized_end=6641
  _globals['_GETPRESIGNEDURLREQUEST_REQUESTPARAMSENTRY']._serialized_start=6589
  _globals['_GETPRESIGNEDURLREQUEST_REQUESTPARAMSENTRY']._serialized_end=6641
  _globals['_GETPRESIGNEDURLRESPONSE']._serialized_start=6643
  _globals['_GETPRESIGNEDURLRESPONSE']._serialized_end=6761
  _globals['_GETPRESIGNEDPUTURLREQUEST']._serialized_start=6764
  _globals['_GETPRESIGNEDPUTURLREQUEST']._serialized_end=6895
  _globals['_GETPRESIGNEDPUTURLRESPONSE']._serialized_start=6897
  _globals['_GETPRESIGNEDPUTURLRESPONSE']._serialized_end=7018
  _globals['_INITIATEMULTIPARTUPLOADREQUEST']._serialized_start=7021
  _globals['_INITIATEMULTIPARTUPLOADREQUEST']._serialized_end=7257
  _globals['_INITIATEMULTIPARTUPLOADREQUEST_METADATAENTRY']._serialized_start=629
  _globals['_INITIATEMULTIPARTUPLOADREQUEST_METADATAENTRY']._serialized_end=676
  _globals['_INITIATEMULTIPARTUPLOADRESPONSE']._serialized_start=7259
  _globals['_INITIATEMULTIPARTUPLOADRESPONSE']._serialized_end=7384
  _globals['_UPLOADPARTREQUEST']._serialized_start=7386
  _globals['_UPLOADPARTREQUEST']._serialized_end=7481
  _globals['_UPLOADPARTMETADATA']._serialized_start=7484
  _globals['_UPLOADPARTMETADATA']._serialized_end=7621
  _globals['_UPLOADPARTRESPONSE']._serialized_start=7623
  _globals['_UPLOADPARTRESPONSE']._serialized_end=7710
  _globals['_COMPLETEDPART']._serialized_start=7712
  _globals['_COMPLETEDPART']._serialized_end=7762
  _globals['_COMPLETEMULTIPARTUPLOADREQUEST']._serialized_start=7765
  _globals['_COMPLETEMULTIPARTUPLOADREQUEST']._serialized_end=7915
  _globals['_COMPLETEMULTIPARTUPLOADRESPONSE']._serialized_start=7917
  _globals['_COMPLETEMULTIPARTUPLOADRESPONSE']._serialized_end=8034
  _globals['_ABORTMULTIPARTUPLOADREQUEST']._serialized_start=8036
  _globals['_ABORTMULTIPARTUPLOADREQUEST']._serialized_end=8142
  _globals['_ABORTMULTIPARTUPLOADRESPONSE']._serialized_start=8144
  _globals['_ABORTMULTIPARTUPLOADRESPONSE']._serialized_end=8223
  _globals['_MINIOHEALTHCHECKREQUEST']._serialized_start=8225
  _globals['_MINIOHEALTHCHECKREQUEST']._serialized_end=8268
  _globals['_MINIOHEALTHCHECKRESPONSE']._serialized_start=8271
  _globals['_MINIOHEALTHCHECKRESPONSE']._serialized_end=8451
  _globals['_MINIOSERVICE']._serialized_start=8620
  _globals['_MINIOSERVICE']._serialized_end=11398
# @@protoc_insertion_point(module_scope)
