# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: redis_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'redis_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13redis_service.proto\x12\tisa.redis\x1a\x0c\x63ommon.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"&\n\x08KeyValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\")\n\tHashField\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"+\n\nZSetMember\x12\x0e\n\x06member\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x01\"\xa2\x02\n\x0bSessionInfo\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12.\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32 .isa.redis.SessionInfo.DataEntry\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpires_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rlast_accessed\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"l\n\x0c\x42\x61tchCommand\x12\x11\n\toperation\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12-\n\nexpiration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\"R\n\nSetRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\"/\n\x0bSetResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"C\n\nGetRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"+\n\x0bGetResponse\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\t\"L\n\x12GetMultipleRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0c\n\x04keys\x18\x03 \x03(\t\":\n\x13GetMultipleResponse\x12#\n\x06values\x18\x01 \x03(\x0b\x32\x13.isa.redis.KeyValue\"\x8f\x01\n\x18SetWithExpirationRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\x12-\n\nexpiration\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\"X\n\x10IncrementRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\r\n\x05\x64\x65lta\x18\x04 \x01(\x03\"\"\n\x11IncrementResponse\x12\r\n\x05value\x18\x01 \x01(\x03\"X\n\x10\x44\x65\x63rementRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\r\n\x05\x64\x65lta\x18\x04 \x01(\x03\"\"\n\x11\x44\x65\x63rementResponse\x12\r\n\x05value\x18\x01 \x01(\x03\"U\n\rAppendRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\" \n\x0e\x41ppendResponse\x12\x0e\n\x06length\x18\x01 \x01(\x03\"F\n\rDeleteRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"8\n\x0e\x44\x65leteResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rdeleted_count\x18\x02 \x01(\x05\"O\n\x15\x44\x65leteMultipleRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0c\n\x04keys\x18\x03 \x03(\t\"F\n\rExistsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\" \n\x0e\x45xistsResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\"u\n\rExpireRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12-\n\nexpiration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\"!\n\x0e\x45xpireResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"F\n\rGetTTLRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"%\n\x0eGetTTLResponse\x12\x13\n\x0bttl_seconds\x18\x01 \x01(\x03\"[\n\rRenameRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0f\n\x07old_key\x18\x03 \x01(\t\x12\x0f\n\x07new_key\x18\x04 \x01(\t\"!\n\x0eRenameResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"[\n\x0fListKeysRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0f\n\x07pattern\x18\x03 \x01(\t\x12\r\n\x05limit\x18\x04 \x01(\x05\"5\n\x10ListKeysResponse\x12\x0c\n\x04keys\x18\x01 \x03(\t\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"j\n\x0bHSetRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12$\n\x06\x66ields\x18\x04 \x03(\x0b\x32\x14.isa.redis.HashField\"3\n\x0cHSetResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x12\n\nfields_set\x18\x02 \x01(\x05\"S\n\x0bHGetRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\r\n\x05\x66ield\x18\x04 \x01(\t\",\n\x0cHGetResponse\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\t\"G\n\x0eHGetAllRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"7\n\x0fHGetAllResponse\x12$\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x14.isa.redis.HashField\"W\n\x0eHDeleteRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0e\n\x06\x66ields\x18\x04 \x03(\t\"9\n\x0fHDeleteResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rdeleted_count\x18\x02 \x01(\x05\"V\n\x0eHExistsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\r\n\x05\x66ield\x18\x04 \x01(\t\"!\n\x0fHExistsResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\"E\n\x0cHKeysRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\x1f\n\rHKeysResponse\x12\x0e\n\x06\x66ields\x18\x01 \x03(\t\"G\n\x0eHValuesRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"!\n\x0fHValuesResponse\x12\x0e\n\x06values\x18\x01 \x03(\t\"h\n\x11HIncrementRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\r\n\x05\x66ield\x18\x04 \x01(\t\x12\r\n\x05\x64\x65lta\x18\x05 \x01(\x03\"#\n\x12HIncrementResponse\x12\r\n\x05value\x18\x01 \x01(\x03\"U\n\x0cLPushRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0e\n\x06values\x18\x04 \x03(\t\"\x1f\n\rLPushResponse\x12\x0e\n\x06length\x18\x01 \x01(\x05\"U\n\x0cRPushRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0e\n\x06values\x18\x04 \x03(\t\"\x1f\n\rRPushResponse\x12\x0e\n\x06length\x18\x01 \x01(\x05\"D\n\x0bLPopRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\",\n\x0cLPopResponse\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\t\"D\n\x0bRPopRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\",\n\x0cRPopResponse\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\t\"c\n\rLRangeRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\r\n\x05start\x18\x04 \x01(\x05\x12\x0c\n\x04stop\x18\x05 \x01(\x05\" \n\x0eLRangeResponse\x12\x0e\n\x06values\x18\x01 \x03(\t\"D\n\x0bLLenRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\x1e\n\x0cLLenResponse\x12\x0e\n\x06length\x18\x01 \x01(\x05\"U\n\rLIndexRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\".\n\x0eLIndexResponse\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\t\"b\n\x0cLTrimRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\r\n\x05start\x18\x04 \x01(\x05\x12\x0c\n\x04stop\x18\x05 \x01(\x05\" \n\rLTrimResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"U\n\x0bSAddRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\"#\n\x0cSAddResponse\x12\x13\n\x0b\x61\x64\x64\x65\x64_count\x18\x01 \x01(\x05\"X\n\x0eSRemoveRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\"(\n\x0fSRemoveResponse\x12\x15\n\rremoved_count\x18\x01 \x01(\x05\"H\n\x0fSMembersRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"#\n\x10SMembersResponse\x12\x0f\n\x07members\x18\x01 \x03(\t\"Y\n\x10SIsMemberRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\"&\n\x11SIsMemberResponse\x12\x11\n\tis_member\x18\x01 \x01(\x08\"E\n\x0cSCardRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\x1e\n\rSCardResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\"G\n\rSUnionRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0c\n\x04keys\x18\x03 \x03(\t\"!\n\x0eSUnionResponse\x12\x0f\n\x07members\x18\x01 \x03(\t\"G\n\rSInterRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0c\n\x04keys\x18\x03 \x03(\t\"!\n\x0eSInterResponse\x12\x0f\n\x07members\x18\x01 \x03(\t\"F\n\x0cSDiffRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0c\n\x04keys\x18\x03 \x03(\t\" \n\rSDiffResponse\x12\x0f\n\x07members\x18\x01 \x03(\t\"l\n\x0bZAddRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12&\n\x07members\x18\x04 \x03(\x0b\x32\x15.isa.redis.ZSetMember\"#\n\x0cZAddResponse\x12\x13\n\x0b\x61\x64\x64\x65\x64_count\x18\x01 \x01(\x05\"X\n\x0eZRemoveRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\"(\n\x0fZRemoveResponse\x12\x15\n\rremoved_count\x18\x01 \x01(\x05\"x\n\rZRangeRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\r\n\x05start\x18\x04 \x01(\x05\x12\x0c\n\x04stop\x18\x05 \x01(\x05\x12\x13\n\x0bwith_scores\x18\x06 \x01(\x08\"8\n\x0eZRangeResponse\x12&\n\x07members\x18\x01 \x03(\x0b\x32\x15.isa.redis.ZSetMember\"\x92\x01\n\x14ZRangeByScoreRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x11\n\tmin_score\x18\x04 \x01(\x01\x12\x11\n\tmax_score\x18\x05 \x01(\x01\x12\x0e\n\x06offset\x18\x06 \x01(\x05\x12\r\n\x05\x63ount\x18\x07 \x01(\x05\"?\n\x15ZRangeByScoreResponse\x12&\n\x07members\x18\x01 \x03(\x0b\x32\x15.isa.redis.ZSetMember\"U\n\x0cZRankRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\",\n\rZRankResponse\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12\x0c\n\x04rank\x18\x02 \x01(\x05\"V\n\rZScoreRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\".\n\x0eZScoreResponse\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12\r\n\x05score\x18\x02 \x01(\x01\"E\n\x0cZCardRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\x1e\n\rZCardResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\"i\n\x11ZIncrementRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\r\n\x05\x64\x65lta\x18\x05 \x01(\x01\"#\n\x12ZIncrementResponse\x12\r\n\x05score\x18\x01 \x01(\x01\"\xa9\x01\n\x12\x41\x63quireLockRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x10\n\x08lock_key\x18\x03 \x01(\t\x12&\n\x03ttl\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x0cwait_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\"h\n\x13\x41\x63quireLockResponse\x12\x10\n\x08\x61\x63quired\x18\x01 \x01(\x08\x12\x0f\n\x07lock_id\x18\x02 \x01(\t\x12.\n\nexpires_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"a\n\x12ReleaseLockRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x10\n\x08lock_key\x18\x03 \x01(\t\x12\x0f\n\x07lock_id\x18\x04 \x01(\t\"\'\n\x13ReleaseLockResponse\x12\x10\n\x08released\x18\x01 \x01(\x08\"\x87\x01\n\x10RenewLockRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x10\n\x08lock_key\x18\x03 \x01(\t\x12\x0f\n\x07lock_id\x18\x04 \x01(\t\x12&\n\x03ttl\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\"T\n\x11RenewLockResponse\x12\x0f\n\x07renewed\x18\x01 \x01(\x08\x12.\n\nexpires_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\\\n\x0ePublishRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\"+\n\x0fPublishResponse\x12\x18\n\x10subscriber_count\x18\x01 \x01(\x05\"N\n\x10SubscribeRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x10\n\x08\x63hannels\x18\x03 \x03(\t\"b\n\x0fMessageResponse\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"P\n\x12UnsubscribeRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x10\n\x08\x63hannels\x18\x03 \x03(\t\"&\n\x13UnsubscribeResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"h\n\x11RedisBatchRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12)\n\x08\x63ommands\x18\x03 \x03(\x0b\x32\x17.isa.redis.BatchCommand\"M\n\x12RedisBatchResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0e\x65xecuted_count\x18\x02 \x01(\x05\x12\x0e\n\x06\x65rrors\x18\x03 \x03(\t\"\xce\x01\n\x14\x43reateSessionRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x37\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32).isa.redis.CreateSessionRequest.DataEntry\x12&\n\x03ttl\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"[\n\x15\x43reateSessionResponse\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12.\n\nexpires_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"8\n\x11GetSessionRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\"L\n\x12GetSessionResponse\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12\'\n\x07session\x18\x02 \x01(\x0b\x32\x16.isa.redis.SessionInfo\"\xb5\x01\n\x14UpdateSessionRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x37\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32).isa.redis.UpdateSessionRequest.DataEntry\x12\x12\n\nextend_ttl\x18\x04 \x01(\x08\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"(\n\x15UpdateSessionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\";\n\x14\x44\x65leteSessionRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\"(\n\x15\x44\x65leteSessionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"?\n\x13ListSessionsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\"@\n\x14ListSessionsResponse\x12(\n\x08sessions\x18\x01 \x03(\x0b\x32\x16.isa.redis.SessionInfo\"@\n\x14GetStatisticsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\"\xa8\x02\n\x15GetStatisticsResponse\x12\x12\n\ntotal_keys\x18\x01 \x01(\x03\x12\x19\n\x11memory_used_bytes\x18\x02 \x01(\x03\x12\x1a\n\x12\x63ommands_processed\x18\x03 \x01(\x03\x12\x1c\n\x14\x63onnections_received\x18\x04 \x01(\x03\x12\x10\n\x08hit_rate\x18\x05 \x01(\x01\x12X\n\x15key_type_distribution\x18\x06 \x03(\x0b\x32\x39.isa.redis.GetStatisticsResponse.KeyTypeDistributionEntry\x1a:\n\x18KeyTypeDistributionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"J\n\x11GetKeyInfoRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xd4\x01\n\x12GetKeyInfoResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\x12\"\n\x04type\x18\x02 \x01(\x0e\x32\x14.isa.redis.ValueType\x12\x13\n\x0bttl_seconds\x18\x03 \x01(\x03\x12\x12\n\nsize_bytes\x18\x04 \x01(\x03\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rlast_accessed\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"-\n\x17RedisHealthCheckRequest\x12\x12\n\ndeep_check\x18\x01 \x01(\x08\"\xb8\x01\n\x18RedisHealthCheckResponse\x12\x0f\n\x07healthy\x18\x01 \x01(\x08\x12\x14\n\x0credis_status\x18\x02 \x01(\t\x12\x19\n\x11\x63onnected_clients\x18\x03 \x01(\x03\x12\x19\n\x11used_memory_bytes\x18\x04 \x01(\x03\x12.\n\nchecked_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07message\x18\x06 \x01(\t*u\n\tValueType\x12\x15\n\x11VALUE_TYPE_STRING\x10\x00\x12\x13\n\x0fVALUE_TYPE_HASH\x10\x01\x12\x13\n\x0fVALUE_TYPE_LIST\x10\x02\x12\x12\n\x0eVALUE_TYPE_SET\x10\x03\x12\x13\n\x0fVALUE_TYPE_ZSET\x10\x04\x32\xbc \n\x0cRedisService\x12\x34\n\x03Set\x12\x15.isa.redis.SetRequest\x1a\x16.isa.redis.SetResponse\x12\x34\n\x03Get\x12\x15.isa.redis.GetRequest\x1a\x16.isa.redis.GetResponse\x12L\n\x0bGetMultiple\x12\x1d.isa.redis.GetMultipleRequest\x1a\x1e.isa.redis.GetMultipleResponse\x12P\n\x11SetWithExpiration\x12#.isa.redis.SetWithExpirationRequest\x1a\x16.isa.redis.SetResponse\x12\x46\n\tIncrement\x12\x1b.isa.redis.IncrementRequest\x1a\x1c.isa.redis.IncrementResponse\x12\x46\n\tDecrement\x12\x1b.isa.redis.DecrementRequest\x1a\x1c.isa.redis.DecrementResponse\x12=\n\x06\x41ppend\x12\x18.isa.redis.AppendRequest\x1a\x19.isa.redis.AppendResponse\x12=\n\x06\x44\x65lete\x12\x18.isa.redis.DeleteRequest\x1a\x19.isa.redis.DeleteResponse\x12M\n\x0e\x44\x65leteMultiple\x12 .isa.redis.DeleteMultipleRequest\x1a\x19.isa.redis.DeleteResponse\x12=\n\x06\x45xists\x12\x18.isa.redis.ExistsRequest\x1a\x19.isa.redis.ExistsResponse\x12=\n\x06\x45xpire\x12\x18.isa.redis.ExpireRequest\x1a\x19.isa.redis.ExpireResponse\x12=\n\x06GetTTL\x12\x18.isa.redis.GetTTLRequest\x1a\x19.isa.redis.GetTTLResponse\x12=\n\x06Rename\x12\x18.isa.redis.RenameRequest\x1a\x19.isa.redis.RenameResponse\x12\x43\n\x08ListKeys\x12\x1a.isa.redis.ListKeysRequest\x1a\x1b.isa.redis.ListKeysResponse\x12\x37\n\x04HSet\x12\x16.isa.redis.HSetRequest\x1a\x17.isa.redis.HSetResponse\x12\x37\n\x04HGet\x12\x16.isa.redis.HGetRequest\x1a\x17.isa.redis.HGetResponse\x12@\n\x07HGetAll\x12\x19.isa.redis.HGetAllRequest\x1a\x1a.isa.redis.HGetAllResponse\x12@\n\x07HDelete\x12\x19.isa.redis.HDeleteRequest\x1a\x1a.isa.redis.HDeleteResponse\x12@\n\x07HExists\x12\x19.isa.redis.HExistsRequest\x1a\x1a.isa.redis.HExistsResponse\x12:\n\x05HKeys\x12\x17.isa.redis.HKeysRequest\x1a\x18.isa.redis.HKeysResponse\x12@\n\x07HValues\x12\x19.isa.redis.HValuesRequest\x1a\x1a.isa.redis.HValuesResponse\x12I\n\nHIncrement\x12\x1c.isa.redis.HIncrementRequest\x1a\x1d.isa.redis.HIncrementResponse\x12:\n\x05LPush\x12\x17.isa.redis.LPushRequest\x1a\x18.isa.redis.LPushResponse\x12:\n\x05RPush\x12\x17.isa.redis.RPushRequest\x1a\x18.isa.redis.RPushResponse\x12\x37\n\x04LPop\x12\x16.isa.redis.LPopRequest\x1a\x17.isa.redis.LPopResponse\x12\x37\n\x04RPop\x12\x16.isa.redis.RPopRequest\x1a\x17.isa.redis.RPopResponse\x12=\n\x06LRange\x12\x18.isa.redis.LRangeRequest\x1a\x19.isa.redis.LRangeResponse\x12\x37\n\x04LLen\x12\x16.isa.redis.LLenRequest\x1a\x17.isa.redis.LLenResponse\x12=\n\x06LIndex\x12\x18.isa.redis.LIndexRequest\x1a\x19.isa.redis.LIndexResponse\x12:\n\x05LTrim\x12\x17.isa.redis.LTrimRequest\x1a\x18.isa.redis.LTrimResponse\x12\x37\n\x04SAdd\x12\x16.isa.redis.SAddRequest\x1a\x17.isa.redis.SAddResponse\x12@\n\x07SRemove\x12\x19.isa.redis.SRemoveRequest\x1a\x1a.isa.redis.SRemoveResponse\x12\x43\n\x08SMembers\x12\x1a.isa.redis.SMembersRequest\x1a\x1b.isa.redis.SMembersResponse\x12\x46\n\tSIsMember\x12\x1b.isa.redis.SIsMemberRequest\x1a\x1c.isa.redis.SIsMemberResponse\x12:\n\x05SCard\x12\x17.isa.redis.SCardRequest\x1a\x18.isa.redis.SCardResponse\x12=\n\x06SUnion\x12\x18.isa.redis.SUnionRequest\x1a\x19.isa.redis.SUnionResponse\x12=\n\x06SInter\x12\x18.isa.redis.SInterRequest\x1a\x19.isa.redis.SInterResponse\x12:\n\x05SDiff\x12\x17.isa.redis.SDiffRequest\x1a\x18.isa.redis.SDiffResponse\x12\x37\n\x04ZAdd\x12\x16.isa.redis.ZAddRequest\x1a\x17.isa.redis.ZAddResponse\x12@\n\x07ZRemove\x12\x19.isa.redis.ZRemoveRequest\x1a\x1a.isa.redis.ZRemoveResponse\x12=\n\x06ZRange\x12\x18.isa.redis.ZRangeRequest\x1a\x19.isa.redis.ZRangeResponse\x12R\n\rZRangeByScore\x12\x1f.isa.redis.ZRangeByScoreRequest\x1a .isa.redis.ZRangeByScoreResponse\x12:\n\x05ZRank\x12\x17.isa.redis.ZRankRequest\x1a\x18.isa.redis.ZRankResponse\x12=\n\x06ZScore\x12\x18.isa.redis.ZScoreRequest\x1a\x19.isa.redis.ZScoreResponse\x12:\n\x05ZCard\x12\x17.isa.redis.ZCardRequest\x1a\x18.isa.redis.ZCardResponse\x12I\n\nZIncrement\x12\x1c.isa.redis.ZIncrementRequest\x1a\x1d.isa.redis.ZIncrementResponse\x12L\n\x0b\x41\x63quireLock\x12\x1d.isa.redis.AcquireLockRequest\x1a\x1e.isa.redis.AcquireLockResponse\x12L\n\x0bReleaseLock\x12\x1d.isa.redis.ReleaseLockRequest\x1a\x1e.isa.redis.ReleaseLockResponse\x12\x46\n\tRenewLock\x12\x1b.isa.redis.RenewLockRequest\x1a\x1c.isa.redis.RenewLockResponse\x12@\n\x07Publish\x12\x19.isa.redis.PublishRequest\x1a\x1a.isa.redis.PublishResponse\x12\x46\n\tSubscribe\x12\x1b.isa.redis.SubscribeRequest\x1a\x1a.isa.redis.MessageResponse0\x01\x12L\n\x0bUnsubscribe\x12\x1d.isa.redis.UnsubscribeRequest\x1a\x1e.isa.redis.UnsubscribeResponse\x12K\n\x0c\x45xecuteBatch\x12\x1c.isa.redis.RedisBatchRequest\x1a\x1d.isa.redis.RedisBatchResponse\x12R\n\rCreateSession\x12\x1f.isa.redis.CreateSessionRequest\x1a .isa.redis.CreateSessionResponse\x12I\n\nGetSession\x12\x1c.isa.redis.GetSessionRequest\x1a\x1d.isa.redis.GetSessionResponse\x12R\n\rUpdateSession\x12\x1f.isa.redis.UpdateSessionRequest\x1a .isa.redis.UpdateSessionResponse\x12R\n\rDeleteSession\x12\x1f.isa.redis.DeleteSessionRequest\x1a .isa.redis.DeleteSessionResponse\x12O\n\x0cListSessions\x12\x1e.isa.redis.ListSessionsRequest\x1a\x1f.isa.redis.ListSessionsResponse\x12R\n\rGetStatistics\x12\x1f.isa.redis.GetStatisticsRequest\x1a .isa.redis.GetStatisticsResponse\x12I\n\nGetKeyInfo\x12\x1c.isa.redis.GetKeyInfoRequest\x1a\x1d.isa.redis.GetKeyInfoResponse\x12V\n\x0bHealthCheck\x12\".isa.redis.RedisHealthCheckRequest\x1a#.isa.redis.RedisHealthCheckResponseB0Z.github.com/isa-cloud/isa_cloud/api/proto/redisb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'redis_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z.github.com/isa-cloud/isa_cloud/api/proto/redis'
  _globals['_SESSIONINFO_DATAENTRY']._loaded_options = None
  _globals['_SESSIONINFO_DATAENTRY']._serialized_options = b'8\001'
  _globals['_CREATESESSIONREQUEST_DATAENTRY']._loaded_options = None
  _globals['_CREATESESSIONREQUEST_DATAENTRY']._serialized_options = b'8\001'
  _globals['_UPDATESESSIONREQUEST_DATAENTRY']._loaded_options = None
  _globals['_UPDATESESSIONREQUEST_DATAENTRY']._serialized_options = b'8\001'
  _globals['_GETSTATISTICSRESPONSE_KEYTYPEDISTRIBUTIONENTRY']._loaded_options = None
  _globals['_GETSTATISTICSRESPONSE_KEYTYPEDISTRIBUTIONENTRY']._serialized_options = b'8\001'
  _globals['_VALUETYPE']._serialized_start=9600
  _globals['_VALUETYPE']._serialized_end=9717
  _globals['_KEYVALUE']._serialized_start=113
  _globals['_KEYVALUE']._serialized_end=151
  _globals['_HASHFIELD']._serialized_start=153
  _globals['_HASHFIELD']._serialized_end=194
  _globals['_ZSETMEMBER']._serialized_start=196
  _globals['_ZSETMEMBER']._serialized_end=239
  _globals['_SESSIONINFO']._serialized_start=242
  _globals['_SESSIONINFO']._serialized_end=532
  _globals['_SESSIONINFO_DATAENTRY']._serialized_start=489
  _globals['_SESSIONINFO_DATAENTRY']._serialized_end=532
  _globals['_BATCHCOMMAND']._serialized_start=534
  _globals['_BATCHCOMMAND']._serialized_end=642
  _globals['_SETREQUEST']._serialized_start=644
  _globals['_SETREQUEST']._serialized_end=726
  _globals['_SETRESPONSE']._serialized_start=728
  _globals['_SETRESPONSE']._serialized_end=775
  _globals['_GETREQUEST']._serialized_start=777
  _globals['_GETREQUEST']._serialized_end=844
  _globals['_GETRESPONSE']._serialized_start=846
  _globals['_GETRESPONSE']._serialized_end=889
  _globals['_GETMULTIPLEREQUEST']._serialized_start=891
  _globals['_GETMULTIPLEREQUEST']._serialized_end=967
  _globals['_GETMULTIPLERESPONSE']._serialized_start=969
  _globals['_GETMULTIPLERESPONSE']._serialized_end=1027
  _globals['_SETWITHEXPIRATIONREQUEST']._serialized_start=1030
  _globals['_SETWITHEXPIRATIONREQUEST']._serialized_end=1173
  _globals['_INCREMENTREQUEST']._serialized_start=1175
  _globals['_INCREMENTREQUEST']._serialized_end=1263
  _globals['_INCREMENTRESPONSE']._serialized_start=1265
  _globals['_INCREMENTRESPONSE']._serialized_end=1299
  _globals['_DECREMENTREQUEST']._serialized_start=1301
  _globals['_DECREMENTREQUEST']._serialized_end=1389
  _globals['_DECREMENTRESPONSE']._serialized_start=1391
  _globals['_DECREMENTRESPONSE']._serialized_end=1425
  _globals['_APPENDREQUEST']._serialized_start=1427
  _globals['_APPENDREQUEST']._serialized_end=1512
  _globals['_APPENDRESPONSE']._serialized_start=1514
  _globals['_APPENDRESPONSE']._serialized_end=1546
  _globals['_DELETEREQUEST']._serialized_start=1548
  _globals['_DELETEREQUEST']._serialized_end=1618
  _globals['_DELETERESPONSE']._serialized_start=1620
  _globals['_DELETERESPONSE']._serialized_end=1676
  _globals['_DELETEMULTIPLEREQUEST']._serialized_start=1678
  _globals['_DELETEMULTIPLEREQUEST']._serialized_end=1757
  _globals['_EXISTSREQUEST']._serialized_start=1759
  _globals['_EXISTSREQUEST']._serialized_end=1829
  _globals['_EXISTSRESPONSE']._serialized_start=1831
  _globals['_EXISTSRESPONSE']._serialized_end=1863
  _globals['_EXPIREREQUEST']._serialized_start=1865
  _globals['_EXPIREREQUEST']._serialized_end=1982
  _globals['_EXPIRERESPONSE']._serialized_start=1984
  _globals['_EXPIRERESPONSE']._serialized_end=2017
  _globals['_GETTTLREQUEST']._serialized_start=2019
  _globals['_GETTTLREQUEST']._serialized_end=2089
  _globals['_GETTTLRESPONSE']._serialized_start=2091
  _globals['_GETTTLRESPONSE']._serialized_end=2128
  _globals['_RENAMEREQUEST']._serialized_start=2130
  _globals['_RENAMEREQUEST']._serialized_end=2221
  _globals['_RENAMERESPONSE']._serialized_start=2223
  _globals['_RENAMERESPONSE']._serialized_end=2256
  _globals['_LISTKEYSREQUEST']._serialized_start=2258
  _globals['_LISTKEYSREQUEST']._serialized_end=2349
  _globals['_LISTKEYSRESPONSE']._serialized_start=2351
  _globals['_LISTKEYSRESPONSE']._serialized_end=2404
  _globals['_HSETREQUEST']._serialized_start=2406
  _globals['_HSETREQUEST']._serialized_end=2512
  _globals['_HSETRESPONSE']._serialized_start=2514
  _globals['_HSETRESPONSE']._serialized_end=2565
  _globals['_HGETREQUEST']._serialized_start=2567
  _globals['_HGETREQUEST']._serialized_end=2650
  _globals['_HGETRESPONSE']._serialized_start=2652
  _globals['_HGETRESPONSE']._serialized_end=2696
  _globals['_HGETALLREQUEST']._serialized_start=2698
  _globals['_HGETALLREQUEST']._serialized_end=2769
  _globals['_HGETALLRESPONSE']._serialized_start=2771
  _globals['_HGETALLRESPONSE']._serialized_end=2826
  _globals['_HDELETEREQUEST']._serialized_start=2828
  _globals['_HDELETEREQUEST']._serialized_end=2915
  _globals['_HDELETERESPONSE']._serialized_start=2917
  _globals['_HDELETERESPONSE']._serialized_end=2974
  _globals['_HEXISTSREQUEST']._serialized_start=2976
  _globals['_HEXISTSREQUEST']._serialized_end=3062
  _globals['_HEXISTSRESPONSE']._serialized_start=3064
  _globals['_HEXISTSRESPONSE']._serialized_end=3097
  _globals['_HKEYSREQUEST']._serialized_start=3099
  _globals['_HKEYSREQUEST']._serialized_end=3168
  _globals['_HKEYSRESPONSE']._serialized_start=3170
  _globals['_HKEYSRESPONSE']._serialized_end=3201
  _globals['_HVALUESREQUEST']._serialized_start=3203
  _globals['_HVALUESREQUEST']._serialized_end=3274
  _globals['_HVALUESRESPONSE']._serialized_start=3276
  _globals['_HVALUESRESPONSE']._serialized_end=3309
  _globals['_HINCREMENTREQUEST']._serialized_start=3311
  _globals['_HINCREMENTREQUEST']._serialized_end=3415
  _globals['_HINCREMENTRESPONSE']._serialized_start=3417
  _globals['_HINCREMENTRESPONSE']._serialized_end=3452
  _globals['_LPUSHREQUEST']._serialized_start=3454
  _globals['_LPUSHREQUEST']._serialized_end=3539
  _globals['_LPUSHRESPONSE']._serialized_start=3541
  _globals['_LPUSHRESPONSE']._serialized_end=3572
  _globals['_RPUSHREQUEST']._serialized_start=3574
  _globals['_RPUSHREQUEST']._serialized_end=3659
  _globals['_RPUSHRESPONSE']._serialized_start=3661
  _globals['_RPUSHRESPONSE']._serialized_end=3692
  _globals['_LPOPREQUEST']._serialized_start=3694
  _globals['_LPOPREQUEST']._serialized_end=3762
  _globals['_LPOPRESPONSE']._serialized_start=3764
  _globals['_LPOPRESPONSE']._serialized_end=3808
  _globals['_RPOPREQUEST']._serialized_start=3810
  _globals['_RPOPREQUEST']._serialized_end=3878
  _globals['_RPOPRESPONSE']._serialized_start=3880
  _globals['_RPOPRESPONSE']._serialized_end=3924
  _globals['_LRANGEREQUEST']._serialized_start=3926
  _globals['_LRANGEREQUEST']._serialized_end=4025
  _globals['_LRANGERESPONSE']._serialized_start=4027
  _globals['_LRANGERESPONSE']._serialized_end=4059
  _globals['_LLENREQUEST']._serialized_start=4061
  _globals['_LLENREQUEST']._serialized_end=4129
  _globals['_LLENRESPONSE']._serialized_start=4131
  _globals['_LLENRESPONSE']._serialized_end=4161
  _globals['_LINDEXREQUEST']._serialized_start=4163
  _globals['_LINDEXREQUEST']._serialized_end=4248
  _globals['_LINDEXRESPONSE']._serialized_start=4250
  _globals['_LINDEXRESPONSE']._serialized_end=4296
  _globals['_LTRIMREQUEST']._serialized_start=4298
  _globals['_LTRIMREQUEST']._serialized_end=4396
  _globals['_LTRIMRESPONSE']._serialized_start=4398
  _globals['_LTRIMRESPONSE']._serialized_end=4430
  _globals['_SADDREQUEST']._serialized_start=4432
  _globals['_SADDREQUEST']._serialized_end=4517
  _globals['_SADDRESPONSE']._serialized_start=4519
  _globals['_SADDRESPONSE']._serialized_end=4554
  _globals['_SREMOVEREQUEST']._serialized_start=4556
  _globals['_SREMOVEREQUEST']._serialized_end=4644
  _globals['_SREMOVERESPONSE']._serialized_start=4646
  _globals['_SREMOVERESPONSE']._serialized_end=4686
  _globals['_SMEMBERSREQUEST']._serialized_start=4688
  _globals['_SMEMBERSREQUEST']._serialized_end=4760
  _globals['_SMEMBERSRESPONSE']._serialized_start=4762
  _globals['_SMEMBERSRESPONSE']._serialized_end=4797
  _globals['_SISMEMBERREQUEST']._serialized_start=4799
  _globals['_SISMEMBERREQUEST']._serialized_end=4888
  _globals['_SISMEMBERRESPONSE']._serialized_start=4890
  _globals['_SISMEMBERRESPONSE']._serialized_end=4928
  _globals['_SCARDREQUEST']._serialized_start=4930
  _globals['_SCARDREQUEST']._serialized_end=4999
  _globals['_SCARDRESPONSE']._serialized_start=5001
  _globals['_SCARDRESPONSE']._serialized_end=5031
  _globals['_SUNIONREQUEST']._serialized_start=5033
  _globals['_SUNIONREQUEST']._serialized_end=5104
  _globals['_SUNIONRESPONSE']._serialized_start=5106
  _globals['_SUNIONRESPONSE']._serialized_end=5139
  _globals['_SINTERREQUEST']._serialized_start=5141
  _globals['_SINTERREQUEST']._serialized_end=5212
  _globals['_SINTERRESPONSE']._serialized_start=5214
  _globals['_SINTERRESPONSE']._serialized_end=5247
  _globals['_SDIFFREQUEST']._serialized_start=5249
  _globals['_SDIFFREQUEST']._serialized_end=5319
  _globals['_SDIFFRESPONSE']._serialized_start=5321
  _globals['_SDIFFRESPONSE']._serialized_end=5353
  _globals['_ZADDREQUEST']._serialized_start=5355
  _globals['_ZADDREQUEST']._serialized_end=5463
  _globals['_ZADDRESPONSE']._serialized_start=5465
  _globals['_ZADDRESPONSE']._serialized_end=5500
  _globals['_ZREMOVEREQUEST']._serialized_start=5502
  _globals['_ZREMOVEREQUEST']._serialized_end=5590
  _globals['_ZREMOVERESPONSE']._serialized_start=5592
  _globals['_ZREMOVERESPONSE']._serialized_end=5632
  _globals['_ZRANGEREQUEST']._serialized_start=5634
  _globals['_ZRANGEREQUEST']._serialized_end=5754
  _globals['_ZRANGERESPONSE']._serialized_start=5756
  _globals['_ZRANGERESPONSE']._serialized_end=5812
  _globals['_ZRANGEBYSCOREREQUEST']._serialized_start=5815
  _globals['_ZRANGEBYSCOREREQUEST']._serialized_end=5961
  _globals['_ZRANGEBYSCORERESPONSE']._serialized_start=5963
  _globals['_ZRANGEBYSCORERESPONSE']._serialized_end=6026
  _globals['_ZRANKREQUEST']._serialized_start=6028
  _globals['_ZRANKREQUEST']._serialized_end=6113
  _globals['_ZRANKRESPONSE']._serialized_start=6115
  _globals['_ZRANKRESPONSE']._serialized_end=6159
  _globals['_ZSCOREREQUEST']._serialized_start=6161
  _globals['_ZSCOREREQUEST']._serialized_end=6247
  _globals['_ZSCORERESPONSE']._serialized_start=6249
  _globals['_ZSCORERESPONSE']._serialized_end=6295
  _globals['_ZCARDREQUEST']._serialized_start=6297
  _globals['_ZCARDREQUEST']._serialized_end=6366
  _globals['_ZCARDRESPONSE']._serialized_start=6368
  _globals['_ZCARDRESPONSE']._serialized_end=6398
  _globals['_ZINCREMENTREQUEST']._serialized_start=6400
  _globals['_ZINCREMENTREQUEST']._serialized_end=6505
  _globals['_ZINCREMENTRESPONSE']._serialized_start=6507
  _globals['_ZINCREMENTRESPONSE']._serialized_end=6542
  _globals['_ACQUIRELOCKREQUEST']._serialized_start=6545
  _globals['_ACQUIRELOCKREQUEST']._serialized_end=6714
  _globals['_ACQUIRELOCKRESPONSE']._serialized_start=6716
  _globals['_ACQUIRELOCKRESPONSE']._serialized_end=6820
  _globals['_RELEASELOCKREQUEST']._serialized_start=6822
  _globals['_RELEASELOCKREQUEST']._serialized_end=6919
  _globals['_RELEASELOCKRESPONSE']._serialized_start=6921
  _globals['_RELEASELOCKRESPONSE']._serialized_end=6960
  _globals['_RENEWLOCKREQUEST']._serialized_start=6963
  _globals['_RENEWLOCKREQUEST']._serialized_end=7098
  _globals['_RENEWLOCKRESPONSE']._serialized_start=7100
  _globals['_RENEWLOCKRESPONSE']._serialized_end=7184
  _globals['_PUBLISHREQUEST']._serialized_start=7186
  _globals['_PUBLISHREQUEST']._serialized_end=7278
  _globals['_PUBLISHRESPONSE']._serialized_start=7280
  _globals['_PUBLISHRESPONSE']._serialized_end=7323
  _globals['_SUBSCRIBEREQUEST']._serialized_start=7325
  _globals['_SUBSCRIBEREQUEST']._serialized_end=7403
  _globals['_MESSAGERESPONSE']._serialized_start=7405
  _globals['_MESSAGERESPONSE']._serialized_end=7503
  _globals['_UNSUBSCRIBEREQUEST']._serialized_start=7505
  _globals['_UNSUBSCRIBEREQUEST']._serialized_end=7585
  _globals['_UNSUBSCRIBERESPONSE']._serialized_start=7587
  _globals['_UNSUBSCRIBERESPONSE']._serialized_end=7625
  _globals['_REDISBATCHREQUEST']._serialized_start=7627
  _globals['_REDISBATCHREQUEST']._serialized_end=7731
  _globals['_REDISBATCHRESPONSE']._serialized_start=7733
  _globals['_REDISBATCHRESPONSE']._serialized_end=7810
  _globals['_CREATESESSIONREQUEST']._serialized_start=7813
  _globals['_CREATESESSIONREQUEST']._serialized_end=8019
  _globals['_CREATESESSIONREQUEST_DATAENTRY']._serialized_start=489
  _globals['_CREATESESSIONREQUEST_DATAENTRY']._serialized_end=532
  _globals['_CREATESESSIONRESPONSE']._serialized_start=8021
  _globals['_CREATESESSIONRESPONSE']._serialized_end=8112
  _globals['_GETSESSIONREQUEST']._serialized_start=8114
  _globals['_GETSESSIONREQUEST']._serialized_end=8170
  _globals['_GETSESSIONRESPONSE']._serialized_start=8172
  _globals['_GETSESSIONRESPONSE']._serialized_end=8248
  _globals['_UPDATESESSIONREQUEST']._serialized_start=8251
  _globals['_UPDATESESSIONREQUEST']._serialized_end=8432
  _globals['_UPDATESESSIONREQUEST_DATAENTRY']._serialized_start=489
  _globals['_UPDATESESSIONREQUEST_DATAENTRY']._serialized_end=532
  _globals['_UPDATESESSIONRESPONSE']._serialized_start=8434
  _globals['_UPDATESESSIONRESPONSE']._serialized_end=8474
  _globals['_DELETESESSIONREQUEST']._serialized_start=8476
  _globals['_DELETESESSIONREQUEST']._serialized_end=8535
  _globals['_DELETESESSIONRESPONSE']._serialized_start=8537
  _globals['_DELETESESSIONRESPONSE']._serialized_end=8577
  _globals['_LISTSESSIONSREQUEST']._serialized_start=8579
  _globals['_LISTSESSIONSREQUEST']._serialized_end=8642
  _globals['_LISTSESSIONSRESPONSE']._serialized_start=8644
  _globals['_LISTSESSIONSRESPONSE']._serialized_end=8708
  _globals['_GETSTATISTICSREQUEST']._serialized_start=8710
  _globals['_GETSTATISTICSREQUEST']._serialized_end=8774
  _globals['_GETSTATISTICSRESPONSE']._serialized_start=8777
  _globals['_GETSTATISTICSRESPONSE']._serialized_end=9073
  _globals['_GETSTATISTICSRESPONSE_KEYTYPEDISTRIBUTIONENTRY']._serialized_start=9015
  _globals['_GETSTATISTICSRESPONSE_KEYTYPEDISTRIBUTIONENTRY']._serialized_end=9073
  _globals['_GETKEYINFOREQUEST']._serialized_start=9075
  _globals['_GETKEYINFOREQUEST']._serialized_end=9149
  _globals['_GETKEYINFORESPONSE']._serialized_start=9152
  _globals['_GETKEYINFORESPONSE']._serialized_end=9364
  _globals['_REDISHEALTHCHECKREQUEST']._serialized_start=9366
  _globals['_REDISHEALTHCHECKREQUEST']._serialized_end=9411
  _globals['_REDISHEALTHCHECKRESPONSE']._serialized_start=9414
  _globals['_REDISHEALTHCHECKRESPONSE']._serialized_end=9598
  _globals['_REDISSERVICE']._serialized_start=9720
  _globals['_REDISSERVICE']._serialized_end=13876
# @@protoc_insertion_point(module_scope)
