# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neo4j_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'neo4j_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13neo4j_service.proto\x12\tisa.neo4j\x1a\x0c\x63ommon.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"O\n\x04Node\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0e\n\x06labels\x18\x02 \x03(\t\x12+\n\nproperties\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x81\x01\n\x0cRelationship\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x15\n\rstart_node_id\x18\x02 \x01(\x03\x12\x13\n\x0b\x65nd_node_id\x18\x03 \x01(\x03\x12\x0c\n\x04type\x18\x04 \x01(\t\x12+\n\nproperties\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"f\n\x04Path\x12\x1e\n\x05nodes\x18\x01 \x03(\x0b\x32\x0f.isa.neo4j.Node\x12.\n\rrelationships\x18\x02 \x03(\x0b\x32\x17.isa.neo4j.Relationship\x12\x0e\n\x06length\x18\x03 \x01(\x05\"\x84\x01\n\tResultRow\x12\x30\n\x06\x66ields\x18\x01 \x03(\x0b\x32 .isa.neo4j.ResultRow.FieldsEntry\x1a\x45\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\"\xd7\x02\n\x0cQuerySummary\x12\x12\n\nquery_type\x18\x01 \x01(\t\x12\x15\n\rnodes_created\x18\x02 \x01(\x05\x12\x15\n\rnodes_deleted\x18\x03 \x01(\x05\x12\x1d\n\x15relationships_created\x18\x04 \x01(\x05\x12\x1d\n\x15relationships_deleted\x18\x05 \x01(\x05\x12\x16\n\x0eproperties_set\x18\x06 \x01(\x05\x12\x14\n\x0clabels_added\x18\x07 \x01(\x05\x12\x16\n\x0elabels_removed\x18\x08 \x01(\x05\x12\x15\n\rindexes_added\x18\t \x01(\x05\x12\x17\n\x0findexes_removed\x18\n \x01(\x05\x12\x19\n\x11\x63onstraints_added\x18\x0b \x01(\x05\x12\x1b\n\x13\x63onstraints_removed\x18\x0c \x01(\x05\x12\x19\n\x11\x65xecution_time_ms\x18\r \x01(\x01\"\xa9\x02\n\x10RunCypherRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x0e\n\x06\x63ypher\x18\x02 \x01(\t\x12?\n\nparameters\x18\x03 \x03(\x0b\x32+.isa.neo4j.RunCypherRequest.ParametersEntry\x12\x15\n\x08\x64\x61tabase\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x17\n\ntimeout_ms\x18\x05 \x01(\x05H\x01\x88\x01\x01\x1aI\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\x42\x0b\n\t_databaseB\r\n\x0b_timeout_ms\"\xa2\x01\n\x11RunCypherResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\"\n\x04rows\x18\x02 \x03(\x0b\x32\x14.isa.neo4j.ResultRow\x12\x0f\n\x07\x63olumns\x18\x03 \x03(\t\x12(\n\x07summary\x18\x04 \x01(\x0b\x32\x17.isa.neo4j.QuerySummary\"\xb1\x02\n\x14RunCypherReadRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x0e\n\x06\x63ypher\x18\x02 \x01(\t\x12\x43\n\nparameters\x18\x03 \x03(\x0b\x32/.isa.neo4j.RunCypherReadRequest.ParametersEntry\x12\x15\n\x08\x64\x61tabase\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x17\n\ntimeout_ms\x18\x05 \x01(\x05H\x01\x88\x01\x01\x1aI\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\x42\x0b\n\t_databaseB\r\n\x0b_timeout_ms\"\xa6\x01\n\x15RunCypherReadResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\"\n\x04rows\x18\x02 \x03(\x0b\x32\x14.isa.neo4j.ResultRow\x12\x0f\n\x07\x63olumns\x18\x03 \x03(\t\x12(\n\x07summary\x18\x04 \x01(\x0b\x32\x17.isa.neo4j.QuerySummary\"\xb3\x02\n\x15RunCypherWriteRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x0e\n\x06\x63ypher\x18\x02 \x01(\t\x12\x44\n\nparameters\x18\x03 \x03(\x0b\x32\x30.isa.neo4j.RunCypherWriteRequest.ParametersEntry\x12\x15\n\x08\x64\x61tabase\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x17\n\ntimeout_ms\x18\x05 \x01(\x05H\x01\x88\x01\x01\x1aI\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\x42\x0b\n\t_databaseB\r\n\x0b_timeout_ms\"\xa7\x01\n\x16RunCypherWriteResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\"\n\x04rows\x18\x02 \x03(\x0b\x32\x14.isa.neo4j.ResultRow\x12\x0f\n\x07\x63olumns\x18\x03 \x03(\t\x12(\n\x07summary\x18\x04 \x01(\x0b\x32\x17.isa.neo4j.QuerySummary\"\x93\x01\n\x15RunCypherBatchRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\'\n\x07queries\x18\x02 \x03(\x0b\x32\x16.isa.neo4j.CypherQuery\x12\x15\n\x08\x64\x61tabase\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_database\"\xa4\x01\n\x0b\x43ypherQuery\x12\x0e\n\x06\x63ypher\x18\x01 \x01(\t\x12:\n\nparameters\x18\x02 \x03(\x0b\x32&.isa.neo4j.CypherQuery.ParametersEntry\x1aI\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\"w\n\x16RunCypherBatchResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12-\n\x07results\x18\x02 \x03(\x0b\x32\x1c.isa.neo4j.RunCypherResponse\"\xa3\x01\n\x11\x43reateNodeRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x0e\n\x06labels\x18\x02 \x03(\t\x12+\n\nproperties\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\x08\x64\x61tabase\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_database\"c\n\x12\x43reateNodeResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x1d\n\x04node\x18\x02 \x01(\x0b\x32\x0f.isa.neo4j.Node\"t\n\x0eGetNodeRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x0f\n\x07node_id\x18\x02 \x01(\x03\x12\x15\n\x08\x64\x61tabase\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_database\"o\n\x0fGetNodeResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x1d\n\x04node\x18\x02 \x01(\x0b\x32\x0f.isa.neo4j.Node\x12\r\n\x05\x66ound\x18\x03 \x01(\x08\"\xc6\x01\n\x11UpdateNodeRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x0f\n\x07node_id\x18\x02 \x01(\x03\x12+\n\nproperties\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x07replace\x18\x04 \x01(\x08H\x00\x88\x01\x01\x12\x15\n\x08\x64\x61tabase\x18\x05 \x01(\tH\x01\x88\x01\x01\x42\n\n\x08_replaceB\x0b\n\t_database\"c\n\x12UpdateNodeResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x1d\n\x04node\x18\x02 \x01(\x0b\x32\x0f.isa.neo4j.Node\"\x97\x01\n\x11\x44\x65leteNodeRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x0f\n\x07node_id\x18\x02 \x01(\x03\x12\x13\n\x06\x64\x65tach\x18\x03 \x01(\x08H\x00\x88\x01\x01\x12\x15\n\x08\x64\x61tabase\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\t\n\x07_detachB\x0b\n\t_database\"t\n\x12\x44\x65leteNodeResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x1d\n\x15relationships_deleted\x18\x03 \x01(\x05\"\xd9\x01\n\x10MergeNodeRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x0e\n\x06labels\x18\x02 \x03(\t\x12\x31\n\x10match_properties\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12/\n\x0eset_properties\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\x08\x64\x61tabase\x18\x05 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_database\"s\n\x11MergeNodeResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x1d\n\x04node\x18\x02 \x01(\x0b\x32\x0f.isa.neo4j.Node\x12\x0f\n\x07\x63reated\x18\x03 \x01(\x08\"\xea\x01\n\x10\x46indNodesRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x12\n\x05label\x18\x02 \x01(\tH\x00\x88\x01\x01\x12+\n\nproperties\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\x05limit\x18\x04 \x01(\x05H\x01\x88\x01\x01\x12\x11\n\x04skip\x18\x05 \x01(\x05H\x02\x88\x01\x01\x12\x15\n\x08\x64\x61tabase\x18\x06 \x01(\tH\x03\x88\x01\x01\x42\x08\n\x06_labelB\x08\n\x06_limitB\x07\n\x05_skipB\x0b\n\t_database\"x\n\x11\x46indNodesResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x1e\n\x05nodes\x18\x02 \x03(\x0b\x32\x0f.isa.neo4j.Node\x12\x13\n\x0btotal_count\x18\x03 \x01(\x05\"\xd5\x01\n\x19\x43reateRelationshipRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x15\n\rstart_node_id\x18\x02 \x01(\x03\x12\x13\n\x0b\x65nd_node_id\x18\x03 \x01(\x03\x12\x0c\n\x04type\x18\x04 \x01(\t\x12+\n\nproperties\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\x08\x64\x61tabase\x18\x06 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_database\"{\n\x1a\x43reateRelationshipResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12-\n\x0crelationship\x18\x02 \x01(\x0b\x32\x17.isa.neo4j.Relationship\"\x84\x01\n\x16GetRelationshipRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0frelationship_id\x18\x02 \x01(\x03\x12\x15\n\x08\x64\x61tabase\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_database\"\x87\x01\n\x17GetRelationshipResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12-\n\x0crelationship\x18\x02 \x01(\x0b\x32\x17.isa.neo4j.Relationship\x12\r\n\x05\x66ound\x18\x03 \x01(\x08\"\xd6\x01\n\x19UpdateRelationshipRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0frelationship_id\x18\x02 \x01(\x03\x12+\n\nproperties\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x07replace\x18\x04 \x01(\x08H\x00\x88\x01\x01\x12\x15\n\x08\x64\x61tabase\x18\x05 \x01(\tH\x01\x88\x01\x01\x42\n\n\x08_replaceB\x0b\n\t_database\"{\n\x1aUpdateRelationshipResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12-\n\x0crelationship\x18\x02 \x01(\x0b\x32\x17.isa.neo4j.Relationship\"\x87\x01\n\x19\x44\x65leteRelationshipRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0frelationship_id\x18\x02 \x01(\x03\x12\x15\n\x08\x64\x61tabase\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_database\"]\n\x1a\x44\x65leteRelationshipResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07success\x18\x02 \x01(\x08\"\xac\x02\n\x18\x46indRelationshipsRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x1a\n\rstart_node_id\x18\x02 \x01(\x03H\x00\x88\x01\x01\x12\x18\n\x0b\x65nd_node_id\x18\x03 \x01(\x03H\x01\x88\x01\x01\x12\x11\n\x04type\x18\x04 \x01(\tH\x02\x88\x01\x01\x12+\n\nproperties\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\x05limit\x18\x06 \x01(\x05H\x03\x88\x01\x01\x12\x15\n\x08\x64\x61tabase\x18\x07 \x01(\tH\x04\x88\x01\x01\x42\x10\n\x0e_start_node_idB\x0e\n\x0c_end_node_idB\x07\n\x05_typeB\x08\n\x06_limitB\x0b\n\t_database\"\x90\x01\n\x19\x46indRelationshipsResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12.\n\rrelationships\x18\x02 \x03(\x0b\x32\x17.isa.neo4j.Relationship\x12\x13\n\x0btotal_count\x18\x03 \x01(\x05\"\xfb\x01\n\x13GetNeighborsRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x0f\n\x07node_id\x18\x02 \x01(\x03\x12\x1e\n\x11relationship_type\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tdirection\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tmax_depth\x18\x05 \x01(\x05H\x02\x88\x01\x01\x12\x15\n\x08\x64\x61tabase\x18\x06 \x01(\tH\x03\x88\x01\x01\x42\x14\n\x12_relationship_typeB\x0c\n\n_directionB\x0c\n\n_max_depthB\x0b\n\t_database\"\x96\x01\n\x14GetNeighborsResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x1e\n\x05nodes\x18\x02 \x03(\x0b\x32\x0f.isa.neo4j.Node\x12.\n\rrelationships\x18\x03 \x03(\x0b\x32\x17.isa.neo4j.Relationship\"\xeb\x01\n\x0eGetPathRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x15\n\rstart_node_id\x18\x02 \x01(\x03\x12\x13\n\x0b\x65nd_node_id\x18\x03 \x01(\x03\x12\x1e\n\x11relationship_type\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tmax_depth\x18\x05 \x01(\x05H\x01\x88\x01\x01\x12\x15\n\x08\x64\x61tabase\x18\x06 \x01(\tH\x02\x88\x01\x01\x42\x14\n\x12_relationship_typeB\x0c\n\n_max_depthB\x0b\n\t_database\"o\n\x0fGetPathResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x1d\n\x04path\x18\x02 \x01(\x0b\x32\x0f.isa.neo4j.Path\x12\r\n\x05\x66ound\x18\x03 \x01(\x08\"\xf3\x01\n\x16GetShortestPathRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x15\n\rstart_node_id\x18\x02 \x01(\x03\x12\x13\n\x0b\x65nd_node_id\x18\x03 \x01(\x03\x12\x1e\n\x11relationship_type\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tmax_depth\x18\x05 \x01(\x05H\x01\x88\x01\x01\x12\x15\n\x08\x64\x61tabase\x18\x06 \x01(\tH\x02\x88\x01\x01\x42\x14\n\x12_relationship_typeB\x0c\n\n_max_depthB\x0b\n\t_database\"w\n\x17GetShortestPathResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x1d\n\x04path\x18\x02 \x01(\x0b\x32\x0f.isa.neo4j.Path\x12\r\n\x05\x66ound\x18\x03 \x01(\x08\"\x8d\x02\n\x12GetAllPathsRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x15\n\rstart_node_id\x18\x02 \x01(\x03\x12\x13\n\x0b\x65nd_node_id\x18\x03 \x01(\x03\x12\x1e\n\x11relationship_type\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tmax_depth\x18\x05 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05limit\x18\x06 \x01(\x05H\x02\x88\x01\x01\x12\x15\n\x08\x64\x61tabase\x18\x07 \x01(\tH\x03\x88\x01\x01\x42\x14\n\x12_relationship_typeB\x0c\n\n_max_depthB\x08\n\x06_limitB\x0b\n\t_database\"e\n\x13GetAllPathsResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x1e\n\x05paths\x18\x02 \x03(\x0b\x32\x0f.isa.neo4j.Path\"\x9c\x02\n\x0fPageRankRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x12\n\x05label\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11relationship_type\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x0emax_iterations\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x1d\n\x10\x64\x61mpening_factor\x18\x05 \x01(\x01H\x03\x88\x01\x01\x12\x15\n\x08\x64\x61tabase\x18\x06 \x01(\tH\x04\x88\x01\x01\x42\x08\n\x06_labelB\x14\n\x12_relationship_typeB\x11\n\x0f_max_iterationsB\x13\n\x11_dampening_factorB\x0b\n\t_database\"\xaa\x01\n\x10PageRankResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x37\n\x06scores\x18\x02 \x03(\x0b\x32\'.isa.neo4j.PageRankResponse.ScoresEntry\x1a-\n\x0bScoresEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\"\xc5\x01\n\x1c\x42\x65tweennessCentralityRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x12\n\x05label\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11relationship_type\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08\x64\x61tabase\x18\x04 \x01(\tH\x02\x88\x01\x01\x42\x08\n\x06_labelB\x14\n\x12_relationship_typeB\x0b\n\t_database\"\xc4\x01\n\x1d\x42\x65tweennessCentralityResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x44\n\x06scores\x18\x02 \x03(\x0b\x32\x34.isa.neo4j.BetweennessCentralityResponse.ScoresEntry\x1a-\n\x0bScoresEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\"\xe8\x01\n\x19\x43ommunityDetectionRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x12\n\x05label\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11relationship_type\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x16\n\talgorithm\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x15\n\x08\x64\x61tabase\x18\x05 \x01(\tH\x03\x88\x01\x01\x42\x08\n\x06_labelB\x14\n\x12_relationship_typeB\x0c\n\n_algorithmB\x0b\n\t_database\"\xe6\x01\n\x1a\x43ommunityDetectionResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12K\n\x0b\x63ommunities\x18\x02 \x03(\x0b\x32\x36.isa.neo4j.CommunityDetectionResponse.CommunitiesEntry\x12\x17\n\x0fnum_communities\x18\x03 \x01(\x05\x1a\x32\n\x10\x43ommunitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xc6\x01\n\x12\x43reateIndexRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x12\n\nindex_name\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x12\n\nproperties\x18\x04 \x03(\t\x12\x17\n\nindex_type\x18\x05 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x64\x61tabase\x18\x06 \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b_index_typeB\x0b\n\t_database\"V\n\x13\x43reateIndexResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07success\x18\x02 \x01(\x08\"y\n\x10\x44ropIndexRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x12\n\nindex_name\x18\x02 \x01(\t\x12\x15\n\x08\x64\x61tabase\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_database\"T\n\x11\x44ropIndexResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07success\x18\x02 \x01(\x08\"g\n\x12ListIndexesRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x15\n\x08\x64\x61tabase\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_database\"l\n\x13ListIndexesResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12%\n\x07indexes\x18\x02 \x03(\x0b\x32\x14.isa.neo4j.IndexInfo\"c\n\tIndexInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x17\n\x0flabels_or_types\x18\x03 \x03(\t\x12\x12\n\nproperties\x18\x04 \x03(\t\x12\r\n\x05state\x18\x05 \x01(\t\"\xc1\x01\n\x17\x43reateConstraintRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63onstraint_name\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x12\n\nproperties\x18\x04 \x03(\t\x12\x17\n\x0f\x63onstraint_type\x18\x05 \x01(\t\x12\x15\n\x08\x64\x61tabase\x18\x06 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_database\"[\n\x18\x43reateConstraintResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07success\x18\x02 \x01(\x08\"\x83\x01\n\x15\x44ropConstraintRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63onstraint_name\x18\x02 \x01(\t\x12\x15\n\x08\x64\x61tabase\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_database\"Y\n\x16\x44ropConstraintResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07success\x18\x02 \x01(\x08\"k\n\x16ListConstraintsRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x15\n\x08\x64\x61tabase\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_database\"y\n\x17ListConstraintsResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12.\n\x0b\x63onstraints\x18\x02 \x03(\x0b\x32\x19.isa.neo4j.ConstraintInfo\"O\n\x0e\x43onstraintInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x12\n\nproperties\x18\x04 \x03(\t\"\x94\x01\n\x17\x42\x65ginTransactionRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x15\n\x08\x64\x61tabase\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x17\n\ntimeout_ms\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\x0b\n\t_databaseB\r\n\x0b_timeout_ms\"b\n\x18\x42\x65ginTransactionResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x16\n\x0etransaction_id\x18\x02 \x01(\t\"a\n\x18\x43ommitTransactionRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x16\n\x0etransaction_id\x18\x02 \x01(\t\"\\\n\x19\x43ommitTransactionResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07success\x18\x02 \x01(\x08\"c\n\x1aRollbackTransactionRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x16\n\x0etransaction_id\x18\x02 \x01(\t\"^\n\x1bRollbackTransactionResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07success\x18\x02 \x01(\x08\"k\n\x16GetDatabaseInfoRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x15\n\x08\x64\x61tabase\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_database\"\xd9\x01\n\x17GetDatabaseInfoResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nnode_count\x18\x03 \x01(\x03\x12\x1a\n\x12relationship_count\x18\x04 \x01(\x03\x12\x13\n\x0blabel_count\x18\x05 \x01(\x03\x12\x1f\n\x17relationship_type_count\x18\x06 \x01(\x03\x12\x1a\n\x12property_key_count\x18\x07 \x01(\x03\"E\n\x14ListDatabasesRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\"s\n\x15ListDatabasesResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12*\n\tdatabases\x18\x02 \x03(\x0b\x32\x17.isa.neo4j.DatabaseInfo\"=\n\x0c\x44\x61tabaseInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x03 \x01(\x08\"i\n\x14GetStatisticsRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x15\n\x08\x64\x61tabase\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_database\"t\n\x15GetStatisticsResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12+\n\nstatistics\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"H\n\x17Neo4jHealthCheckRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\"}\n\x18Neo4jHealthCheckResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07healthy\x18\x02 \x01(\x08\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x0f\n\x07\x65\x64ition\x18\x04 \x01(\t2\xac\x17\n\x0cNeo4jService\x12\x46\n\tRunCypher\x12\x1b.isa.neo4j.RunCypherRequest\x1a\x1c.isa.neo4j.RunCypherResponse\x12R\n\rRunCypherRead\x12\x1f.isa.neo4j.RunCypherReadRequest\x1a .isa.neo4j.RunCypherReadResponse\x12U\n\x0eRunCypherWrite\x12 .isa.neo4j.RunCypherWriteRequest\x1a!.isa.neo4j.RunCypherWriteResponse\x12U\n\x0eRunCypherBatch\x12 .isa.neo4j.RunCypherBatchRequest\x1a!.isa.neo4j.RunCypherBatchResponse\x12I\n\nCreateNode\x12\x1c.isa.neo4j.CreateNodeRequest\x1a\x1d.isa.neo4j.CreateNodeResponse\x12@\n\x07GetNode\x12\x19.isa.neo4j.GetNodeRequest\x1a\x1a.isa.neo4j.GetNodeResponse\x12I\n\nUpdateNode\x12\x1c.isa.neo4j.UpdateNodeRequest\x1a\x1d.isa.neo4j.UpdateNodeResponse\x12I\n\nDeleteNode\x12\x1c.isa.neo4j.DeleteNodeRequest\x1a\x1d.isa.neo4j.DeleteNodeResponse\x12\x46\n\tMergeNode\x12\x1b.isa.neo4j.MergeNodeRequest\x1a\x1c.isa.neo4j.MergeNodeResponse\x12\x46\n\tFindNodes\x12\x1b.isa.neo4j.FindNodesRequest\x1a\x1c.isa.neo4j.FindNodesResponse\x12\x61\n\x12\x43reateRelationship\x12$.isa.neo4j.CreateRelationshipRequest\x1a%.isa.neo4j.CreateRelationshipResponse\x12X\n\x0fGetRelationship\x12!.isa.neo4j.GetRelationshipRequest\x1a\".isa.neo4j.GetRelationshipResponse\x12\x61\n\x12UpdateRelationship\x12$.isa.neo4j.UpdateRelationshipRequest\x1a%.isa.neo4j.UpdateRelationshipResponse\x12\x61\n\x12\x44\x65leteRelationship\x12$.isa.neo4j.DeleteRelationshipRequest\x1a%.isa.neo4j.DeleteRelationshipResponse\x12^\n\x11\x46indRelationships\x12#.isa.neo4j.FindRelationshipsRequest\x1a$.isa.neo4j.FindRelationshipsResponse\x12O\n\x0cGetNeighbors\x12\x1e.isa.neo4j.GetNeighborsRequest\x1a\x1f.isa.neo4j.GetNeighborsResponse\x12@\n\x07GetPath\x12\x19.isa.neo4j.GetPathRequest\x1a\x1a.isa.neo4j.GetPathResponse\x12X\n\x0fGetShortestPath\x12!.isa.neo4j.GetShortestPathRequest\x1a\".isa.neo4j.GetShortestPathResponse\x12L\n\x0bGetAllPaths\x12\x1d.isa.neo4j.GetAllPathsRequest\x1a\x1e.isa.neo4j.GetAllPathsResponse\x12\x43\n\x08PageRank\x12\x1a.isa.neo4j.PageRankRequest\x1a\x1b.isa.neo4j.PageRankResponse\x12j\n\x15\x42\x65tweennessCentrality\x12\'.isa.neo4j.BetweennessCentralityRequest\x1a(.isa.neo4j.BetweennessCentralityResponse\x12\x61\n\x12\x43ommunityDetection\x12$.isa.neo4j.CommunityDetectionRequest\x1a%.isa.neo4j.CommunityDetectionResponse\x12L\n\x0b\x43reateIndex\x12\x1d.isa.neo4j.CreateIndexRequest\x1a\x1e.isa.neo4j.CreateIndexResponse\x12\x46\n\tDropIndex\x12\x1b.isa.neo4j.DropIndexRequest\x1a\x1c.isa.neo4j.DropIndexResponse\x12L\n\x0bListIndexes\x12\x1d.isa.neo4j.ListIndexesRequest\x1a\x1e.isa.neo4j.ListIndexesResponse\x12[\n\x10\x43reateConstraint\x12\".isa.neo4j.CreateConstraintRequest\x1a#.isa.neo4j.CreateConstraintResponse\x12U\n\x0e\x44ropConstraint\x12 .isa.neo4j.DropConstraintRequest\x1a!.isa.neo4j.DropConstraintResponse\x12X\n\x0fListConstraints\x12!.isa.neo4j.ListConstraintsRequest\x1a\".isa.neo4j.ListConstraintsResponse\x12[\n\x10\x42\x65ginTransaction\x12\".isa.neo4j.BeginTransactionRequest\x1a#.isa.neo4j.BeginTransactionResponse\x12^\n\x11\x43ommitTransaction\x12#.isa.neo4j.CommitTransactionRequest\x1a$.isa.neo4j.CommitTransactionResponse\x12\x64\n\x13RollbackTransaction\x12%.isa.neo4j.RollbackTransactionRequest\x1a&.isa.neo4j.RollbackTransactionResponse\x12X\n\x0fGetDatabaseInfo\x12!.isa.neo4j.GetDatabaseInfoRequest\x1a\".isa.neo4j.GetDatabaseInfoResponse\x12R\n\rListDatabases\x12\x1f.isa.neo4j.ListDatabasesRequest\x1a .isa.neo4j.ListDatabasesResponse\x12R\n\rGetStatistics\x12\x1f.isa.neo4j.GetStatisticsRequest\x1a .isa.neo4j.GetStatisticsResponse\x12V\n\x0bHealthCheck\x12\".isa.neo4j.Neo4jHealthCheckRequest\x1a#.isa.neo4j.Neo4jHealthCheckResponseB0Z.github.com/isa-cloud/isa_cloud/api/proto/neo4jb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neo4j_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z.github.com/isa-cloud/isa_cloud/api/proto/neo4j'
  _globals['_RESULTROW_FIELDSENTRY']._loaded_options = None
  _globals['_RESULTROW_FIELDSENTRY']._serialized_options = b'8\001'
  _globals['_RUNCYPHERREQUEST_PARAMETERSENTRY']._loaded_options = None
  _globals['_RUNCYPHERREQUEST_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_RUNCYPHERREADREQUEST_PARAMETERSENTRY']._loaded_options = None
  _globals['_RUNCYPHERREADREQUEST_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_RUNCYPHERWRITEREQUEST_PARAMETERSENTRY']._loaded_options = None
  _globals['_RUNCYPHERWRITEREQUEST_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_CYPHERQUERY_PARAMETERSENTRY']._loaded_options = None
  _globals['_CYPHERQUERY_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_PAGERANKRESPONSE_SCORESENTRY']._loaded_options = None
  _globals['_PAGERANKRESPONSE_SCORESENTRY']._serialized_options = b'8\001'
  _globals['_BETWEENNESSCENTRALITYRESPONSE_SCORESENTRY']._loaded_options = None
  _globals['_BETWEENNESSCENTRALITYRESPONSE_SCORESENTRY']._serialized_options = b'8\001'
  _globals['_COMMUNITYDETECTIONRESPONSE_COMMUNITIESENTRY']._loaded_options = None
  _globals['_COMMUNITYDETECTIONRESPONSE_COMMUNITIESENTRY']._serialized_options = b'8\001'
  _globals['_NODE']._serialized_start=111
  _globals['_NODE']._serialized_end=190
  _globals['_RELATIONSHIP']._serialized_start=193
  _globals['_RELATIONSHIP']._serialized_end=322
  _globals['_PATH']._serialized_start=324
  _globals['_PATH']._serialized_end=426
  _globals['_RESULTROW']._serialized_start=429
  _globals['_RESULTROW']._serialized_end=561
  _globals['_RESULTROW_FIELDSENTRY']._serialized_start=492
  _globals['_RESULTROW_FIELDSENTRY']._serialized_end=561
  _globals['_QUERYSUMMARY']._serialized_start=564
  _globals['_QUERYSUMMARY']._serialized_end=907
  _globals['_RUNCYPHERREQUEST']._serialized_start=910
  _globals['_RUNCYPHERREQUEST']._serialized_end=1207
  _globals['_RUNCYPHERREQUEST_PARAMETERSENTRY']._serialized_start=1106
  _globals['_RUNCYPHERREQUEST_PARAMETERSENTRY']._serialized_end=1179
  _globals['_RUNCYPHERRESPONSE']._serialized_start=1210
  _globals['_RUNCYPHERRESPONSE']._serialized_end=1372
  _globals['_RUNCYPHERREADREQUEST']._serialized_start=1375
  _globals['_RUNCYPHERREADREQUEST']._serialized_end=1680
  _globals['_RUNCYPHERREADREQUEST_PARAMETERSENTRY']._serialized_start=1106
  _globals['_RUNCYPHERREADREQUEST_PARAMETERSENTRY']._serialized_end=1179
  _globals['_RUNCYPHERREADRESPONSE']._serialized_start=1683
  _globals['_RUNCYPHERREADRESPONSE']._serialized_end=1849
  _globals['_RUNCYPHERWRITEREQUEST']._serialized_start=1852
  _globals['_RUNCYPHERWRITEREQUEST']._serialized_end=2159
  _globals['_RUNCYPHERWRITEREQUEST_PARAMETERSENTRY']._serialized_start=1106
  _globals['_RUNCYPHERWRITEREQUEST_PARAMETERSENTRY']._serialized_end=1179
  _globals['_RUNCYPHERWRITERESPONSE']._serialized_start=2162
  _globals['_RUNCYPHERWRITERESPONSE']._serialized_end=2329
  _globals['_RUNCYPHERBATCHREQUEST']._serialized_start=2332
  _globals['_RUNCYPHERBATCHREQUEST']._serialized_end=2479
  _globals['_CYPHERQUERY']._serialized_start=2482
  _globals['_CYPHERQUERY']._serialized_end=2646
  _globals['_CYPHERQUERY_PARAMETERSENTRY']._serialized_start=1106
  _globals['_CYPHERQUERY_PARAMETERSENTRY']._serialized_end=1179
  _globals['_RUNCYPHERBATCHRESPONSE']._serialized_start=2648
  _globals['_RUNCYPHERBATCHRESPONSE']._serialized_end=2767
  _globals['_CREATENODEREQUEST']._serialized_start=2770
  _globals['_CREATENODEREQUEST']._serialized_end=2933
  _globals['_CREATENODERESPONSE']._serialized_start=2935
  _globals['_CREATENODERESPONSE']._serialized_end=3034
  _globals['_GETNODEREQUEST']._serialized_start=3036
  _globals['_GETNODEREQUEST']._serialized_end=3152
  _globals['_GETNODERESPONSE']._serialized_start=3154
  _globals['_GETNODERESPONSE']._serialized_end=3265
  _globals['_UPDATENODEREQUEST']._serialized_start=3268
  _globals['_UPDATENODEREQUEST']._serialized_end=3466
  _globals['_UPDATENODERESPONSE']._serialized_start=3468
  _globals['_UPDATENODERESPONSE']._serialized_end=3567
  _globals['_DELETENODEREQUEST']._serialized_start=3570
  _globals['_DELETENODEREQUEST']._serialized_end=3721
  _globals['_DELETENODERESPONSE']._serialized_start=3723
  _globals['_DELETENODERESPONSE']._serialized_end=3839
  _globals['_MERGENODEREQUEST']._serialized_start=3842
  _globals['_MERGENODEREQUEST']._serialized_end=4059
  _globals['_MERGENODERESPONSE']._serialized_start=4061
  _globals['_MERGENODERESPONSE']._serialized_end=4176
  _globals['_FINDNODESREQUEST']._serialized_start=4179
  _globals['_FINDNODESREQUEST']._serialized_end=4413
  _globals['_FINDNODESRESPONSE']._serialized_start=4415
  _globals['_FINDNODESRESPONSE']._serialized_end=4535
  _globals['_CREATERELATIONSHIPREQUEST']._serialized_start=4538
  _globals['_CREATERELATIONSHIPREQUEST']._serialized_end=4751
  _globals['_CREATERELATIONSHIPRESPONSE']._serialized_start=4753
  _globals['_CREATERELATIONSHIPRESPONSE']._serialized_end=4876
  _globals['_GETRELATIONSHIPREQUEST']._serialized_start=4879
  _globals['_GETRELATIONSHIPREQUEST']._serialized_end=5011
  _globals['_GETRELATIONSHIPRESPONSE']._serialized_start=5014
  _globals['_GETRELATIONSHIPRESPONSE']._serialized_end=5149
  _globals['_UPDATERELATIONSHIPREQUEST']._serialized_start=5152
  _globals['_UPDATERELATIONSHIPREQUEST']._serialized_end=5366
  _globals['_UPDATERELATIONSHIPRESPONSE']._serialized_start=5368
  _globals['_UPDATERELATIONSHIPRESPONSE']._serialized_end=5491
  _globals['_DELETERELATIONSHIPREQUEST']._serialized_start=5494
  _globals['_DELETERELATIONSHIPREQUEST']._serialized_end=5629
  _globals['_DELETERELATIONSHIPRESPONSE']._serialized_start=5631
  _globals['_DELETERELATIONSHIPRESPONSE']._serialized_end=5724
  _globals['_FINDRELATIONSHIPSREQUEST']._serialized_start=5727
  _globals['_FINDRELATIONSHIPSREQUEST']._serialized_end=6027
  _globals['_FINDRELATIONSHIPSRESPONSE']._serialized_start=6030
  _globals['_FINDRELATIONSHIPSRESPONSE']._serialized_end=6174
  _globals['_GETNEIGHBORSREQUEST']._serialized_start=6177
  _globals['_GETNEIGHBORSREQUEST']._serialized_end=6428
  _globals['_GETNEIGHBORSRESPONSE']._serialized_start=6431
  _globals['_GETNEIGHBORSRESPONSE']._serialized_end=6581
  _globals['_GETPATHREQUEST']._serialized_start=6584
  _globals['_GETPATHREQUEST']._serialized_end=6819
  _globals['_GETPATHRESPONSE']._serialized_start=6821
  _globals['_GETPATHRESPONSE']._serialized_end=6932
  _globals['_GETSHORTESTPATHREQUEST']._serialized_start=6935
  _globals['_GETSHORTESTPATHREQUEST']._serialized_end=7178
  _globals['_GETSHORTESTPATHRESPONSE']._serialized_start=7180
  _globals['_GETSHORTESTPATHRESPONSE']._serialized_end=7299
  _globals['_GETALLPATHSREQUEST']._serialized_start=7302
  _globals['_GETALLPATHSREQUEST']._serialized_end=7571
  _globals['_GETALLPATHSRESPONSE']._serialized_start=7573
  _globals['_GETALLPATHSRESPONSE']._serialized_end=7674
  _globals['_PAGERANKREQUEST']._serialized_start=7677
  _globals['_PAGERANKREQUEST']._serialized_end=7961
  _globals['_PAGERANKRESPONSE']._serialized_start=7964
  _globals['_PAGERANKRESPONSE']._serialized_end=8134
  _globals['_PAGERANKRESPONSE_SCORESENTRY']._serialized_start=8089
  _globals['_PAGERANKRESPONSE_SCORESENTRY']._serialized_end=8134
  _globals['_BETWEENNESSCENTRALITYREQUEST']._serialized_start=8137
  _globals['_BETWEENNESSCENTRALITYREQUEST']._serialized_end=8334
  _globals['_BETWEENNESSCENTRALITYRESPONSE']._serialized_start=8337
  _globals['_BETWEENNESSCENTRALITYRESPONSE']._serialized_end=8533
  _globals['_BETWEENNESSCENTRALITYRESPONSE_SCORESENTRY']._serialized_start=8089
  _globals['_BETWEENNESSCENTRALITYRESPONSE_SCORESENTRY']._serialized_end=8134
  _globals['_COMMUNITYDETECTIONREQUEST']._serialized_start=8536
  _globals['_COMMUNITYDETECTIONREQUEST']._serialized_end=8768
  _globals['_COMMUNITYDETECTIONRESPONSE']._serialized_start=8771
  _globals['_COMMUNITYDETECTIONRESPONSE']._serialized_end=9001
  _globals['_COMMUNITYDETECTIONRESPONSE_COMMUNITIESENTRY']._serialized_start=8951
  _globals['_COMMUNITYDETECTIONRESPONSE_COMMUNITIESENTRY']._serialized_end=9001
  _globals['_CREATEINDEXREQUEST']._serialized_start=9004
  _globals['_CREATEINDEXREQUEST']._serialized_end=9202
  _globals['_CREATEINDEXRESPONSE']._serialized_start=9204
  _globals['_CREATEINDEXRESPONSE']._serialized_end=9290
  _globals['_DROPINDEXREQUEST']._serialized_start=9292
  _globals['_DROPINDEXREQUEST']._serialized_end=9413
  _globals['_DROPINDEXRESPONSE']._serialized_start=9415
  _globals['_DROPINDEXRESPONSE']._serialized_end=9499
  _globals['_LISTINDEXESREQUEST']._serialized_start=9501
  _globals['_LISTINDEXESREQUEST']._serialized_end=9604
  _globals['_LISTINDEXESRESPONSE']._serialized_start=9606
  _globals['_LISTINDEXESRESPONSE']._serialized_end=9714
  _globals['_INDEXINFO']._serialized_start=9716
  _globals['_INDEXINFO']._serialized_end=9815
  _globals['_CREATECONSTRAINTREQUEST']._serialized_start=9818
  _globals['_CREATECONSTRAINTREQUEST']._serialized_end=10011
  _globals['_CREATECONSTRAINTRESPONSE']._serialized_start=10013
  _globals['_CREATECONSTRAINTRESPONSE']._serialized_end=10104
  _globals['_DROPCONSTRAINTREQUEST']._serialized_start=10107
  _globals['_DROPCONSTRAINTREQUEST']._serialized_end=10238
  _globals['_DROPCONSTRAINTRESPONSE']._serialized_start=10240
  _globals['_DROPCONSTRAINTRESPONSE']._serialized_end=10329
  _globals['_LISTCONSTRAINTSREQUEST']._serialized_start=10331
  _globals['_LISTCONSTRAINTSREQUEST']._serialized_end=10438
  _globals['_LISTCONSTRAINTSRESPONSE']._serialized_start=10440
  _globals['_LISTCONSTRAINTSRESPONSE']._serialized_end=10561
  _globals['_CONSTRAINTINFO']._serialized_start=10563
  _globals['_CONSTRAINTINFO']._serialized_end=10642
  _globals['_BEGINTRANSACTIONREQUEST']._serialized_start=10645
  _globals['_BEGINTRANSACTIONREQUEST']._serialized_end=10793
  _globals['_BEGINTRANSACTIONRESPONSE']._serialized_start=10795
  _globals['_BEGINTRANSACTIONRESPONSE']._serialized_end=10893
  _globals['_COMMITTRANSACTIONREQUEST']._serialized_start=10895
  _globals['_COMMITTRANSACTIONREQUEST']._serialized_end=10992
  _globals['_COMMITTRANSACTIONRESPONSE']._serialized_start=10994
  _globals['_COMMITTRANSACTIONRESPONSE']._serialized_end=11086
  _globals['_ROLLBACKTRANSACTIONREQUEST']._serialized_start=11088
  _globals['_ROLLBACKTRANSACTIONREQUEST']._serialized_end=11187
  _globals['_ROLLBACKTRANSACTIONRESPONSE']._serialized_start=11189
  _globals['_ROLLBACKTRANSACTIONRESPONSE']._serialized_end=11283
  _globals['_GETDATABASEINFOREQUEST']._serialized_start=11285
  _globals['_GETDATABASEINFOREQUEST']._serialized_end=11392
  _globals['_GETDATABASEINFORESPONSE']._serialized_start=11395
  _globals['_GETDATABASEINFORESPONSE']._serialized_end=11612
  _globals['_LISTDATABASESREQUEST']._serialized_start=11614
  _globals['_LISTDATABASESREQUEST']._serialized_end=11683
  _globals['_LISTDATABASESRESPONSE']._serialized_start=11685
  _globals['_LISTDATABASESRESPONSE']._serialized_end=11800
  _globals['_DATABASEINFO']._serialized_start=11802
  _globals['_DATABASEINFO']._serialized_end=11863
  _globals['_GETSTATISTICSREQUEST']._serialized_start=11865
  _globals['_GETSTATISTICSREQUEST']._serialized_end=11970
  _globals['_GETSTATISTICSRESPONSE']._serialized_start=11972
  _globals['_GETSTATISTICSRESPONSE']._serialized_end=12088
  _globals['_NEO4JHEALTHCHECKREQUEST']._serialized_start=12090
  _globals['_NEO4JHEALTHCHECKREQUEST']._serialized_end=12162
  _globals['_NEO4JHEALTHCHECKRESPONSE']._serialized_start=12164
  _globals['_NEO4JHEALTHCHECKRESPONSE']._serialized_end=12289
  _globals['_NEO4JSERVICE']._serialized_start=12292
  _globals['_NEO4JSERVICE']._serialized_end=15280
# @@protoc_insertion_point(module_scope)
