# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: common.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63ommon.proto\x12\nisa.common\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x9c\x01\n\x0c\x42\x61seResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x12\n\nerror_code\x18\x03 \x01(\t\x12\x15\n\rerror_message\x18\x04 \x01(\t\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08trace_id\x18\x06 \x01(\t\"\x85\x02\n\x04User\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08\x61uth0_id\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x17\n\x0forganization_id\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tis_active\x18\x07 \x01(\x08\x12\x30\n\x08metadata\x18\x08 \x03(\x0b\x32\x1e.isa.common.User.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaa\x01\n\x0cOrganization\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0c\n\x04plan\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tis_active\x18\x07 \x01(\x08\"\xca\x01\n\x0b\x41uthContext\x12\x1e\n\x04user\x18\x01 \x01(\x0b\x32\x10.isa.common.User\x12.\n\x0corganization\x18\x02 \x01(\x0b\x32\x18.isa.common.Organization\x12\x13\n\x0bpermissions\x18\x03 \x03(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x04 \x01(\t\x12.\n\nexpires_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08provider\x18\x06 \x01(\t\"\xa8\x02\n\x0eRequestContext\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x10\n\x08trace_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x17\n\x0forganization_id\x18\x04 \x01(\t\x12\x14\n\x0cservice_name\x18\x05 \x01(\t\x12\x13\n\x0bmethod_name\x18\x06 \x01(\t\x12.\n\nstart_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x08metadata\x18\x08 \x03(\x0b\x32(.isa.common.RequestContext.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf8\x01\n\x0fRequestMetadata\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x03 \x01(\t\x12\x12\n\nrequest_id\x18\x04 \x01(\t\x12\x10\n\x08trace_id\x18\x05 \x01(\t\x12H\n\x0f\x63ustom_metadata\x18\x06 \x03(\x0b\x32/.isa.common.RequestMetadata.CustomMetadataEntry\x1a\x35\n\x13\x43ustomMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xac\x01\n\x10ResponseMetadata\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\x12\x12\n\nerror_code\x18\x04 \x01(\t\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nrequest_id\x18\x06 \x01(\t\x12\x10\n\x08trace_id\x18\x07 \x01(\tB1Z/github.com/isa-cloud/isa_cloud/api/proto/commonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/isa-cloud/isa_cloud/api/proto/common'
  _globals['_USER_METADATAENTRY']._loaded_options = None
  _globals['_USER_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_REQUESTCONTEXT_METADATAENTRY']._loaded_options = None
  _globals['_REQUESTCONTEXT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_REQUESTMETADATA_CUSTOMMETADATAENTRY']._loaded_options = None
  _globals['_REQUESTMETADATA_CUSTOMMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_BASERESPONSE']._serialized_start=92
  _globals['_BASERESPONSE']._serialized_end=248
  _globals['_USER']._serialized_start=251
  _globals['_USER']._serialized_end=512
  _globals['_USER_METADATAENTRY']._serialized_start=465
  _globals['_USER_METADATAENTRY']._serialized_end=512
  _globals['_ORGANIZATION']._serialized_start=515
  _globals['_ORGANIZATION']._serialized_end=685
  _globals['_AUTHCONTEXT']._serialized_start=688
  _globals['_AUTHCONTEXT']._serialized_end=890
  _globals['_REQUESTCONTEXT']._serialized_start=893
  _globals['_REQUESTCONTEXT']._serialized_end=1189
  _globals['_REQUESTCONTEXT_METADATAENTRY']._serialized_start=465
  _globals['_REQUESTCONTEXT_METADATAENTRY']._serialized_end=512
  _globals['_REQUESTMETADATA']._serialized_start=1192
  _globals['_REQUESTMETADATA']._serialized_end=1440
  _globals['_REQUESTMETADATA_CUSTOMMETADATAENTRY']._serialized_start=1387
  _globals['_REQUESTMETADATA_CUSTOMMETADATAENTRY']._serialized_end=1440
  _globals['_RESPONSEMETADATA']._serialized_start=1443
  _globals['_RESPONSEMETADATA']._serialized_end=1615
# @@protoc_insertion_point(module_scope)
