# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: qdrant_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'qdrant_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14qdrant_service.proto\x12\nisa.qdrant\x1a\x0c\x63ommon.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x16\n\x06Vector\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x02\"\x8a\x01\n\x0cNamedVectors\x12\x36\n\x07vectors\x18\x01 \x03(\x0b\x32%.isa.qdrant.NamedVectors.VectorsEntry\x1a\x42\n\x0cVectorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.isa.qdrant.Vector:\x02\x38\x01\"\xbf\x01\n\x05Point\x12\x10\n\x06num_id\x18\x01 \x01(\x04H\x00\x12\x10\n\x06str_id\x18\x02 \x01(\tH\x00\x12$\n\x06vector\x18\x03 \x01(\x0b\x32\x12.isa.qdrant.VectorH\x01\x12\x31\n\rnamed_vectors\x18\x04 \x01(\x0b\x32\x18.isa.qdrant.NamedVectorsH\x01\x12(\n\x07payload\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructB\x04\n\x02idB\t\n\x07vectors\"g\n\x0bScoredPoint\x12 \n\x05point\x18\x01 \x01(\x0b\x32\x11.isa.qdrant.Point\x12\r\n\x05score\x18\x02 \x01(\x02\x12\'\n\x07version\x18\x03 \x01(\x0b\x32\x16.google.protobuf.Value\"\x8f\x01\n\x06\x46ilter\x12)\n\x04must\x18\x01 \x03(\x0b\x32\x1b.isa.qdrant.FilterCondition\x12+\n\x06should\x18\x02 \x03(\x0b\x32\x1b.isa.qdrant.FilterCondition\x12-\n\x08must_not\x18\x03 \x03(\x0b\x32\x1b.isa.qdrant.FilterCondition\"\xb8\x02\n\x0f\x46ilterCondition\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12+\n\x05match\x18\x02 \x01(\x0b\x32\x1a.isa.qdrant.MatchConditionH\x00\x12+\n\x05range\x18\x03 \x01(\x0b\x32\x1a.isa.qdrant.RangeConditionH\x00\x12?\n\x10geo_bounding_box\x18\x04 \x01(\x0b\x32#.isa.qdrant.GeoBoundingBoxConditionH\x00\x12\x34\n\ngeo_radius\x18\x05 \x01(\x0b\x32\x1e.isa.qdrant.GeoRadiusConditionH\x00\x12\x38\n\x0cvalues_count\x18\x06 \x01(\x0b\x32 .isa.qdrant.ValuesCountConditionH\x00\x42\x0b\n\tcondition\"X\n\x0eMatchCondition\x12\x11\n\x07keyword\x18\x01 \x01(\tH\x00\x12\x11\n\x07integer\x18\x02 \x01(\x03H\x00\x12\x11\n\x07\x62oolean\x18\x03 \x01(\x08H\x00\x42\r\n\x0bmatch_value\"t\n\x0eRangeCondition\x12\x0f\n\x02gt\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x10\n\x03gte\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x0f\n\x02lt\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12\x10\n\x03lte\x18\x04 \x01(\x01H\x03\x88\x01\x01\x42\x05\n\x03_gtB\x06\n\x04_gteB\x05\n\x03_ltB\x06\n\x04_lte\"m\n\x17GeoBoundingBoxCondition\x12&\n\x08top_left\x18\x01 \x01(\x0b\x32\x14.isa.qdrant.GeoPoint\x12*\n\x0c\x62ottom_right\x18\x02 \x01(\x0b\x32\x14.isa.qdrant.GeoPoint\"Q\n\x12GeoRadiusCondition\x12$\n\x06\x63\x65nter\x18\x01 \x01(\x0b\x32\x14.isa.qdrant.GeoPoint\x12\x15\n\rradius_meters\x18\x02 \x01(\x01\"$\n\x08GeoPoint\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lon\x18\x02 \x01(\x01\"z\n\x14ValuesCountCondition\x12\x0f\n\x02lt\x18\x01 \x01(\x04H\x00\x88\x01\x01\x12\x10\n\x03lte\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x0f\n\x02gt\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x10\n\x03gte\x18\x04 \x01(\x04H\x03\x88\x01\x01\x42\x05\n\x03_ltB\x06\n\x04_lteB\x05\n\x03_gtB\x06\n\x04_gte\"\xe0\x01\n\x0cVectorParams\x12\x0c\n\x04size\x18\x01 \x01(\x04\x12&\n\x08\x64istance\x18\x02 \x01(\x0e\x32\x14.isa.qdrant.Distance\x12\x30\n\x0bhnsw_config\x18\x03 \x01(\x0b\x32\x16.isa.qdrant.HnswConfigH\x00\x88\x01\x01\x12@\n\x13quantization_config\x18\x04 \x01(\x0b\x32\x1e.isa.qdrant.QuantizationConfigH\x01\x88\x01\x01\x42\x0e\n\x0c_hnsw_configB\x16\n\x14_quantization_config\"J\n\nHnswConfig\x12\t\n\x01m\x18\x01 \x01(\x04\x12\x14\n\x0c\x65\x66_construct\x18\x02 \x01(\x04\x12\x1b\n\x13\x66ull_scan_threshold\x18\x03 \x01(\x04\"\x8a\x01\n\x12QuantizationConfig\x12\x30\n\x06scalar\x18\x01 \x01(\x0b\x32\x1e.isa.qdrant.ScalarQuantizationH\x00\x12\x32\n\x07product\x18\x02 \x01(\x0b\x32\x1f.isa.qdrant.ProductQuantizationH\x00\x42\x0e\n\x0cquantization\"\xb1\x01\n\x12ScalarQuantization\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32).isa.qdrant.ScalarQuantization.ScalarType\x12\x15\n\x08quantile\x18\x02 \x01(\x02H\x00\x88\x01\x01\x12\x17\n\nalways_ram\x18\x03 \x01(\x08H\x01\x88\x01\x01\"\x16\n\nScalarType\x12\x08\n\x04INT8\x10\x00\x42\x0b\n\t_quantileB\r\n\x0b_always_ram\"\xc3\x01\n\x13ProductQuantization\x12\x45\n\x0b\x63ompression\x18\x01 \x01(\x0e\x32\x30.isa.qdrant.ProductQuantization.CompressionRatio\x12\x17\n\nalways_ram\x18\x02 \x01(\x08H\x00\x88\x01\x01\"=\n\x10\x43ompressionRatio\x12\x06\n\x02X4\x10\x00\x12\x06\n\x02X8\x10\x01\x12\x07\n\x03X16\x10\x02\x12\x07\n\x03X32\x10\x03\x12\x07\n\x03X64\x10\x04\x42\r\n\x0b_always_ram\"\x9b\x01\n\x13VectorsConfigParams\x12;\n\x06params\x18\x01 \x03(\x0b\x32+.isa.qdrant.VectorsConfigParams.ParamsEntry\x1aG\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.isa.qdrant.VectorParams:\x02\x38\x01\"\xc0\x03\n\x17\x43reateCollectionRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12\x31\n\rvector_params\x18\x03 \x01(\x0b\x32\x18.isa.qdrant.VectorParamsH\x00\x12>\n\x13named_vector_params\x18\x04 \x01(\x0b\x32\x1f.isa.qdrant.VectorsConfigParamsH\x00\x12\x19\n\x0cshard_number\x18\x05 \x01(\rH\x01\x88\x01\x01\x12\x1f\n\x12replication_factor\x18\x06 \x01(\rH\x02\x88\x01\x01\x12%\n\x18write_consistency_factor\x18\x07 \x01(\rH\x03\x88\x01\x01\x12\x1c\n\x0fon_disk_payload\x18\x08 \x01(\x08H\x04\x88\x01\x01\x42\x10\n\x0evectors_configB\x0f\n\r_shard_numberB\x15\n\x13_replication_factorB\x1b\n\x19_write_consistency_factorB\x12\n\x10_on_disk_payload\"[\n\x18\x43reateCollectionResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07success\x18\x02 \x01(\x08\"G\n\x16ListCollectionsRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\"\x81\x01\n\x17ListCollectionsResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x36\n\x0b\x63ollections\x18\x02 \x03(\x0b\x32!.isa.qdrant.CollectionDescription\"%\n\x15\x43ollectionDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\"b\n\x18GetCollectionInfoRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\"u\n\x19GetCollectionInfoResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12(\n\x04info\x18\x02 \x01(\x0b\x32\x1a.isa.qdrant.CollectionInfo\"\xaa\x01\n\x0e\x43ollectionInfo\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x14\n\x0cpoints_count\x18\x02 \x01(\x04\x12\x16\n\x0esegments_count\x18\x03 \x01(\x04\x12\'\n\x06\x63onfig\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x31\n\x10optimizer_status\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xd0\x01\n\x17UpdateCollectionRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12\x1e\n\x11optimizers_config\x18\x03 \x01(\rH\x00\x88\x01\x01\x12,\n\x06params\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructH\x01\x88\x01\x01\x42\x14\n\x12_optimizers_configB\t\n\x07_params\"[\n\x18UpdateCollectionResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07success\x18\x02 \x01(\x08\"a\n\x17\x44\x65leteCollectionRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\"[\n\x18\x44\x65leteCollectionResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07success\x18\x02 \x01(\x08\"z\n\x1c\x43reateCollectionAliasRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12\x12\n\nalias_name\x18\x03 \x01(\t\"`\n\x1d\x43reateCollectionAliasResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07success\x18\x02 \x01(\x08\"\xc0\x01\n\x13UpsertPointsRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12!\n\x06points\x18\x03 \x03(\x0b\x32\x11.isa.qdrant.Point\x12\x11\n\x04wait\x18\x04 \x01(\x08H\x00\x88\x01\x01\x12\x15\n\x08ordering\x18\x05 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_waitB\x0b\n\t_ordering\"l\n\x14UpsertPointsResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x14\n\x0coperation_id\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\xd4\x01\n\x10GetPointsRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12 \n\x03ids\x18\x03 \x03(\x0b\x32\x13.isa.qdrant.PointId\x12\x19\n\x0cwith_payload\x18\x04 \x01(\x08H\x00\x88\x01\x01\x12\x19\n\x0cwith_vectors\x18\x05 \x01(\x08H\x01\x88\x01\x01\x42\x0f\n\r_with_payloadB\x0f\n\r_with_vectors\"-\n\x07PointId\x12\r\n\x03num\x18\x01 \x01(\x04H\x00\x12\r\n\x03str\x18\x02 \x01(\tH\x00\x42\x04\n\x02id\"f\n\x11GetPointsResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12!\n\x06points\x18\x02 \x03(\x0b\x32\x11.isa.qdrant.Point\"/\n\x0bPointIdList\x12 \n\x03ids\x18\x01 \x03(\x0b\x32\x13.isa.qdrant.PointId\"\xd3\x01\n\x13\x44\x65letePointsRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12&\n\x03ids\x18\x03 \x01(\x0b\x32\x17.isa.qdrant.PointIdListH\x00\x12$\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\x12.isa.qdrant.FilterH\x00\x12\x11\n\x04wait\x18\x05 \x01(\x08H\x01\x88\x01\x01\x42\n\n\x08selectorB\x07\n\x05_wait\"l\n\x14\x44\x65letePointsResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x14\n\x0coperation_id\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\xfe\x01\n\x14UpdatePayloadRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12(\n\x07payload\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12&\n\x03ids\x18\x04 \x01(\x0b\x32\x17.isa.qdrant.PointIdListH\x00\x12$\n\x06\x66ilter\x18\x05 \x01(\x0b\x32\x12.isa.qdrant.FilterH\x00\x12\x11\n\x04wait\x18\x06 \x01(\x08H\x01\x88\x01\x01\x42\n\n\x08selectorB\x07\n\x05_wait\"m\n\x15UpdatePayloadResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x14\n\x0coperation_id\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\xe2\x01\n\x14\x44\x65letePayloadRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12\x0c\n\x04keys\x18\x03 \x03(\t\x12&\n\x03ids\x18\x04 \x01(\x0b\x32\x17.isa.qdrant.PointIdListH\x00\x12$\n\x06\x66ilter\x18\x05 \x01(\x0b\x32\x12.isa.qdrant.FilterH\x00\x12\x11\n\x04wait\x18\x06 \x01(\x08H\x01\x88\x01\x01\x42\n\n\x08selectorB\x07\n\x05_wait\"m\n\x15\x44\x65letePayloadResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x14\n\x0coperation_id\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\xd3\x01\n\x13\x43learPayloadRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12&\n\x03ids\x18\x03 \x01(\x0b\x32\x17.isa.qdrant.PointIdListH\x00\x12$\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\x12.isa.qdrant.FilterH\x00\x12\x11\n\x04wait\x18\x05 \x01(\x08H\x01\x88\x01\x01\x42\n\n\x08selectorB\x07\n\x05_wait\"l\n\x14\x43learPayloadResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x14\n\x0coperation_id\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\xcb\x03\n\rSearchRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12\"\n\x06vector\x18\x03 \x01(\x0b\x32\x12.isa.qdrant.Vector\x12\x18\n\x0bvector_name\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\'\n\x06\x66ilter\x18\x05 \x01(\x0b\x32\x12.isa.qdrant.FilterH\x01\x88\x01\x01\x12,\n\x06params\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructH\x02\x88\x01\x01\x12\r\n\x05limit\x18\x07 \x01(\x04\x12\x13\n\x06offset\x18\x08 \x01(\x04H\x03\x88\x01\x01\x12\x19\n\x0cwith_payload\x18\t \x01(\x08H\x04\x88\x01\x01\x12\x19\n\x0cwith_vectors\x18\n \x01(\x08H\x05\x88\x01\x01\x12\x1c\n\x0fscore_threshold\x18\x0b \x01(\x02H\x06\x88\x01\x01\x42\x0e\n\x0c_vector_nameB\t\n\x07_filterB\t\n\x07_paramsB\t\n\x07_offsetB\x0f\n\r_with_payloadB\x0f\n\r_with_vectorsB\x12\n\x10_score_threshold\"i\n\x0eSearchResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\'\n\x06result\x18\x02 \x03(\x0b\x32\x17.isa.qdrant.ScoredPoint\"\x89\x01\n\x12SearchBatchRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12+\n\x08searches\x18\x03 \x03(\x0b\x32\x19.isa.qdrant.SearchRequest\"r\n\x13SearchBatchResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12+\n\x07results\x18\x02 \x03(\x0b\x32\x1a.isa.qdrant.SearchResponse\"\xb9\x03\n\x10RecommendRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12%\n\x08positive\x18\x03 \x03(\x0b\x32\x13.isa.qdrant.PointId\x12%\n\x08negative\x18\x04 \x03(\x0b\x32\x13.isa.qdrant.PointId\x12\'\n\x06\x66ilter\x18\x05 \x01(\x0b\x32\x12.isa.qdrant.FilterH\x00\x88\x01\x01\x12\r\n\x05limit\x18\x06 \x01(\x04\x12\x13\n\x06offset\x18\x07 \x01(\x04H\x01\x88\x01\x01\x12\x19\n\x0cwith_payload\x18\x08 \x01(\x08H\x02\x88\x01\x01\x12\x19\n\x0cwith_vectors\x18\t \x01(\x08H\x03\x88\x01\x01\x12\x1c\n\x0fscore_threshold\x18\n \x01(\x02H\x04\x88\x01\x01\x12\x15\n\x08strategy\x18\x0b \x01(\tH\x05\x88\x01\x01\x42\t\n\x07_filterB\t\n\x07_offsetB\x0f\n\r_with_payloadB\x0f\n\r_with_vectorsB\x12\n\x10_score_thresholdB\x0b\n\t_strategy\"l\n\x11RecommendResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\'\n\x06result\x18\x02 \x03(\x0b\x32\x17.isa.qdrant.ScoredPoint\"\xdf\x02\n\x0f\x44iscoverRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12#\n\x06target\x18\x03 \x01(\x0b\x32\x13.isa.qdrant.PointId\x12$\n\x07\x63ontext\x18\x04 \x03(\x0b\x32\x13.isa.qdrant.PointId\x12\'\n\x06\x66ilter\x18\x05 \x01(\x0b\x32\x12.isa.qdrant.FilterH\x00\x88\x01\x01\x12\r\n\x05limit\x18\x06 \x01(\x04\x12\x13\n\x06offset\x18\x07 \x01(\x04H\x01\x88\x01\x01\x12\x19\n\x0cwith_payload\x18\x08 \x01(\x08H\x02\x88\x01\x01\x12\x19\n\x0cwith_vectors\x18\t \x01(\x08H\x03\x88\x01\x01\x42\t\n\x07_filterB\t\n\x07_offsetB\x0f\n\r_with_payloadB\x0f\n\r_with_vectors\"k\n\x10\x44iscoverResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\'\n\x06result\x18\x02 \x03(\x0b\x32\x17.isa.qdrant.ScoredPoint\"\xb6\x02\n\rScrollRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12\'\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x12.isa.qdrant.FilterH\x00\x88\x01\x01\x12\x12\n\x05limit\x18\x04 \x01(\rH\x01\x88\x01\x01\x12(\n\x06offset\x18\x05 \x01(\x0b\x32\x13.isa.qdrant.PointIdH\x02\x88\x01\x01\x12\x19\n\x0cwith_payload\x18\x06 \x01(\x08H\x03\x88\x01\x01\x12\x19\n\x0cwith_vectors\x18\x07 \x01(\x08H\x04\x88\x01\x01\x42\t\n\x07_filterB\x08\n\x06_limitB\t\n\x07_offsetB\x0f\n\r_with_payloadB\x0f\n\r_with_vectors\"\xac\x01\n\x0eScrollResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12!\n\x06points\x18\x02 \x03(\x0b\x32\x11.isa.qdrant.Point\x12\x32\n\x10next_page_offset\x18\x03 \x01(\x0b\x32\x13.isa.qdrant.PointIdH\x00\x88\x01\x01\x42\x13\n\x11_next_page_offset\"\xa8\x01\n\x0c\x43ountRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12\'\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x12.isa.qdrant.FilterH\x00\x88\x01\x01\x12\x12\n\x05\x65xact\x18\x04 \x01(\x08H\x01\x88\x01\x01\x42\t\n\x07_filterB\x08\n\x06_exact\"N\n\rCountResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\"\x8a\x02\n\x17\x43reateFieldIndexRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12\x12\n\nfield_name\x18\x03 \x01(\t\x12\x17\n\nfield_type\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x38\n\x12\x66ield_index_params\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructH\x01\x88\x01\x01\x12\x11\n\x04wait\x18\x06 \x01(\x08H\x02\x88\x01\x01\x42\r\n\x0b_field_typeB\x15\n\x13_field_index_paramsB\x07\n\x05_wait\"p\n\x18\x43reateFieldIndexResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x14\n\x0coperation_id\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x91\x01\n\x17\x44\x65leteFieldIndexRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12\x12\n\nfield_name\x18\x03 \x01(\t\x12\x11\n\x04wait\x18\x04 \x01(\x08H\x00\x88\x01\x01\x42\x07\n\x05_wait\"p\n\x18\x44\x65leteFieldIndexResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x14\n\x0coperation_id\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"_\n\x15\x43reateSnapshotRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\"\x8f\x01\n\x16\x43reateSnapshotResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x15\n\rsnapshot_name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"^\n\x14ListSnapshotsRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\"{\n\x15ListSnapshotsResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x32\n\tsnapshots\x18\x02 \x03(\x0b\x32\x1f.isa.qdrant.SnapshotDescription\"g\n\x13SnapshotDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nsize_bytes\x18\x03 \x01(\x04\"v\n\x15\x44\x65leteSnapshotRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12\x15\n\rsnapshot_name\x18\x03 \x01(\t\"Y\n\x16\x44\x65leteSnapshotResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07success\x18\x02 \x01(\x08\"I\n\x18QdrantHealthCheckRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\"m\n\x19QdrantHealthCheckResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07healthy\x18\x02 \x01(\x08\x12\x0f\n\x07version\x18\x03 \x01(\t\"F\n\x15GetClusterInfoRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\"w\n\x16GetClusterInfoResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12-\n\x0c\x63luster_info\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct*t\n\x08\x44istance\x12\x14\n\x10\x44ISTANCE_UNKNOWN\x10\x00\x12\x13\n\x0f\x44ISTANCE_COSINE\x10\x01\x12\x13\n\x0f\x44ISTANCE_EUCLID\x10\x02\x12\x10\n\x0c\x44ISTANCE_DOT\x10\x03\x12\x16\n\x12\x44ISTANCE_MANHATTAN\x10\x04\x32\xe3\x10\n\rQdrantService\x12]\n\x10\x43reateCollection\x12#.isa.qdrant.CreateCollectionRequest\x1a$.isa.qdrant.CreateCollectionResponse\x12Z\n\x0fListCollections\x12\".isa.qdrant.ListCollectionsRequest\x1a#.isa.qdrant.ListCollectionsResponse\x12`\n\x11GetCollectionInfo\x12$.isa.qdrant.GetCollectionInfoRequest\x1a%.isa.qdrant.GetCollectionInfoResponse\x12]\n\x10UpdateCollection\x12#.isa.qdrant.UpdateCollectionRequest\x1a$.isa.qdrant.UpdateCollectionResponse\x12]\n\x10\x44\x65leteCollection\x12#.isa.qdrant.DeleteCollectionRequest\x1a$.isa.qdrant.DeleteCollectionResponse\x12l\n\x15\x43reateCollectionAlias\x12(.isa.qdrant.CreateCollectionAliasRequest\x1a).isa.qdrant.CreateCollectionAliasResponse\x12Q\n\x0cUpsertPoints\x12\x1f.isa.qdrant.UpsertPointsRequest\x1a .isa.qdrant.UpsertPointsResponse\x12H\n\tGetPoints\x12\x1c.isa.qdrant.GetPointsRequest\x1a\x1d.isa.qdrant.GetPointsResponse\x12Q\n\x0c\x44\x65letePoints\x12\x1f.isa.qdrant.DeletePointsRequest\x1a .isa.qdrant.DeletePointsResponse\x12T\n\rUpdatePayload\x12 .isa.qdrant.UpdatePayloadRequest\x1a!.isa.qdrant.UpdatePayloadResponse\x12T\n\rDeletePayload\x12 .isa.qdrant.DeletePayloadRequest\x1a!.isa.qdrant.DeletePayloadResponse\x12Q\n\x0c\x43learPayload\x12\x1f.isa.qdrant.ClearPayloadRequest\x1a .isa.qdrant.ClearPayloadResponse\x12?\n\x06Search\x12\x19.isa.qdrant.SearchRequest\x1a\x1a.isa.qdrant.SearchResponse\x12N\n\x0bSearchBatch\x12\x1e.isa.qdrant.SearchBatchRequest\x1a\x1f.isa.qdrant.SearchBatchResponse\x12H\n\tRecommend\x12\x1c.isa.qdrant.RecommendRequest\x1a\x1d.isa.qdrant.RecommendResponse\x12\x45\n\x08\x44iscover\x12\x1b.isa.qdrant.DiscoverRequest\x1a\x1c.isa.qdrant.DiscoverResponse\x12?\n\x06Scroll\x12\x19.isa.qdrant.ScrollRequest\x1a\x1a.isa.qdrant.ScrollResponse\x12<\n\x05\x43ount\x12\x18.isa.qdrant.CountRequest\x1a\x19.isa.qdrant.CountResponse\x12]\n\x10\x43reateFieldIndex\x12#.isa.qdrant.CreateFieldIndexRequest\x1a$.isa.qdrant.CreateFieldIndexResponse\x12]\n\x10\x44\x65leteFieldIndex\x12#.isa.qdrant.DeleteFieldIndexRequest\x1a$.isa.qdrant.DeleteFieldIndexResponse\x12W\n\x0e\x43reateSnapshot\x12!.isa.qdrant.CreateSnapshotRequest\x1a\".isa.qdrant.CreateSnapshotResponse\x12T\n\rListSnapshots\x12 .isa.qdrant.ListSnapshotsRequest\x1a!.isa.qdrant.ListSnapshotsResponse\x12W\n\x0e\x44\x65leteSnapshot\x12!.isa.qdrant.DeleteSnapshotRequest\x1a\".isa.qdrant.DeleteSnapshotResponse\x12Z\n\x0bHealthCheck\x12$.isa.qdrant.QdrantHealthCheckRequest\x1a%.isa.qdrant.QdrantHealthCheckResponse\x12W\n\x0eGetClusterInfo\x12!.isa.qdrant.GetClusterInfoRequest\x1a\".isa.qdrant.GetClusterInfoResponseB1Z/github.com/isa-cloud/isa_cloud/api/proto/qdrantb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qdrant_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/isa-cloud/isa_cloud/api/proto/qdrant'
  _globals['_NAMEDVECTORS_VECTORSENTRY']._loaded_options = None
  _globals['_NAMEDVECTORS_VECTORSENTRY']._serialized_options = b'8\001'
  _globals['_VECTORSCONFIGPARAMS_PARAMSENTRY']._loaded_options = None
  _globals['_VECTORSCONFIGPARAMS_PARAMSENTRY']._serialized_options = b'8\001'
  _globals['_DISTANCE']._serialized_start=10941
  _globals['_DISTANCE']._serialized_end=11057
  _globals['_VECTOR']._serialized_start=113
  _globals['_VECTOR']._serialized_end=135
  _globals['_NAMEDVECTORS']._serialized_start=138
  _globals['_NAMEDVECTORS']._serialized_end=276
  _globals['_NAMEDVECTORS_VECTORSENTRY']._serialized_start=210
  _globals['_NAMEDVECTORS_VECTORSENTRY']._serialized_end=276
  _globals['_POINT']._serialized_start=279
  _globals['_POINT']._serialized_end=470
  _globals['_SCOREDPOINT']._serialized_start=472
  _globals['_SCOREDPOINT']._serialized_end=575
  _globals['_FILTER']._serialized_start=578
  _globals['_FILTER']._serialized_end=721
  _globals['_FILTERCONDITION']._serialized_start=724
  _globals['_FILTERCONDITION']._serialized_end=1036
  _globals['_MATCHCONDITION']._serialized_start=1038
  _globals['_MATCHCONDITION']._serialized_end=1126
  _globals['_RANGECONDITION']._serialized_start=1128
  _globals['_RANGECONDITION']._serialized_end=1244
  _globals['_GEOBOUNDINGBOXCONDITION']._serialized_start=1246
  _globals['_GEOBOUNDINGBOXCONDITION']._serialized_end=1355
  _globals['_GEORADIUSCONDITION']._serialized_start=1357
  _globals['_GEORADIUSCONDITION']._serialized_end=1438
  _globals['_GEOPOINT']._serialized_start=1440
  _globals['_GEOPOINT']._serialized_end=1476
  _globals['_VALUESCOUNTCONDITION']._serialized_start=1478
  _globals['_VALUESCOUNTCONDITION']._serialized_end=1600
  _globals['_VECTORPARAMS']._serialized_start=1603
  _globals['_VECTORPARAMS']._serialized_end=1827
  _globals['_HNSWCONFIG']._serialized_start=1829
  _globals['_HNSWCONFIG']._serialized_end=1903
  _globals['_QUANTIZATIONCONFIG']._serialized_start=1906
  _globals['_QUANTIZATIONCONFIG']._serialized_end=2044
  _globals['_SCALARQUANTIZATION']._serialized_start=2047
  _globals['_SCALARQUANTIZATION']._serialized_end=2224
  _globals['_SCALARQUANTIZATION_SCALARTYPE']._serialized_start=2174
  _globals['_SCALARQUANTIZATION_SCALARTYPE']._serialized_end=2196
  _globals['_PRODUCTQUANTIZATION']._serialized_start=2227
  _globals['_PRODUCTQUANTIZATION']._serialized_end=2422
  _globals['_PRODUCTQUANTIZATION_COMPRESSIONRATIO']._serialized_start=2346
  _globals['_PRODUCTQUANTIZATION_COMPRESSIONRATIO']._serialized_end=2407
  _globals['_VECTORSCONFIGPARAMS']._serialized_start=2425
  _globals['_VECTORSCONFIGPARAMS']._serialized_end=2580
  _globals['_VECTORSCONFIGPARAMS_PARAMSENTRY']._serialized_start=2509
  _globals['_VECTORSCONFIGPARAMS_PARAMSENTRY']._serialized_end=2580
  _globals['_CREATECOLLECTIONREQUEST']._serialized_start=2583
  _globals['_CREATECOLLECTIONREQUEST']._serialized_end=3031
  _globals['_CREATECOLLECTIONRESPONSE']._serialized_start=3033
  _globals['_CREATECOLLECTIONRESPONSE']._serialized_end=3124
  _globals['_LISTCOLLECTIONSREQUEST']._serialized_start=3126
  _globals['_LISTCOLLECTIONSREQUEST']._serialized_end=3197
  _globals['_LISTCOLLECTIONSRESPONSE']._serialized_start=3200
  _globals['_LISTCOLLECTIONSRESPONSE']._serialized_end=3329
  _globals['_COLLECTIONDESCRIPTION']._serialized_start=3331
  _globals['_COLLECTIONDESCRIPTION']._serialized_end=3368
  _globals['_GETCOLLECTIONINFOREQUEST']._serialized_start=3370
  _globals['_GETCOLLECTIONINFOREQUEST']._serialized_end=3468
  _globals['_GETCOLLECTIONINFORESPONSE']._serialized_start=3470
  _globals['_GETCOLLECTIONINFORESPONSE']._serialized_end=3587
  _globals['_COLLECTIONINFO']._serialized_start=3590
  _globals['_COLLECTIONINFO']._serialized_end=3760
  _globals['_UPDATECOLLECTIONREQUEST']._serialized_start=3763
  _globals['_UPDATECOLLECTIONREQUEST']._serialized_end=3971
  _globals['_UPDATECOLLECTIONRESPONSE']._serialized_start=3973
  _globals['_UPDATECOLLECTIONRESPONSE']._serialized_end=4064
  _globals['_DELETECOLLECTIONREQUEST']._serialized_start=4066
  _globals['_DELETECOLLECTIONREQUEST']._serialized_end=4163
  _globals['_DELETECOLLECTIONRESPONSE']._serialized_start=4165
  _globals['_DELETECOLLECTIONRESPONSE']._serialized_end=4256
  _globals['_CREATECOLLECTIONALIASREQUEST']._serialized_start=4258
  _globals['_CREATECOLLECTIONALIASREQUEST']._serialized_end=4380
  _globals['_CREATECOLLECTIONALIASRESPONSE']._serialized_start=4382
  _globals['_CREATECOLLECTIONALIASRESPONSE']._serialized_end=4478
  _globals['_UPSERTPOINTSREQUEST']._serialized_start=4481
  _globals['_UPSERTPOINTSREQUEST']._serialized_end=4673
  _globals['_UPSERTPOINTSRESPONSE']._serialized_start=4675
  _globals['_UPSERTPOINTSRESPONSE']._serialized_end=4783
  _globals['_GETPOINTSREQUEST']._serialized_start=4786
  _globals['_GETPOINTSREQUEST']._serialized_end=4998
  _globals['_POINTID']._serialized_start=5000
  _globals['_POINTID']._serialized_end=5045
  _globals['_GETPOINTSRESPONSE']._serialized_start=5047
  _globals['_GETPOINTSRESPONSE']._serialized_end=5149
  _globals['_POINTIDLIST']._serialized_start=5151
  _globals['_POINTIDLIST']._serialized_end=5198
  _globals['_DELETEPOINTSREQUEST']._serialized_start=5201
  _globals['_DELETEPOINTSREQUEST']._serialized_end=5412
  _globals['_DELETEPOINTSRESPONSE']._serialized_start=5414
  _globals['_DELETEPOINTSRESPONSE']._serialized_end=5522
  _globals['_UPDATEPAYLOADREQUEST']._serialized_start=5525
  _globals['_UPDATEPAYLOADREQUEST']._serialized_end=5779
  _globals['_UPDATEPAYLOADRESPONSE']._serialized_start=5781
  _globals['_UPDATEPAYLOADRESPONSE']._serialized_end=5890
  _globals['_DELETEPAYLOADREQUEST']._serialized_start=5893
  _globals['_DELETEPAYLOADREQUEST']._serialized_end=6119
  _globals['_DELETEPAYLOADRESPONSE']._serialized_start=6121
  _globals['_DELETEPAYLOADRESPONSE']._serialized_end=6230
  _globals['_CLEARPAYLOADREQUEST']._serialized_start=6233
  _globals['_CLEARPAYLOADREQUEST']._serialized_end=6444
  _globals['_CLEARPAYLOADRESPONSE']._serialized_start=6446
  _globals['_CLEARPAYLOADRESPONSE']._serialized_end=6554
  _globals['_SEARCHREQUEST']._serialized_start=6557
  _globals['_SEARCHREQUEST']._serialized_end=7016
  _globals['_SEARCHRESPONSE']._serialized_start=7018
  _globals['_SEARCHRESPONSE']._serialized_end=7123
  _globals['_SEARCHBATCHREQUEST']._serialized_start=7126
  _globals['_SEARCHBATCHREQUEST']._serialized_end=7263
  _globals['_SEARCHBATCHRESPONSE']._serialized_start=7265
  _globals['_SEARCHBATCHRESPONSE']._serialized_end=7379
  _globals['_RECOMMENDREQUEST']._serialized_start=7382
  _globals['_RECOMMENDREQUEST']._serialized_end=7823
  _globals['_RECOMMENDRESPONSE']._serialized_start=7825
  _globals['_RECOMMENDRESPONSE']._serialized_end=7933
  _globals['_DISCOVERREQUEST']._serialized_start=7936
  _globals['_DISCOVERREQUEST']._serialized_end=8287
  _globals['_DISCOVERRESPONSE']._serialized_start=8289
  _globals['_DISCOVERRESPONSE']._serialized_end=8396
  _globals['_SCROLLREQUEST']._serialized_start=8399
  _globals['_SCROLLREQUEST']._serialized_end=8709
  _globals['_SCROLLRESPONSE']._serialized_start=8712
  _globals['_SCROLLRESPONSE']._serialized_end=8884
  _globals['_COUNTREQUEST']._serialized_start=8887
  _globals['_COUNTREQUEST']._serialized_end=9055
  _globals['_COUNTRESPONSE']._serialized_start=9057
  _globals['_COUNTRESPONSE']._serialized_end=9135
  _globals['_CREATEFIELDINDEXREQUEST']._serialized_start=9138
  _globals['_CREATEFIELDINDEXREQUEST']._serialized_end=9404
  _globals['_CREATEFIELDINDEXRESPONSE']._serialized_start=9406
  _globals['_CREATEFIELDINDEXRESPONSE']._serialized_end=9518
  _globals['_DELETEFIELDINDEXREQUEST']._serialized_start=9521
  _globals['_DELETEFIELDINDEXREQUEST']._serialized_end=9666
  _globals['_DELETEFIELDINDEXRESPONSE']._serialized_start=9668
  _globals['_DELETEFIELDINDEXRESPONSE']._serialized_end=9780
  _globals['_CREATESNAPSHOTREQUEST']._serialized_start=9782
  _globals['_CREATESNAPSHOTREQUEST']._serialized_end=9877
  _globals['_CREATESNAPSHOTRESPONSE']._serialized_start=9880
  _globals['_CREATESNAPSHOTRESPONSE']._serialized_end=10023
  _globals['_LISTSNAPSHOTSREQUEST']._serialized_start=10025
  _globals['_LISTSNAPSHOTSREQUEST']._serialized_end=10119
  _globals['_LISTSNAPSHOTSRESPONSE']._serialized_start=10121
  _globals['_LISTSNAPSHOTSRESPONSE']._serialized_end=10244
  _globals['_SNAPSHOTDESCRIPTION']._serialized_start=10246
  _globals['_SNAPSHOTDESCRIPTION']._serialized_end=10349
  _globals['_DELETESNAPSHOTREQUEST']._serialized_start=10351
  _globals['_DELETESNAPSHOTREQUEST']._serialized_end=10469
  _globals['_DELETESNAPSHOTRESPONSE']._serialized_start=10471
  _globals['_DELETESNAPSHOTRESPONSE']._serialized_end=10560
  _globals['_QDRANTHEALTHCHECKREQUEST']._serialized_start=10562
  _globals['_QDRANTHEALTHCHECKREQUEST']._serialized_end=10635
  _globals['_QDRANTHEALTHCHECKRESPONSE']._serialized_start=10637
  _globals['_QDRANTHEALTHCHECKRESPONSE']._serialized_end=10746
  _globals['_GETCLUSTERINFOREQUEST']._serialized_start=10748
  _globals['_GETCLUSTERINFOREQUEST']._serialized_end=10818
  _globals['_GETCLUSTERINFORESPONSE']._serialized_start=10820
  _globals['_GETCLUSTERINFORESPONSE']._serialized_end=10939
  _globals['_QDRANTSERVICE']._serialized_start=11060
  _globals['_QDRANTSERVICE']._serialized_end=13207
# @@protoc_insertion_point(module_scope)
