# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nats_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nats_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12nats_service.proto\x12\x08isa.nats\x1a\x0c\x63ommon.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xd2\x01\n\x0bNATSMessage\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x33\n\x07headers\x18\x03 \x03(\x0b\x32\".isa.nats.NATSMessage.HeadersEntry\x12\x10\n\x08reply_to\x18\x04 \x01(\t\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf0\x01\n\x0cStreamConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08subjects\x18\x02 \x03(\t\x12&\n\x07storage\x18\x03 \x01(\x0e\x32\x15.isa.nats.StorageType\x12\x10\n\x08max_msgs\x18\x04 \x01(\x05\x12\x11\n\tmax_bytes\x18\x05 \x01(\x03\x12*\n\x07max_age\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x14\n\x0cmax_msg_size\x18\x07 \x01(\x05\x12\x10\n\x08replicas\x18\x08 \x01(\x05\x12\x1f\n\x17\x64iscard_new_per_subject\x18\t \x01(\x08\"\x95\x01\n\nStreamInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x16.isa.nats.StreamConfig\x12$\n\x05state\x18\x03 \x01(\x0b\x32\x15.isa.nats.StreamState\x12+\n\x07\x63reated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xdc\x01\n\x0bStreamState\x12\x10\n\x08messages\x18\x01 \x01(\x03\x12\r\n\x05\x62ytes\x18\x02 \x01(\x03\x12\x11\n\tfirst_seq\x18\x03 \x01(\x03\x12\x10\n\x08last_seq\x18\x04 \x01(\x03\x12,\n\x08\x66irst_ts\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07last_ts\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0cnum_subjects\x18\x07 \x01(\x05\x12\x16\n\x0e\x63onsumer_count\x18\x08 \x01(\x05\"\xe4\x02\n\x0e\x43onsumerConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64urable_name\x18\x02 \x01(\t\x12\x16\n\x0e\x66ilter_subject\x18\x03 \x01(\t\x12\x31\n\x0f\x64\x65livery_policy\x18\x04 \x01(\x0e\x32\x18.isa.nats.DeliveryPolicy\x12\'\n\nack_policy\x18\x05 \x01(\x0e\x32\x13.isa.nats.AckPolicy\x12+\n\x08\x61\x63k_wait\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x13\n\x0bmax_deliver\x18\x07 \x01(\x05\x12-\n\rreplay_policy\x18\x08 \x01(\x0e\x32\x16.isa.nats.ReplayPolicy\x12\x15\n\ropt_start_seq\x18\t \x01(\x03\x12\x32\n\x0eopt_start_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xb0\x01\n\x0c\x43onsumerInfo\x12\x13\n\x0bstream_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12(\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x18.isa.nats.ConsumerConfig\x12&\n\x05state\x18\x04 \x01(\x0b\x32\x17.isa.nats.ConsumerState\x12+\n\x07\x63reated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"k\n\rConsumerState\x12\x15\n\rdelivered_seq\x18\x01 \x01(\x03\x12\x15\n\rack_floor_seq\x18\x02 \x01(\x03\x12\x13\n\x0bnum_pending\x18\x03 \x01(\x03\x12\x17\n\x0fnum_redelivered\x18\x04 \x01(\x03\"\xd3\x01\n\x0ePublishRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0f\n\x07subject\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x12\x36\n\x07headers\x18\x05 \x03(\x0b\x32%.isa.nats.PublishRequest.HeadersEntry\x12\x10\n\x08reply_to\x18\x06 \x01(\t\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x0fPublishResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"h\n\x13PublishBatchRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\'\n\x08messages\x18\x03 \x03(\x0b\x32\x15.isa.nats.NATSMessage\"P\n\x14PublishBatchResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x17\n\x0fpublished_count\x18\x02 \x01(\x05\x12\x0e\n\x06\x65rrors\x18\x03 \x03(\t\"b\n\x10SubscribeRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0f\n\x07subject\x18\x03 \x01(\t\x12\x13\n\x0bqueue_group\x18\x04 \x01(\t\"\xec\x01\n\x0fMessageResponse\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x37\n\x07headers\x18\x03 \x03(\x0b\x32&.isa.nats.MessageResponse.HeadersEntry\x12\x10\n\x08reply_to\x18\x04 \x01(\t\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08sequence\x18\x06 \x01(\x03\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"O\n\x12UnsubscribeRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0f\n\x07subject\x18\x03 \x01(\t\"&\n\x13UnsubscribeResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\x85\x01\n\x0eRequestRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0f\n\x07subject\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x12*\n\x07timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\"G\n\x0fRequestResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x15\n\rerror_message\x18\x03 \x01(\t\"g\n\x15QueueSubscribeRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0f\n\x07subject\x18\x03 \x01(\t\x12\x13\n\x0bqueue_group\x18\x04 \x01(\t\"g\n\x13\x43reateStreamRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12&\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x16.isa.nats.StreamConfig\"^\n\x14\x43reateStreamResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12$\n\x06stream\x18\x02 \x01(\x0b\x32\x14.isa.nats.StreamInfo\x12\x0f\n\x07message\x18\x03 \x01(\t\"T\n\x13\x44\x65leteStreamRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\"\'\n\x14\x44\x65leteStreamResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"U\n\x14GetStreamInfoRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\"=\n\x15GetStreamInfoResponse\x12$\n\x06stream\x18\x01 \x01(\x0b\x32\x14.isa.nats.StreamInfo\">\n\x12ListStreamsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\"<\n\x13ListStreamsResponse\x12%\n\x07streams\x18\x01 \x03(\x0b\x32\x14.isa.nats.StreamInfo\"|\n\x13UpdateStreamRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\x12&\n\x06\x63onfig\x18\x04 \x01(\x0b\x32\x16.isa.nats.StreamConfig\"M\n\x14UpdateStreamResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12$\n\x06stream\x18\x02 \x01(\x0b\x32\x14.isa.nats.StreamInfo\"d\n\x12PurgeStreamRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\x12\x0f\n\x07subject\x18\x04 \x01(\t\"<\n\x13PurgeStreamResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x14\n\x0cpurged_count\x18\x02 \x01(\x03\"\x80\x01\n\x15\x43reateConsumerRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\x12(\n\x06\x63onfig\x18\x04 \x01(\x0b\x32\x18.isa.nats.ConsumerConfig\"d\n\x16\x43reateConsumerResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12(\n\x08\x63onsumer\x18\x02 \x01(\x0b\x32\x16.isa.nats.ConsumerInfo\x12\x0f\n\x07message\x18\x03 \x01(\t\"m\n\x15\x44\x65leteConsumerRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\x12\x15\n\rconsumer_name\x18\x04 \x01(\t\")\n\x16\x44\x65leteConsumerResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"n\n\x16GetConsumerInfoRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\x12\x15\n\rconsumer_name\x18\x04 \x01(\t\"C\n\x17GetConsumerInfoResponse\x12(\n\x08\x63onsumer\x18\x01 \x01(\x0b\x32\x16.isa.nats.ConsumerInfo\"U\n\x14ListConsumersRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\"B\n\x15ListConsumersResponse\x12)\n\tconsumers\x18\x01 \x03(\x0b\x32\x16.isa.nats.ConsumerInfo\"\xe6\x01\n\x16PublishToStreamRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\x12\x0f\n\x07subject\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\x12>\n\x07headers\x18\x06 \x03(\x0b\x32-.isa.nats.PublishToStreamRequest.HeadersEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"|\n\x17PublishToStreamResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x10\n\x08sequence\x18\x02 \x01(\x03\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07message\x18\x04 \x01(\t\"\xac\x01\n\x13PullMessagesRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\x12\x15\n\rconsumer_name\x18\x04 \x01(\t\x12\x12\n\nbatch_size\x18\x05 \x01(\x05\x12+\n\x08max_wait\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\"D\n\x14PullMessagesResponse\x12,\n\x08messages\x18\x01 \x03(\x0b\x32\x1a.isa.nats.JetStreamMessage\"\xf3\x01\n\x10JetStreamMessage\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x38\n\x07headers\x18\x03 \x03(\x0b\x32\'.isa.nats.JetStreamMessage.HeadersEntry\x12\x10\n\x08sequence\x18\x04 \x01(\x03\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rnum_delivered\x18\x06 \x01(\x05\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"{\n\x11\x41\x63kMessageRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\x12\x15\n\rconsumer_name\x18\x04 \x01(\t\x12\x10\n\x08sequence\x18\x05 \x01(\x03\"%\n\x12\x41\x63kMessageResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\xa5\x01\n\x11NakMessageRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\x12\x15\n\rconsumer_name\x18\x04 \x01(\t\x12\x10\n\x08sequence\x18\x05 \x01(\x03\x12(\n\x05\x64\x65lay\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\"%\n\x12NakMessageResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"d\n\x0cKVPutRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\x0c\"2\n\rKVPutResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x10\n\x08revision\x18\x02 \x01(\x03\"U\n\x0cKVGetRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\"l\n\rKVGetResponse\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x10\n\x08revision\x18\x03 \x01(\x03\x12+\n\x07\x63reated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"X\n\x0fKVDeleteRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\"#\n\x10KVDeleteResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"I\n\rKVKeysRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\"\x1e\n\x0eKVKeysResponse\x12\x0c\n\x04keys\x18\x01 \x03(\t\"\xdc\x01\n\x10ObjectPutRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x13\n\x0bobject_name\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\x12:\n\x08metadata\x18\x06 \x03(\x0b\x32(.isa.nats.ObjectPutRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n\x11ObjectPutResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x11\n\tobject_id\x18\x02 \x01(\t\"a\n\x10ObjectGetRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x13\n\x0bobject_name\x18\x04 \x01(\t\"\x9e\x01\n\x11ObjectGetResponse\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12;\n\x08metadata\x18\x03 \x03(\x0b\x32).isa.nats.ObjectGetResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"d\n\x13ObjectDeleteRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x13\n\x0bobject_name\x18\x04 \x01(\t\"\'\n\x14ObjectDeleteResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"M\n\x11ObjectListRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\";\n\x12ObjectListResponse\x12%\n\x07objects\x18\x01 \x03(\x0b\x32\x14.isa.nats.ObjectInfo\"\xbd\x01\n\nObjectInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x03\x12,\n\x08modified\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x08metadata\x18\x04 \x03(\x0b\x32\".isa.nats.ObjectInfo.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"@\n\x14GetStatisticsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\"\xd1\x01\n\x15GetStatisticsResponse\x12\x15\n\rtotal_streams\x18\x01 \x01(\x03\x12\x17\n\x0ftotal_consumers\x18\x02 \x01(\x03\x12\x16\n\x0etotal_messages\x18\x03 \x01(\x03\x12\x13\n\x0btotal_bytes\x18\x04 \x01(\x03\x12\x13\n\x0b\x63onnections\x18\x05 \x01(\x05\x12\x0f\n\x07in_msgs\x18\x06 \x01(\x03\x12\x10\n\x08out_msgs\x18\x07 \x01(\x03\x12\x10\n\x08in_bytes\x18\x08 \x01(\x03\x12\x11\n\tout_bytes\x18\t \x01(\x03\"V\n\x15GetStreamStatsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\"\x8f\x01\n\x16GetStreamStatsResponse\x12\x13\n\x0bstream_name\x18\x01 \x01(\t\x12\x10\n\x08messages\x18\x02 \x01(\x03\x12\r\n\x05\x62ytes\x18\x03 \x01(\x03\x12\x16\n\x0e\x63onsumer_count\x18\x04 \x01(\x05\x12\x14\n\x0cmessage_rate\x18\x05 \x01(\x01\x12\x11\n\tbyte_rate\x18\x06 \x01(\x01\",\n\x16NATSHealthCheckRequest\x12\x12\n\ndeep_check\x18\x01 \x01(\x08\"\xb0\x01\n\x17NATSHealthCheckResponse\x12\x0f\n\x07healthy\x18\x01 \x01(\x08\x12\x13\n\x0bnats_status\x18\x02 \x01(\t\x12\x19\n\x11jetstream_enabled\x18\x03 \x01(\x08\x12\x13\n\x0b\x63onnections\x18\x04 \x01(\x05\x12.\n\nchecked_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07message\x18\x06 \x01(\t*\xa2\x01\n\x0e\x44\x65liveryPolicy\x12\x10\n\x0c\x44\x45LIVERY_ALL\x10\x00\x12\x11\n\rDELIVERY_LAST\x10\x01\x12\x10\n\x0c\x44\x45LIVERY_NEW\x10\x02\x12\x1e\n\x1a\x44\x45LIVERY_BY_START_SEQUENCE\x10\x03\x12\x1a\n\x16\x44\x45LIVERY_BY_START_TIME\x10\x04\x12\x1d\n\x19\x44\x45LIVERY_LAST_PER_SUBJECT\x10\x05*8\n\tAckPolicy\x12\x10\n\x0c\x41\x43K_EXPLICIT\x10\x00\x12\x0b\n\x07\x41\x43K_ALL\x10\x01\x12\x0c\n\x08\x41\x43K_NONE\x10\x02*7\n\x0cReplayPolicy\x12\x12\n\x0eREPLAY_INSTANT\x10\x00\x12\x13\n\x0fREPLAY_ORIGINAL\x10\x01*3\n\x0bStorageType\x12\x10\n\x0cSTORAGE_FILE\x10\x00\x12\x12\n\x0eSTORAGE_MEMORY\x10\x01\x32\xb5\x12\n\x0bNATSService\x12>\n\x07Publish\x12\x18.isa.nats.PublishRequest\x1a\x19.isa.nats.PublishResponse\x12M\n\x0cPublishBatch\x12\x1d.isa.nats.PublishBatchRequest\x1a\x1e.isa.nats.PublishBatchResponse\x12\x44\n\tSubscribe\x12\x1a.isa.nats.SubscribeRequest\x1a\x19.isa.nats.MessageResponse0\x01\x12J\n\x0bUnsubscribe\x12\x1c.isa.nats.UnsubscribeRequest\x1a\x1d.isa.nats.UnsubscribeResponse\x12>\n\x07Request\x12\x18.isa.nats.RequestRequest\x1a\x19.isa.nats.RequestResponse\x12N\n\x0eQueueSubscribe\x12\x1f.isa.nats.QueueSubscribeRequest\x1a\x19.isa.nats.MessageResponse0\x01\x12M\n\x0c\x43reateStream\x12\x1d.isa.nats.CreateStreamRequest\x1a\x1e.isa.nats.CreateStreamResponse\x12M\n\x0c\x44\x65leteStream\x12\x1d.isa.nats.DeleteStreamRequest\x1a\x1e.isa.nats.DeleteStreamResponse\x12P\n\rGetStreamInfo\x12\x1e.isa.nats.GetStreamInfoRequest\x1a\x1f.isa.nats.GetStreamInfoResponse\x12J\n\x0bListStreams\x12\x1c.isa.nats.ListStreamsRequest\x1a\x1d.isa.nats.ListStreamsResponse\x12M\n\x0cUpdateStream\x12\x1d.isa.nats.UpdateStreamRequest\x1a\x1e.isa.nats.UpdateStreamResponse\x12J\n\x0bPurgeStream\x12\x1c.isa.nats.PurgeStreamRequest\x1a\x1d.isa.nats.PurgeStreamResponse\x12S\n\x0e\x43reateConsumer\x12\x1f.isa.nats.CreateConsumerRequest\x1a .isa.nats.CreateConsumerResponse\x12S\n\x0e\x44\x65leteConsumer\x12\x1f.isa.nats.DeleteConsumerRequest\x1a .isa.nats.DeleteConsumerResponse\x12V\n\x0fGetConsumerInfo\x12 .isa.nats.GetConsumerInfoRequest\x1a!.isa.nats.GetConsumerInfoResponse\x12P\n\rListConsumers\x12\x1e.isa.nats.ListConsumersRequest\x1a\x1f.isa.nats.ListConsumersResponse\x12V\n\x0fPublishToStream\x12 .isa.nats.PublishToStreamRequest\x1a!.isa.nats.PublishToStreamResponse\x12M\n\x0cPullMessages\x12\x1d.isa.nats.PullMessagesRequest\x1a\x1e.isa.nats.PullMessagesResponse\x12G\n\nAckMessage\x12\x1b.isa.nats.AckMessageRequest\x1a\x1c.isa.nats.AckMessageResponse\x12G\n\nNakMessage\x12\x1b.isa.nats.NakMessageRequest\x1a\x1c.isa.nats.NakMessageResponse\x12\x38\n\x05KVPut\x12\x16.isa.nats.KVPutRequest\x1a\x17.isa.nats.KVPutResponse\x12\x38\n\x05KVGet\x12\x16.isa.nats.KVGetRequest\x1a\x17.isa.nats.KVGetResponse\x12\x41\n\x08KVDelete\x12\x19.isa.nats.KVDeleteRequest\x1a\x1a.isa.nats.KVDeleteResponse\x12;\n\x06KVKeys\x12\x17.isa.nats.KVKeysRequest\x1a\x18.isa.nats.KVKeysResponse\x12\x44\n\tObjectPut\x12\x1a.isa.nats.ObjectPutRequest\x1a\x1b.isa.nats.ObjectPutResponse\x12\x44\n\tObjectGet\x12\x1a.isa.nats.ObjectGetRequest\x1a\x1b.isa.nats.ObjectGetResponse\x12M\n\x0cObjectDelete\x12\x1d.isa.nats.ObjectDeleteRequest\x1a\x1e.isa.nats.ObjectDeleteResponse\x12G\n\nObjectList\x12\x1b.isa.nats.ObjectListRequest\x1a\x1c.isa.nats.ObjectListResponse\x12P\n\rGetStatistics\x12\x1e.isa.nats.GetStatisticsRequest\x1a\x1f.isa.nats.GetStatisticsResponse\x12S\n\x0eGetStreamStats\x12\x1f.isa.nats.GetStreamStatsRequest\x1a .isa.nats.GetStreamStatsResponse\x12R\n\x0bHealthCheck\x12 .isa.nats.NATSHealthCheckRequest\x1a!.isa.nats.NATSHealthCheckResponseB/Z-github.com/isa-cloud/isa_cloud/api/proto/natsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nats_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/isa-cloud/isa_cloud/api/proto/nats'
  _globals['_NATSMESSAGE_HEADERSENTRY']._loaded_options = None
  _globals['_NATSMESSAGE_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_MESSAGERESPONSE_HEADERSENTRY']._loaded_options = None
  _globals['_MESSAGERESPONSE_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_PUBLISHTOSTREAMREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_PUBLISHTOSTREAMREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_JETSTREAMMESSAGE_HEADERSENTRY']._loaded_options = None
  _globals['_JETSTREAMMESSAGE_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_OBJECTPUTREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_OBJECTPUTREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_OBJECTGETRESPONSE_METADATAENTRY']._loaded_options = None
  _globals['_OBJECTGETRESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_OBJECTINFO_METADATAENTRY']._loaded_options = None
  _globals['_OBJECTINFO_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_DELIVERYPOLICY']._serialized_start=8073
  _globals['_DELIVERYPOLICY']._serialized_end=8235
  _globals['_ACKPOLICY']._serialized_start=8237
  _globals['_ACKPOLICY']._serialized_end=8293
  _globals['_REPLAYPOLICY']._serialized_start=8295
  _globals['_REPLAYPOLICY']._serialized_end=8350
  _globals['_STORAGETYPE']._serialized_start=8352
  _globals['_STORAGETYPE']._serialized_end=8403
  _globals['_NATSMESSAGE']._serialized_start=112
  _globals['_NATSMESSAGE']._serialized_end=322
  _globals['_NATSMESSAGE_HEADERSENTRY']._serialized_start=276
  _globals['_NATSMESSAGE_HEADERSENTRY']._serialized_end=322
  _globals['_STREAMCONFIG']._serialized_start=325
  _globals['_STREAMCONFIG']._serialized_end=565
  _globals['_STREAMINFO']._serialized_start=568
  _globals['_STREAMINFO']._serialized_end=717
  _globals['_STREAMSTATE']._serialized_start=720
  _globals['_STREAMSTATE']._serialized_end=940
  _globals['_CONSUMERCONFIG']._serialized_start=943
  _globals['_CONSUMERCONFIG']._serialized_end=1299
  _globals['_CONSUMERINFO']._serialized_start=1302
  _globals['_CONSUMERINFO']._serialized_end=1478
  _globals['_CONSUMERSTATE']._serialized_start=1480
  _globals['_CONSUMERSTATE']._serialized_end=1587
  _globals['_PUBLISHREQUEST']._serialized_start=1590
  _globals['_PUBLISHREQUEST']._serialized_end=1801
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._serialized_start=276
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._serialized_end=322
  _globals['_PUBLISHRESPONSE']._serialized_start=1803
  _globals['_PUBLISHRESPONSE']._serialized_end=1854
  _globals['_PUBLISHBATCHREQUEST']._serialized_start=1856
  _globals['_PUBLISHBATCHREQUEST']._serialized_end=1960
  _globals['_PUBLISHBATCHRESPONSE']._serialized_start=1962
  _globals['_PUBLISHBATCHRESPONSE']._serialized_end=2042
  _globals['_SUBSCRIBEREQUEST']._serialized_start=2044
  _globals['_SUBSCRIBEREQUEST']._serialized_end=2142
  _globals['_MESSAGERESPONSE']._serialized_start=2145
  _globals['_MESSAGERESPONSE']._serialized_end=2381
  _globals['_MESSAGERESPONSE_HEADERSENTRY']._serialized_start=276
  _globals['_MESSAGERESPONSE_HEADERSENTRY']._serialized_end=322
  _globals['_UNSUBSCRIBEREQUEST']._serialized_start=2383
  _globals['_UNSUBSCRIBEREQUEST']._serialized_end=2462
  _globals['_UNSUBSCRIBERESPONSE']._serialized_start=2464
  _globals['_UNSUBSCRIBERESPONSE']._serialized_end=2502
  _globals['_REQUESTREQUEST']._serialized_start=2505
  _globals['_REQUESTREQUEST']._serialized_end=2638
  _globals['_REQUESTRESPONSE']._serialized_start=2640
  _globals['_REQUESTRESPONSE']._serialized_end=2711
  _globals['_QUEUESUBSCRIBEREQUEST']._serialized_start=2713
  _globals['_QUEUESUBSCRIBEREQUEST']._serialized_end=2816
  _globals['_CREATESTREAMREQUEST']._serialized_start=2818
  _globals['_CREATESTREAMREQUEST']._serialized_end=2921
  _globals['_CREATESTREAMRESPONSE']._serialized_start=2923
  _globals['_CREATESTREAMRESPONSE']._serialized_end=3017
  _globals['_DELETESTREAMREQUEST']._serialized_start=3019
  _globals['_DELETESTREAMREQUEST']._serialized_end=3103
  _globals['_DELETESTREAMRESPONSE']._serialized_start=3105
  _globals['_DELETESTREAMRESPONSE']._serialized_end=3144
  _globals['_GETSTREAMINFOREQUEST']._serialized_start=3146
  _globals['_GETSTREAMINFOREQUEST']._serialized_end=3231
  _globals['_GETSTREAMINFORESPONSE']._serialized_start=3233
  _globals['_GETSTREAMINFORESPONSE']._serialized_end=3294
  _globals['_LISTSTREAMSREQUEST']._serialized_start=3296
  _globals['_LISTSTREAMSREQUEST']._serialized_end=3358
  _globals['_LISTSTREAMSRESPONSE']._serialized_start=3360
  _globals['_LISTSTREAMSRESPONSE']._serialized_end=3420
  _globals['_UPDATESTREAMREQUEST']._serialized_start=3422
  _globals['_UPDATESTREAMREQUEST']._serialized_end=3546
  _globals['_UPDATESTREAMRESPONSE']._serialized_start=3548
  _globals['_UPDATESTREAMRESPONSE']._serialized_end=3625
  _globals['_PURGESTREAMREQUEST']._serialized_start=3627
  _globals['_PURGESTREAMREQUEST']._serialized_end=3727
  _globals['_PURGESTREAMRESPONSE']._serialized_start=3729
  _globals['_PURGESTREAMRESPONSE']._serialized_end=3789
  _globals['_CREATECONSUMERREQUEST']._serialized_start=3792
  _globals['_CREATECONSUMERREQUEST']._serialized_end=3920
  _globals['_CREATECONSUMERRESPONSE']._serialized_start=3922
  _globals['_CREATECONSUMERRESPONSE']._serialized_end=4022
  _globals['_DELETECONSUMERREQUEST']._serialized_start=4024
  _globals['_DELETECONSUMERREQUEST']._serialized_end=4133
  _globals['_DELETECONSUMERRESPONSE']._serialized_start=4135
  _globals['_DELETECONSUMERRESPONSE']._serialized_end=4176
  _globals['_GETCONSUMERINFOREQUEST']._serialized_start=4178
  _globals['_GETCONSUMERINFOREQUEST']._serialized_end=4288
  _globals['_GETCONSUMERINFORESPONSE']._serialized_start=4290
  _globals['_GETCONSUMERINFORESPONSE']._serialized_end=4357
  _globals['_LISTCONSUMERSREQUEST']._serialized_start=4359
  _globals['_LISTCONSUMERSREQUEST']._serialized_end=4444
  _globals['_LISTCONSUMERSRESPONSE']._serialized_start=4446
  _globals['_LISTCONSUMERSRESPONSE']._serialized_end=4512
  _globals['_PUBLISHTOSTREAMREQUEST']._serialized_start=4515
  _globals['_PUBLISHTOSTREAMREQUEST']._serialized_end=4745
  _globals['_PUBLISHTOSTREAMREQUEST_HEADERSENTRY']._serialized_start=276
  _globals['_PUBLISHTOSTREAMREQUEST_HEADERSENTRY']._serialized_end=322
  _globals['_PUBLISHTOSTREAMRESPONSE']._serialized_start=4747
  _globals['_PUBLISHTOSTREAMRESPONSE']._serialized_end=4871
  _globals['_PULLMESSAGESREQUEST']._serialized_start=4874
  _globals['_PULLMESSAGESREQUEST']._serialized_end=5046
  _globals['_PULLMESSAGESRESPONSE']._serialized_start=5048
  _globals['_PULLMESSAGESRESPONSE']._serialized_end=5116
  _globals['_JETSTREAMMESSAGE']._serialized_start=5119
  _globals['_JETSTREAMMESSAGE']._serialized_end=5362
  _globals['_JETSTREAMMESSAGE_HEADERSENTRY']._serialized_start=276
  _globals['_JETSTREAMMESSAGE_HEADERSENTRY']._serialized_end=322
  _globals['_ACKMESSAGEREQUEST']._serialized_start=5364
  _globals['_ACKMESSAGEREQUEST']._serialized_end=5487
  _globals['_ACKMESSAGERESPONSE']._serialized_start=5489
  _globals['_ACKMESSAGERESPONSE']._serialized_end=5526
  _globals['_NAKMESSAGEREQUEST']._serialized_start=5529
  _globals['_NAKMESSAGEREQUEST']._serialized_end=5694
  _globals['_NAKMESSAGERESPONSE']._serialized_start=5696
  _globals['_NAKMESSAGERESPONSE']._serialized_end=5733
  _globals['_KVPUTREQUEST']._serialized_start=5735
  _globals['_KVPUTREQUEST']._serialized_end=5835
  _globals['_KVPUTRESPONSE']._serialized_start=5837
  _globals['_KVPUTRESPONSE']._serialized_end=5887
  _globals['_KVGETREQUEST']._serialized_start=5889
  _globals['_KVGETREQUEST']._serialized_end=5974
  _globals['_KVGETRESPONSE']._serialized_start=5976
  _globals['_KVGETRESPONSE']._serialized_end=6084
  _globals['_KVDELETEREQUEST']._serialized_start=6086
  _globals['_KVDELETEREQUEST']._serialized_end=6174
  _globals['_KVDELETERESPONSE']._serialized_start=6176
  _globals['_KVDELETERESPONSE']._serialized_end=6211
  _globals['_KVKEYSREQUEST']._serialized_start=6213
  _globals['_KVKEYSREQUEST']._serialized_end=6286
  _globals['_KVKEYSRESPONSE']._serialized_start=6288
  _globals['_KVKEYSRESPONSE']._serialized_end=6318
  _globals['_OBJECTPUTREQUEST']._serialized_start=6321
  _globals['_OBJECTPUTREQUEST']._serialized_end=6541
  _globals['_OBJECTPUTREQUEST_METADATAENTRY']._serialized_start=6494
  _globals['_OBJECTPUTREQUEST_METADATAENTRY']._serialized_end=6541
  _globals['_OBJECTPUTRESPONSE']._serialized_start=6543
  _globals['_OBJECTPUTRESPONSE']._serialized_end=6598
  _globals['_OBJECTGETREQUEST']._serialized_start=6600
  _globals['_OBJECTGETREQUEST']._serialized_end=6697
  _globals['_OBJECTGETRESPONSE']._serialized_start=6700
  _globals['_OBJECTGETRESPONSE']._serialized_end=6858
  _globals['_OBJECTGETRESPONSE_METADATAENTRY']._serialized_start=6494
  _globals['_OBJECTGETRESPONSE_METADATAENTRY']._serialized_end=6541
  _globals['_OBJECTDELETEREQUEST']._serialized_start=6860
  _globals['_OBJECTDELETEREQUEST']._serialized_end=6960
  _globals['_OBJECTDELETERESPONSE']._serialized_start=6962
  _globals['_OBJECTDELETERESPONSE']._serialized_end=7001
  _globals['_OBJECTLISTREQUEST']._serialized_start=7003
  _globals['_OBJECTLISTREQUEST']._serialized_end=7080
  _globals['_OBJECTLISTRESPONSE']._serialized_start=7082
  _globals['_OBJECTLISTRESPONSE']._serialized_end=7141
  _globals['_OBJECTINFO']._serialized_start=7144
  _globals['_OBJECTINFO']._serialized_end=7333
  _globals['_OBJECTINFO_METADATAENTRY']._serialized_start=6494
  _globals['_OBJECTINFO_METADATAENTRY']._serialized_end=6541
  _globals['_GETSTATISTICSREQUEST']._serialized_start=7335
  _globals['_GETSTATISTICSREQUEST']._serialized_end=7399
  _globals['_GETSTATISTICSRESPONSE']._serialized_start=7402
  _globals['_GETSTATISTICSRESPONSE']._serialized_end=7611
  _globals['_GETSTREAMSTATSREQUEST']._serialized_start=7613
  _globals['_GETSTREAMSTATSREQUEST']._serialized_end=7699
  _globals['_GETSTREAMSTATSRESPONSE']._serialized_start=7702
  _globals['_GETSTREAMSTATSRESPONSE']._serialized_end=7845
  _globals['_NATSHEALTHCHECKREQUEST']._serialized_start=7847
  _globals['_NATSHEALTHCHECKREQUEST']._serialized_end=7891
  _globals['_NATSHEALTHCHECKRESPONSE']._serialized_start=7894
  _globals['_NATSHEALTHCHECKRESPONSE']._serialized_end=8070
  _globals['_NATSSERVICE']._serialized_start=8406
  _globals['_NATSSERVICE']._serialized_end=10763
# @@protoc_insertion_point(module_scope)
