# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: mqtt_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'mqtt_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12mqtt_service.proto\x12\x08isa.mqtt\x1a\x0c\x63ommon.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xb1\x03\n\nDeviceInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x03 \x01(\t\x12\x0f\n\x07user_id\x18\x04 \x01(\t\x12\x17\n\x0forganization_id\x18\x05 \x01(\t\x12&\n\x06status\x18\x06 \x01(\x0e\x32\x16.isa.mqtt.DeviceStatus\x12\x31\n\rregistered_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tlast_seen\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x08metadata\x18\t \x03(\x0b\x32\".isa.mqtt.DeviceInfo.MetadataEntry\x12\x19\n\x11subscribed_topics\x18\n \x03(\t\x12\x15\n\rmessages_sent\x18\x0b \x01(\x03\x12\x19\n\x11messages_received\x18\x0c \x01(\x03\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xca\x01\n\tTopicInfo\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x18\n\x10subscriber_count\x18\x02 \x01(\x03\x12\x15\n\rmessage_count\x18\x03 \x01(\x03\x12\x35\n\x11last_message_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x14has_retained_message\x18\x05 \x01(\x08\x12\x0f\n\x07user_id\x18\x06 \x01(\t\x12\x17\n\x0forganization_id\x18\x07 \x01(\t\"\x91\x02\n\x0bMQTTMessage\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x1f\n\x03qos\x18\x03 \x01(\x0e\x32\x12.isa.mqtt.QoSLevel\x12\x10\n\x08retained\x18\x04 \x01(\x08\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nmessage_id\x18\x06 \x01(\t\x12\x39\n\nproperties\x18\x07 \x03(\x0b\x32%.isa.mqtt.MQTTMessage.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe8\x01\n\x0e\x43onnectRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\x15\n\rclean_session\x18\x05 \x01(\x08\x12\x12\n\nkeep_alive\x18\x06 \x01(\x05\x12\x12\n\nwill_topic\x18\x07 \x01(\t\x12\x14\n\x0cwill_payload\x18\x08 \x01(\x0c\x12$\n\x08will_qos\x18\t \x01(\x0e\x32\x12.isa.mqtt.QoSLevel\x12\x13\n\x0bwill_retain\x18\n \x01(\x08\"`\n\x0f\x43onnectResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x17\n\x0fsession_present\x18\x04 \x01(\x08\"8\n\x11\x44isconnectRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"6\n\x12\x44isconnectResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\">\n\x17\x43onnectionStatusRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"\x91\x01\n\x18\x43onnectionStatusResponse\x12\x11\n\tconnected\x18\x01 \x01(\x08\x12\x30\n\x0c\x63onnected_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rmessages_sent\x18\x03 \x01(\x03\x12\x19\n\x11messages_received\x18\x04 \x01(\x03\"\xf9\x01\n\x0ePublishRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\t\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\x12\x1f\n\x03qos\x18\x05 \x01(\x0e\x32\x12.isa.mqtt.QoSLevel\x12\x10\n\x08retained\x18\x06 \x01(\x08\x12<\n\nproperties\x18\x07 \x03(\x0b\x32(.isa.mqtt.PublishRequest.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x0fPublishResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x12\n\nmessage_id\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x30\n\x0cpublished_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"f\n\x13PublishBatchRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12*\n\x08messages\x18\x03 \x03(\x0b\x32\x18.isa.mqtt.PublishRequest\"{\n\x14PublishBatchResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x17\n\x0fpublished_count\x18\x02 \x01(\x05\x12\x14\n\x0c\x66\x61iled_count\x18\x03 \x01(\x05\x12\x13\n\x0bmessage_ids\x18\x04 \x03(\t\x12\x0e\n\x06\x65rrors\x18\x05 \x03(\t\"\xa2\x01\n\x12PublishJSONRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\t\x12%\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1f\n\x03qos\x18\x05 \x01(\x0e\x32\x12.isa.mqtt.QoSLevel\x12\x10\n\x08retained\x18\x06 \x01(\x08\"n\n\x10SubscribeRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x14\n\x0ctopic_filter\x18\x03 \x01(\t\x12\x1f\n\x03qos\x18\x04 \x01(\x0e\x32\x12.isa.mqtt.QoSLevel\"s\n\x18SubscribeMultipleRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x32\n\rsubscriptions\x18\x03 \x03(\x0b\x32\x1b.isa.mqtt.TopicSubscription\"J\n\x11TopicSubscription\x12\x14\n\x0ctopic_filter\x18\x01 \x01(\t\x12\x1f\n\x03qos\x18\x02 \x01(\x0e\x32\x12.isa.mqtt.QoSLevel\"\x99\x02\n\x0fMessageResponse\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x1f\n\x03qos\x18\x03 \x01(\x0e\x32\x12.isa.mqtt.QoSLevel\x12\x10\n\x08retained\x18\x04 \x01(\x08\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nmessage_id\x18\x06 \x01(\t\x12=\n\nproperties\x18\x07 \x03(\x0b\x32).isa.mqtt.MessageResponse.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"P\n\x12UnsubscribeRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x15\n\rtopic_filters\x18\x03 \x03(\t\"S\n\x13UnsubscribeResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x1a\n\x12unsubscribed_count\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\"?\n\x18ListSubscriptionsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\"O\n\x19ListSubscriptionsResponse\x12\x32\n\rsubscriptions\x18\x01 \x03(\x0b\x32\x1b.isa.mqtt.TopicSubscription\"\xf0\x01\n\x15RegisterDeviceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65vice_name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x05 \x01(\t\x12?\n\x08metadata\x18\x06 \x03(\x0b\x32-.isa.mqtt.RegisterDeviceRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"`\n\x16RegisterDeviceResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12$\n\x06\x64\x65vice\x18\x02 \x01(\x0b\x32\x14.isa.mqtt.DeviceInfo\x12\x0f\n\x07message\x18\x03 \x01(\t\"=\n\x17UnregisterDeviceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x11\n\tdevice_id\x18\x02 \x01(\t\"<\n\x18UnregisterDeviceResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x87\x01\n\x12ListDevicesRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12&\n\x06status\x18\x03 \x01(\x0e\x32\x16.isa.mqtt.DeviceStatus\x12\x0c\n\x04page\x18\x04 \x01(\x05\x12\x11\n\tpage_size\x18\x05 \x01(\x05\"r\n\x13ListDevicesResponse\x12%\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x14.isa.mqtt.DeviceInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x11\n\tpage_size\x18\x04 \x01(\x05\":\n\x14GetDeviceInfoRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x11\n\tdevice_id\x18\x02 \x01(\t\"=\n\x15GetDeviceInfoResponse\x12$\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x14.isa.mqtt.DeviceInfo\"\xdd\x01\n\x19UpdateDeviceStatusRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x11\n\tdevice_id\x18\x02 \x01(\t\x12&\n\x06status\x18\x03 \x01(\x0e\x32\x16.isa.mqtt.DeviceStatus\x12\x43\n\x08metadata\x18\x04 \x03(\x0b\x32\x31.isa.mqtt.UpdateDeviceStatusRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"S\n\x1aUpdateDeviceStatusResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12$\n\x06\x64\x65vice\x18\x02 \x01(\x0b\x32\x14.isa.mqtt.DeviceInfo\"5\n\x13GetTopicInfoRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\"?\n\x14GetTopicInfoResponse\x12\'\n\ntopic_info\x18\x01 \x01(\x0b\x32\x13.isa.mqtt.TopicInfo\"n\n\x11ListTopicsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0e\n\x06prefix\x18\x03 \x01(\t\x12\x0c\n\x04page\x18\x04 \x01(\x05\x12\x11\n\tpage_size\x18\x05 \x01(\x05\"N\n\x12ListTopicsResponse\x12#\n\x06topics\x18\x01 \x03(\x0b\x32\x13.isa.mqtt.TopicInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\">\n\x14ValidateTopicRequest\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x17\n\x0f\x61llow_wildcards\x18\x02 \x01(\x08\"K\n\x15ValidateTopicResponse\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x12\n\nviolations\x18\x03 \x03(\t\"m\n\x19SetRetainedMessageRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x12\x1f\n\x03qos\x18\x04 \x01(\x0e\x32\x12.isa.mqtt.QoSLevel\">\n\x1aSetRetainedMessageResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\";\n\x19GetRetainedMessageRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\"S\n\x1aGetRetainedMessageResponse\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12&\n\x07message\x18\x02 \x01(\x0b\x32\x15.isa.mqtt.MQTTMessage\">\n\x1c\x44\x65leteRetainedMessageRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\"A\n\x1d\x44\x65leteRetainedMessageResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"@\n\x14GetStatisticsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\"\xee\x02\n\x15GetStatisticsResponse\x12\x15\n\rtotal_devices\x18\x01 \x01(\x03\x12\x16\n\x0eonline_devices\x18\x02 \x01(\x03\x12\x14\n\x0ctotal_topics\x18\x03 \x01(\x03\x12\x1b\n\x13total_subscriptions\x18\x04 \x01(\x03\x12\x1b\n\x13messages_sent_today\x18\x05 \x01(\x03\x12\x1f\n\x17messages_received_today\x18\x06 \x01(\x03\x12\x17\n\x0f\x61\x63tive_sessions\x18\x07 \x01(\x03\x12]\n\x18\x64\x65vice_type_distribution\x18\x08 \x03(\x0b\x32;.isa.mqtt.GetStatisticsResponse.DeviceTypeDistributionEntry\x1a=\n\x1b\x44\x65viceTypeDistributionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\x9b\x01\n\x17GetDeviceMetricsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x11\n\tdevice_id\x18\x02 \x01(\t\x12.\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xeb\x01\n\x18GetDeviceMetricsResponse\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x15\n\rmessages_sent\x18\x02 \x01(\x03\x12\x19\n\x11messages_received\x18\x03 \x01(\x03\x12\x12\n\nbytes_sent\x18\x04 \x01(\x03\x12\x16\n\x0e\x62ytes_received\x18\x05 \x01(\x03\x12/\n\x0cmessage_rate\x18\x06 \x03(\x0b\x32\x19.isa.mqtt.TimeSeriesPoint\x12-\n\nerror_rate\x18\x07 \x03(\x0b\x32\x19.isa.mqtt.TimeSeriesPoint\"O\n\x0fTimeSeriesPoint\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\",\n\x16MQTTHealthCheckRequest\x12\x12\n\ndeep_check\x18\x01 \x01(\x08\"\x9e\x01\n\x17MQTTHealthCheckResponse\x12\x0f\n\x07healthy\x18\x01 \x01(\x08\x12\x15\n\rbroker_status\x18\x02 \x01(\t\x12\x1a\n\x12\x61\x63tive_connections\x18\x03 \x01(\x03\x12.\n\nchecked_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xaa\x01\n\x1eSubscribeDeviceMessagesRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x32\n\rmessage_types\x18\x03 \x03(\x0e\x32\x1b.isa.mqtt.DeviceMessageType\x12\x12\n\ndevice_ids\x18\x04 \x03(\t\x12\x16\n\x0etopic_patterns\x18\x05 \x03(\t\"\xaf\x02\n\rDeviceMessage\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x31\n\x0cmessage_type\x18\x02 \x01(\x0e\x32\x1b.isa.mqtt.DeviceMessageType\x12\r\n\x05topic\x18\x03 \x01(\t\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x08metadata\x18\x06 \x03(\x0b\x32%.isa.mqtt.DeviceMessage.MetadataEntry\x12\x1f\n\x03qos\x18\x07 \x01(\x0e\x32\x12.isa.mqtt.QoSLevel\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x03\n\x0bWebhookInfo\x12\x12\n\nwebhook_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x32\n\rmessage_types\x18\x04 \x03(\x0e\x32\x1b.isa.mqtt.DeviceMessageType\x12\x12\n\ndevice_ids\x18\x05 \x03(\t\x12\x16\n\x0etopic_patterns\x18\x06 \x03(\t\x12\x33\n\x07headers\x18\x07 \x03(\x0b\x32\".isa.mqtt.WebhookInfo.HeadersEntry\x12\x0f\n\x07\x65nabled\x18\x08 \x01(\x08\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rsuccess_count\x18\x0b \x01(\x03\x12\x15\n\rfailure_count\x18\x0c \x01(\x03\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaf\x02\n\x16RegisterWebhookRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x32\n\rmessage_types\x18\x04 \x03(\x0e\x32\x1b.isa.mqtt.DeviceMessageType\x12\x12\n\ndevice_ids\x18\x05 \x03(\t\x12\x16\n\x0etopic_patterns\x18\x06 \x03(\t\x12>\n\x07headers\x18\x07 \x03(\x0b\x32-.isa.mqtt.RegisterWebhookRequest.HeadersEntry\x12\x0e\n\x06secret\x18\x08 \x01(\t\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"w\n\x17RegisterWebhookResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x12\n\nwebhook_id\x18\x02 \x01(\t\x12&\n\x07webhook\x18\x03 \x01(\x0b\x32\x15.isa.mqtt.WebhookInfo\x12\x0f\n\x07message\x18\x04 \x01(\t\"?\n\x18UnregisterWebhookRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x12\n\nwebhook_id\x18\x02 \x01(\t\"=\n\x19UnregisterWebhookResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"Y\n\x13ListWebhooksRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x18\n\x10include_disabled\x18\x03 \x01(\x08\"T\n\x14ListWebhooksResponse\x12\'\n\x08webhooks\x18\x01 \x03(\x0b\x32\x15.isa.mqtt.WebhookInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05*M\n\x08QoSLevel\x12\x14\n\x10QOS_AT_MOST_ONCE\x10\x00\x12\x15\n\x11QOS_AT_LEAST_ONCE\x10\x01\x12\x14\n\x10QOS_EXACTLY_ONCE\x10\x02*p\n\x0c\x44\x65viceStatus\x12\x12\n\x0e\x44\x45VICE_UNKNOWN\x10\x00\x12\x11\n\rDEVICE_ONLINE\x10\x01\x12\x12\n\x0e\x44\x45VICE_OFFLINE\x10\x02\x12\x13\n\x0f\x44\x45VICE_SLEEPING\x10\x03\x12\x10\n\x0c\x44\x45VICE_ERROR\x10\x04*\xec\x01\n\x11\x44\x65viceMessageType\x12\x1a\n\x16\x44\x45VICE_MESSAGE_UNKNOWN\x10\x00\x12\x1c\n\x18\x44\x45VICE_MESSAGE_TELEMETRY\x10\x01\x12\x19\n\x15\x44\x45VICE_MESSAGE_STATUS\x10\x02\x12\x17\n\x13\x44\x45VICE_MESSAGE_AUTH\x10\x03\x12\x1f\n\x1b\x44\x45VICE_MESSAGE_REGISTRATION\x10\x04\x12#\n\x1f\x44\x45VICE_MESSAGE_COMMAND_RESPONSE\x10\x05\x12#\n\x1f\x44\x45VICE_MESSAGE_NOTIFICATION_ACK\x10\x06\x32\xbc\x12\n\x0bMQTTService\x12>\n\x07\x43onnect\x12\x18.isa.mqtt.ConnectRequest\x1a\x19.isa.mqtt.ConnectResponse\x12G\n\nDisconnect\x12\x1b.isa.mqtt.DisconnectRequest\x1a\x1c.isa.mqtt.DisconnectResponse\x12\\\n\x13GetConnectionStatus\x12!.isa.mqtt.ConnectionStatusRequest\x1a\".isa.mqtt.ConnectionStatusResponse\x12>\n\x07Publish\x12\x18.isa.mqtt.PublishRequest\x1a\x19.isa.mqtt.PublishResponse\x12M\n\x0cPublishBatch\x12\x1d.isa.mqtt.PublishBatchRequest\x1a\x1e.isa.mqtt.PublishBatchResponse\x12\x46\n\x0bPublishJSON\x12\x1c.isa.mqtt.PublishJSONRequest\x1a\x19.isa.mqtt.PublishResponse\x12\x44\n\tSubscribe\x12\x1a.isa.mqtt.SubscribeRequest\x1a\x19.isa.mqtt.MessageResponse0\x01\x12T\n\x11SubscribeMultiple\x12\".isa.mqtt.SubscribeMultipleRequest\x1a\x19.isa.mqtt.MessageResponse0\x01\x12J\n\x0bUnsubscribe\x12\x1c.isa.mqtt.UnsubscribeRequest\x1a\x1d.isa.mqtt.UnsubscribeResponse\x12\\\n\x11ListSubscriptions\x12\".isa.mqtt.ListSubscriptionsRequest\x1a#.isa.mqtt.ListSubscriptionsResponse\x12S\n\x0eRegisterDevice\x12\x1f.isa.mqtt.RegisterDeviceRequest\x1a .isa.mqtt.RegisterDeviceResponse\x12Y\n\x10UnregisterDevice\x12!.isa.mqtt.UnregisterDeviceRequest\x1a\".isa.mqtt.UnregisterDeviceResponse\x12J\n\x0bListDevices\x12\x1c.isa.mqtt.ListDevicesRequest\x1a\x1d.isa.mqtt.ListDevicesResponse\x12P\n\rGetDeviceInfo\x12\x1e.isa.mqtt.GetDeviceInfoRequest\x1a\x1f.isa.mqtt.GetDeviceInfoResponse\x12_\n\x12UpdateDeviceStatus\x12#.isa.mqtt.UpdateDeviceStatusRequest\x1a$.isa.mqtt.UpdateDeviceStatusResponse\x12M\n\x0cGetTopicInfo\x12\x1d.isa.mqtt.GetTopicInfoRequest\x1a\x1e.isa.mqtt.GetTopicInfoResponse\x12G\n\nListTopics\x12\x1b.isa.mqtt.ListTopicsRequest\x1a\x1c.isa.mqtt.ListTopicsResponse\x12P\n\rValidateTopic\x12\x1e.isa.mqtt.ValidateTopicRequest\x1a\x1f.isa.mqtt.ValidateTopicResponse\x12_\n\x12SetRetainedMessage\x12#.isa.mqtt.SetRetainedMessageRequest\x1a$.isa.mqtt.SetRetainedMessageResponse\x12_\n\x12GetRetainedMessage\x12#.isa.mqtt.GetRetainedMessageRequest\x1a$.isa.mqtt.GetRetainedMessageResponse\x12h\n\x15\x44\x65leteRetainedMessage\x12&.isa.mqtt.DeleteRetainedMessageRequest\x1a\'.isa.mqtt.DeleteRetainedMessageResponse\x12P\n\rGetStatistics\x12\x1e.isa.mqtt.GetStatisticsRequest\x1a\x1f.isa.mqtt.GetStatisticsResponse\x12Y\n\x10GetDeviceMetrics\x12!.isa.mqtt.GetDeviceMetricsRequest\x1a\".isa.mqtt.GetDeviceMetricsResponse\x12R\n\x0bHealthCheck\x12 .isa.mqtt.MQTTHealthCheckRequest\x1a!.isa.mqtt.MQTTHealthCheckResponse\x12^\n\x17SubscribeDeviceMessages\x12(.isa.mqtt.SubscribeDeviceMessagesRequest\x1a\x17.isa.mqtt.DeviceMessage0\x01\x12V\n\x0fRegisterWebhook\x12 .isa.mqtt.RegisterWebhookRequest\x1a!.isa.mqtt.RegisterWebhookResponse\x12\\\n\x11UnregisterWebhook\x12\".isa.mqtt.UnregisterWebhookRequest\x1a#.isa.mqtt.UnregisterWebhookResponse\x12M\n\x0cListWebhooks\x12\x1d.isa.mqtt.ListWebhooksRequest\x1a\x1e.isa.mqtt.ListWebhooksResponseB/Z-github.com/isa-cloud/isa_cloud/api/proto/mqttb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mqtt_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/isa-cloud/isa_cloud/api/proto/mqtt'
  _globals['_DEVICEINFO_METADATAENTRY']._loaded_options = None
  _globals['_DEVICEINFO_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_MQTTMESSAGE_PROPERTIESENTRY']._loaded_options = None
  _globals['_MQTTMESSAGE_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_PUBLISHREQUEST_PROPERTIESENTRY']._loaded_options = None
  _globals['_PUBLISHREQUEST_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_MESSAGERESPONSE_PROPERTIESENTRY']._loaded_options = None
  _globals['_MESSAGERESPONSE_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_REGISTERDEVICEREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_REGISTERDEVICEREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEDEVICESTATUSREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_UPDATEDEVICESTATUSREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETSTATISTICSRESPONSE_DEVICETYPEDISTRIBUTIONENTRY']._loaded_options = None
  _globals['_GETSTATISTICSRESPONSE_DEVICETYPEDISTRIBUTIONENTRY']._serialized_options = b'8\001'
  _globals['_DEVICEMESSAGE_METADATAENTRY']._loaded_options = None
  _globals['_DEVICEMESSAGE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_WEBHOOKINFO_HEADERSENTRY']._loaded_options = None
  _globals['_WEBHOOKINFO_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_REGISTERWEBHOOKREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_REGISTERWEBHOOKREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_QOSLEVEL']._serialized_start=8165
  _globals['_QOSLEVEL']._serialized_end=8242
  _globals['_DEVICESTATUS']._serialized_start=8244
  _globals['_DEVICESTATUS']._serialized_end=8356
  _globals['_DEVICEMESSAGETYPE']._serialized_start=8359
  _globals['_DEVICEMESSAGETYPE']._serialized_end=8595
  _globals['_DEVICEINFO']._serialized_start=110
  _globals['_DEVICEINFO']._serialized_end=543
  _globals['_DEVICEINFO_METADATAENTRY']._serialized_start=496
  _globals['_DEVICEINFO_METADATAENTRY']._serialized_end=543
  _globals['_TOPICINFO']._serialized_start=546
  _globals['_TOPICINFO']._serialized_end=748
  _globals['_MQTTMESSAGE']._serialized_start=751
  _globals['_MQTTMESSAGE']._serialized_end=1024
  _globals['_MQTTMESSAGE_PROPERTIESENTRY']._serialized_start=975
  _globals['_MQTTMESSAGE_PROPERTIESENTRY']._serialized_end=1024
  _globals['_CONNECTREQUEST']._serialized_start=1027
  _globals['_CONNECTREQUEST']._serialized_end=1259
  _globals['_CONNECTRESPONSE']._serialized_start=1261
  _globals['_CONNECTRESPONSE']._serialized_end=1357
  _globals['_DISCONNECTREQUEST']._serialized_start=1359
  _globals['_DISCONNECTREQUEST']._serialized_end=1415
  _globals['_DISCONNECTRESPONSE']._serialized_start=1417
  _globals['_DISCONNECTRESPONSE']._serialized_end=1471
  _globals['_CONNECTIONSTATUSREQUEST']._serialized_start=1473
  _globals['_CONNECTIONSTATUSREQUEST']._serialized_end=1535
  _globals['_CONNECTIONSTATUSRESPONSE']._serialized_start=1538
  _globals['_CONNECTIONSTATUSRESPONSE']._serialized_end=1683
  _globals['_PUBLISHREQUEST']._serialized_start=1686
  _globals['_PUBLISHREQUEST']._serialized_end=1935
  _globals['_PUBLISHREQUEST_PROPERTIESENTRY']._serialized_start=975
  _globals['_PUBLISHREQUEST_PROPERTIESENTRY']._serialized_end=1024
  _globals['_PUBLISHRESPONSE']._serialized_start=1937
  _globals['_PUBLISHRESPONSE']._serialized_end=2058
  _globals['_PUBLISHBATCHREQUEST']._serialized_start=2060
  _globals['_PUBLISHBATCHREQUEST']._serialized_end=2162
  _globals['_PUBLISHBATCHRESPONSE']._serialized_start=2164
  _globals['_PUBLISHBATCHRESPONSE']._serialized_end=2287
  _globals['_PUBLISHJSONREQUEST']._serialized_start=2290
  _globals['_PUBLISHJSONREQUEST']._serialized_end=2452
  _globals['_SUBSCRIBEREQUEST']._serialized_start=2454
  _globals['_SUBSCRIBEREQUEST']._serialized_end=2564
  _globals['_SUBSCRIBEMULTIPLEREQUEST']._serialized_start=2566
  _globals['_SUBSCRIBEMULTIPLEREQUEST']._serialized_end=2681
  _globals['_TOPICSUBSCRIPTION']._serialized_start=2683
  _globals['_TOPICSUBSCRIPTION']._serialized_end=2757
  _globals['_MESSAGERESPONSE']._serialized_start=2760
  _globals['_MESSAGERESPONSE']._serialized_end=3041
  _globals['_MESSAGERESPONSE_PROPERTIESENTRY']._serialized_start=975
  _globals['_MESSAGERESPONSE_PROPERTIESENTRY']._serialized_end=1024
  _globals['_UNSUBSCRIBEREQUEST']._serialized_start=3043
  _globals['_UNSUBSCRIBEREQUEST']._serialized_end=3123
  _globals['_UNSUBSCRIBERESPONSE']._serialized_start=3125
  _globals['_UNSUBSCRIBERESPONSE']._serialized_end=3208
  _globals['_LISTSUBSCRIPTIONSREQUEST']._serialized_start=3210
  _globals['_LISTSUBSCRIPTIONSREQUEST']._serialized_end=3273
  _globals['_LISTSUBSCRIPTIONSRESPONSE']._serialized_start=3275
  _globals['_LISTSUBSCRIPTIONSRESPONSE']._serialized_end=3354
  _globals['_REGISTERDEVICEREQUEST']._serialized_start=3357
  _globals['_REGISTERDEVICEREQUEST']._serialized_end=3597
  _globals['_REGISTERDEVICEREQUEST_METADATAENTRY']._serialized_start=496
  _globals['_REGISTERDEVICEREQUEST_METADATAENTRY']._serialized_end=543
  _globals['_REGISTERDEVICERESPONSE']._serialized_start=3599
  _globals['_REGISTERDEVICERESPONSE']._serialized_end=3695
  _globals['_UNREGISTERDEVICEREQUEST']._serialized_start=3697
  _globals['_UNREGISTERDEVICEREQUEST']._serialized_end=3758
  _globals['_UNREGISTERDEVICERESPONSE']._serialized_start=3760
  _globals['_UNREGISTERDEVICERESPONSE']._serialized_end=3820
  _globals['_LISTDEVICESREQUEST']._serialized_start=3823
  _globals['_LISTDEVICESREQUEST']._serialized_end=3958
  _globals['_LISTDEVICESRESPONSE']._serialized_start=3960
  _globals['_LISTDEVICESRESPONSE']._serialized_end=4074
  _globals['_GETDEVICEINFOREQUEST']._serialized_start=4076
  _globals['_GETDEVICEINFOREQUEST']._serialized_end=4134
  _globals['_GETDEVICEINFORESPONSE']._serialized_start=4136
  _globals['_GETDEVICEINFORESPONSE']._serialized_end=4197
  _globals['_UPDATEDEVICESTATUSREQUEST']._serialized_start=4200
  _globals['_UPDATEDEVICESTATUSREQUEST']._serialized_end=4421
  _globals['_UPDATEDEVICESTATUSREQUEST_METADATAENTRY']._serialized_start=496
  _globals['_UPDATEDEVICESTATUSREQUEST_METADATAENTRY']._serialized_end=543
  _globals['_UPDATEDEVICESTATUSRESPONSE']._serialized_start=4423
  _globals['_UPDATEDEVICESTATUSRESPONSE']._serialized_end=4506
  _globals['_GETTOPICINFOREQUEST']._serialized_start=4508
  _globals['_GETTOPICINFOREQUEST']._serialized_end=4561
  _globals['_GETTOPICINFORESPONSE']._serialized_start=4563
  _globals['_GETTOPICINFORESPONSE']._serialized_end=4626
  _globals['_LISTTOPICSREQUEST']._serialized_start=4628
  _globals['_LISTTOPICSREQUEST']._serialized_end=4738
  _globals['_LISTTOPICSRESPONSE']._serialized_start=4740
  _globals['_LISTTOPICSRESPONSE']._serialized_end=4818
  _globals['_VALIDATETOPICREQUEST']._serialized_start=4820
  _globals['_VALIDATETOPICREQUEST']._serialized_end=4882
  _globals['_VALIDATETOPICRESPONSE']._serialized_start=4884
  _globals['_VALIDATETOPICRESPONSE']._serialized_end=4959
  _globals['_SETRETAINEDMESSAGEREQUEST']._serialized_start=4961
  _globals['_SETRETAINEDMESSAGEREQUEST']._serialized_end=5070
  _globals['_SETRETAINEDMESSAGERESPONSE']._serialized_start=5072
  _globals['_SETRETAINEDMESSAGERESPONSE']._serialized_end=5134
  _globals['_GETRETAINEDMESSAGEREQUEST']._serialized_start=5136
  _globals['_GETRETAINEDMESSAGEREQUEST']._serialized_end=5195
  _globals['_GETRETAINEDMESSAGERESPONSE']._serialized_start=5197
  _globals['_GETRETAINEDMESSAGERESPONSE']._serialized_end=5280
  _globals['_DELETERETAINEDMESSAGEREQUEST']._serialized_start=5282
  _globals['_DELETERETAINEDMESSAGEREQUEST']._serialized_end=5344
  _globals['_DELETERETAINEDMESSAGERESPONSE']._serialized_start=5346
  _globals['_DELETERETAINEDMESSAGERESPONSE']._serialized_end=5411
  _globals['_GETSTATISTICSREQUEST']._serialized_start=5413
  _globals['_GETSTATISTICSREQUEST']._serialized_end=5477
  _globals['_GETSTATISTICSRESPONSE']._serialized_start=5480
  _globals['_GETSTATISTICSRESPONSE']._serialized_end=5846
  _globals['_GETSTATISTICSRESPONSE_DEVICETYPEDISTRIBUTIONENTRY']._serialized_start=5785
  _globals['_GETSTATISTICSRESPONSE_DEVICETYPEDISTRIBUTIONENTRY']._serialized_end=5846
  _globals['_GETDEVICEMETRICSREQUEST']._serialized_start=5849
  _globals['_GETDEVICEMETRICSREQUEST']._serialized_end=6004
  _globals['_GETDEVICEMETRICSRESPONSE']._serialized_start=6007
  _globals['_GETDEVICEMETRICSRESPONSE']._serialized_end=6242
  _globals['_TIMESERIESPOINT']._serialized_start=6244
  _globals['_TIMESERIESPOINT']._serialized_end=6323
  _globals['_MQTTHEALTHCHECKREQUEST']._serialized_start=6325
  _globals['_MQTTHEALTHCHECKREQUEST']._serialized_end=6369
  _globals['_MQTTHEALTHCHECKRESPONSE']._serialized_start=6372
  _globals['_MQTTHEALTHCHECKRESPONSE']._serialized_end=6530
  _globals['_SUBSCRIBEDEVICEMESSAGESREQUEST']._serialized_start=6533
  _globals['_SUBSCRIBEDEVICEMESSAGESREQUEST']._serialized_end=6703
  _globals['_DEVICEMESSAGE']._serialized_start=6706
  _globals['_DEVICEMESSAGE']._serialized_end=7009
  _globals['_DEVICEMESSAGE_METADATAENTRY']._serialized_start=496
  _globals['_DEVICEMESSAGE_METADATAENTRY']._serialized_end=543
  _globals['_WEBHOOKINFO']._serialized_start=7012
  _globals['_WEBHOOKINFO']._serialized_end=7431
  _globals['_WEBHOOKINFO_HEADERSENTRY']._serialized_start=7385
  _globals['_WEBHOOKINFO_HEADERSENTRY']._serialized_end=7431
  _globals['_REGISTERWEBHOOKREQUEST']._serialized_start=7434
  _globals['_REGISTERWEBHOOKREQUEST']._serialized_end=7737
  _globals['_REGISTERWEBHOOKREQUEST_HEADERSENTRY']._serialized_start=7385
  _globals['_REGISTERWEBHOOKREQUEST_HEADERSENTRY']._serialized_end=7431
  _globals['_REGISTERWEBHOOKRESPONSE']._serialized_start=7739
  _globals['_REGISTERWEBHOOKRESPONSE']._serialized_end=7858
  _globals['_UNREGISTERWEBHOOKREQUEST']._serialized_start=7860
  _globals['_UNREGISTERWEBHOOKREQUEST']._serialized_end=7923
  _globals['_UNREGISTERWEBHOOKRESPONSE']._serialized_start=7925
  _globals['_UNREGISTERWEBHOOKRESPONSE']._serialized_end=7986
  _globals['_LISTWEBHOOKSREQUEST']._serialized_start=7988
  _globals['_LISTWEBHOOKSREQUEST']._serialized_end=8077
  _globals['_LISTWEBHOOKSRESPONSE']._serialized_start=8079
  _globals['_LISTWEBHOOKSRESPONSE']._serialized_end=8163
  _globals['_MQTTSERVICE']._serialized_start=8598
  _globals['_MQTTSERVICE']._serialized_end=10962
# @@protoc_insertion_point(module_scope)
